@@ -14,4 +14,7 @@
 
 from .interface import enable
 from .interface import bench
-from .interface import superbench
\ No newline at end of file
+from .interface import superbench
+
+# from .interface import superreport
+from .interface import auto_quant
