@@ -12,23 +12,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import logging
+import os
+import re
+import sys
+
+import yaml
+
 from ... import globals
 from ...utils.line_operation import (
     get_line_indent_level,
-    is_eval_func_model_name,
     get_line_left_hand_side,
     get_line_wo_comment,
-    single_line_comment_or_empty_line_detection
+    is_eval_func_model_name,
+    single_line_comment_or_empty_line_detection,
 )
-from . import domain
-import logging
-import yaml
-import sys
-import os
 
-logging.basicConfig(level=globals.logging_level,
-                    format='%(asctime)s %(levelname)s %(message)s',
-                    datefmt='%a, %d %b %Y %H:%M:%S +0000')
+logging.basicConfig(
+    level=globals.logging_level, format="%(asctime)s %(levelname)s %(message)s", datefmt="%a, %d %b %Y %H:%M:%S +0000"
+)
 logger = logging.getLogger(__name__)
 
 
@@ -38,32 +40,33 @@ class AutoInc_Harness(object):
 
     def print_info(self):
         for i in globals.list_model_def_instance:
-            logger.debug(f"i.print_info(): {i.print_info()}")   
+            logger.debug(f"i.print_info(): {i.print_info()}")
 
     # collect file transformation info and register in globals
     # (i.e. which file to add which lines at which location)
     def register_transformation(self):
-        backend_file = open(os.path.dirname(__file__) +
-                            "/../../backends/" + self.backend + ".yaml")
+        backend_file = open(os.path.dirname(__file__) + "/../../backends/" + self.backend + ".yaml")
         backend_dict = yaml.load(backend_file, Loader=yaml.BaseLoader)
         logger.debug(f"backend_dict: {backend_dict}")
         bk_trans_location = backend_dict["transformation"]["location"]  # string
         bk_trans_content = backend_dict["transformation"]["content"]  # string
         bk_trans_order = backend_dict["transformation"]["order"]  # list
 
-        domain_ = domain.determine_domain(globals.list_code_path[0])
+        # modular design
+        if globals.use_modular:
+            content = globals.modular_item
+            bk_trans_content = ["[+] " + content.replace("\n", "\n[+] ")[:-5]]
+
         list_code = []
         history = set()
         for i in globals.list_code_path:
-            list_code.append(open(i, 'r').read())
+            list_code.append(open(i, "r").read())
         for loc in bk_trans_location:
-
             # PART 1 - "model_definition_line"
             if "insert_below_model_definition_line" in loc:
-
                 for ins in globals.list_model_def_instance:
                     model_name = ins.model_name
-                    if model_name in history and domain_ == 'torchvision':
+                    if model_name in history and globals.code_domain == "torchvision":
                         continue
                     else:
                         history.add(model_name)
@@ -71,7 +74,7 @@ class AutoInc_Harness(object):
                     model_def_line_idx = ins.model_def_line_idx
 
                     file_path_idx = globals.list_code_path.index(file_path)
-                    lines = list_code[file_path_idx].split('\n')
+                    lines = list_code[file_path_idx].split("\n")
                     line_idx = 0
 
                     # to check if this model has an inference line is in the file
@@ -79,12 +82,14 @@ class AutoInc_Harness(object):
                     to_transform = False
                     for i in range(len(lines)):
                         line = lines[i]
-                        if model_name + "(" in line or \
-                            (model_name + "." in line and line.find(model_name) < line.find(".") and "(" in line):
+                        if model_name + "(" in line or (
+                            model_name + "." in line and line.find(model_name) < line.find(".") and "(" in line
+                        ):
                             to_transform = True
-                    if not to_transform:
+                    if not to_transform and globals.code_domain == "onnx":
+                        pass
+                    elif not to_transform:
                         continue
-
                     ### information
 
                     # search DataLoader definition in this file
@@ -92,9 +97,9 @@ class AutoInc_Harness(object):
                     for i in range(len(lines)):
                         line = lines[i]
                         if not single_line_comment_or_empty_line_detection(line):
-                            if ("DataLoader(" in line and "=" in line and line.find("=") < line.find("DataLoader")) \
-                                or ("dataloader" in line and "=" in line and \
-                                    line.find("=") > line.find("dataloader")):
+                            if ("DataLoader(" in line and "=" in line and line.find("=") < line.find("DataLoader")) or (
+                                "dataloader" in line and "=" in line and line.find("=") > line.find("dataloader")
+                            ):
                                 dataloader_def_line_indent_level = get_line_indent_level(line)
                                 dataloader_name = get_line_left_hand_side(line)
                                 dataloader_def_line_idx = i
@@ -108,7 +113,7 @@ class AutoInc_Harness(object):
                         if not single_line_comment_or_empty_line_detection(line):
                             if is_eval_func and "[coder-enabled]" not in line:
                                 inference_line = line
-                                input_name = line[line.find("(")+1:line.find(")")].replace("*","") 
+                                input_name = line[line.find("(") + 1 : line.find(")")].replace("*", "")
                                 # get "c" in "a = b(**c)"
 
                     # search input definition in this file (if any)
@@ -119,8 +124,8 @@ class AutoInc_Harness(object):
                                 if input_name in line and "=" in line and line.find("=") > line.find(input_name):
                                     input_def_line_indent_level = get_line_indent_level(line)
                                     input_def_line_idx = i
-                    
-                    # serach model definition line and its end line index
+
+                    # search model definition line and its end line index
                     # (only has 1 model definition line, because it's in loop of globals.list_model_def_instance)
                     for i in range(len(lines)):
                         line = lines[i]
@@ -142,28 +147,32 @@ class AutoInc_Harness(object):
                     ### check
 
                     bk_trans_content_this = bk_trans_content[bk_trans_location.index(loc)]
-                    if file_path_idx == 0 and (domain_ == 'transformers_trainer' or domain_ == 'torchvision'):
+                    if file_path_idx == 0 and (globals.code_domain in ["transformers_trainer", "torchvision", "onnx"]):
                         pass
-                    elif ("INPUT_NAME" in bk_trans_content_this and input_name == "") \
-                            or ("DATALOADER_NAME" in bk_trans_content_this and dataloader_name == "") \
-                            or ("INFERENCE_LINE" in bk_trans_content_this and inference_line == ""):
-                        logger.info(f"Skipped due to not having enough information required by "
-                                    "the transformation content specified in the config file "
-                                    "(e.g. INPUT_NAME, DATALOADER_NAME, INFERENCE_LINE). "
-                                    f"File path: {file_path}")
+                    elif (
+                        ("INPUT_NAME" in bk_trans_content_this and input_name == "")
+                        or ("DATALOADER_NAME" in bk_trans_content_this and dataloader_name == "")
+                        or ("INFERENCE_LINE" in bk_trans_content_this and inference_line == "")
+                    ):
+                        logger.info(
+                            f"Skipped due to not having enough information required by "
+                            "the transformation content specified in the config file "
+                            "(e.g. INPUT_NAME, DATALOADER_NAME, INFERENCE_LINE). "
+                            f"File path: {file_path}"
+                        )
                         continue
 
                     ### location
 
                     # search for features to put below them
-                    '''
+                    """
                     Example (psuedo-code):
                     model = Net()
                     # jit script begin mark
                     model = torch.jit.script(model)
                     # jit script end mark (feature name + model name to handle multi-model situation)
                     model = ipex.optimize(model, "fp32") # "ipex fp32" must be put below "jit script"
-                    '''
+                    """
                     put_below_idx = 0
                     for i in range(len(lines)):
                         for item in bk_trans_order[0]["below"]:
@@ -181,10 +190,10 @@ class AutoInc_Harness(object):
 
                     # location assignment (below model def / dataloader def / input def)
                     torchvision_indent = -1
-                    if file_path_idx == 0 and domain_ == 'transformers_trainer':
+                    if file_path_idx == 0 and globals.code_domain == "transformers_trainer":
                         for i in range(len(lines)):
                             line = lines[i]
-                            if "trainer = Trainer" in line:
+                            if re.findall("trainer = .*Trainer", line):
                                 if "(" in line and line.count(")") == line.count("("):
                                     trans_insert_location = i + 1
                                 else:
@@ -192,19 +201,26 @@ class AutoInc_Harness(object):
                                     i_search = 1
                                     while do_search:
                                         following_line = lines[i + i_search]
-                                        if ")" in following_line and \
-                                            following_line.count(")") > following_line.count("("):
+                                        if ")" in following_line and following_line.count(")") > following_line.count(
+                                            "("
+                                        ):
                                             do_search = False
                                         i_search += 1
                                     trans_insert_location = i + i_search
                         trans_insert_location = min(max(trans_insert_location, put_below_idx), put_above_idx)
-                    elif file_path_idx == 0 and domain_ == 'torchvision':
+                    elif file_path_idx == 0 and globals.code_domain == "torchvision":
                         trans_insert_location = 1
                         for i in range(len(lines)):
                             line = lines[i]
-                            if "val_loader" in line and "aux_val_loader" not in line \
-                                and ("torch.utils.data.DataLoader" in line \
-                                    or "utils.data.DataLoader" in line or "DataLoader" in line):
+                            if (
+                                "val_loader" in line
+                                and "aux_val_loader" not in line
+                                and (
+                                    "torch.utils.data.DataLoader" in line
+                                    or "utils.data.DataLoader" in line
+                                    or "DataLoader" in line
+                                )
+                            ):
                                 torchvision_indent = get_line_indent_level(line)
                                 if "(" in line and line.count(")") == line.count("("):
                                     trans_insert_location = i + 1
@@ -213,75 +229,107 @@ class AutoInc_Harness(object):
                                     i_search = 1
                                     while do_search:
                                         following_line = lines[i + i_search]
-                                        if ")" in following_line and \
-                                            following_line.count(")") > following_line.count("("):
+                                        if ")" in following_line and following_line.count(")") > following_line.count(
+                                            "("
+                                        ):
                                             do_search = False
                                         i_search += 1
                                     trans_insert_location = i + i_search
                         trans_insert_location = min(max(trans_insert_location, put_below_idx), put_above_idx)
                     else:
                         if "insert_below_model_definition_line" in loc:
-                            trans_insert_location = \
-                                min(max(model_definition_end_line_idx,
-                                    put_below_idx), put_above_idx)
+                            trans_insert_location = min(
+                                max(model_definition_end_line_idx, put_below_idx), put_above_idx
+                            )
                         if "insert_below_dataloader_definition_line" in loc:
                             try:
                                 dataloader_def_line_idx
                             except:
-                                logger.warning(f"Skipped due to not having dataloader definition required by "
-                                                "the transformation content specified in the config file. "
-                                                f"File path: {file_path}")
+                                logger.warning(
+                                    f"Skipped due to not having dataloader definition required by "
+                                    "the transformation content specified in the config file. "
+                                    f"File path: {file_path}"
+                                )
                                 continue
-                            trans_insert_location = max(trans_insert_location,
-                                                        min(max(dataloader_def_line_idx + 1,
-                                                                put_below_idx), put_above_idx))
+                            trans_insert_location = max(
+                                trans_insert_location,
+                                min(max(dataloader_def_line_idx + 1, put_below_idx), put_above_idx),
+                            )
                         if "insert_below_input_definition_line" in loc:
                             try:
                                 input_def_line_idx
                             except:
-                                logger.warning(f"Skipped due to not having input definition required by "
-                                                "the transformation content specified in the config file. "
-                                                f"File path: {file_path}")
+                                logger.warning(
+                                    f"Skipped due to not having input definition required by "
+                                    "the transformation content specified in the config file. "
+                                    f"File path: {file_path}"
+                                )
                                 continue
-                            trans_insert_location = max(trans_insert_location,
-                                                        min(max(input_def_line_idx + 1,
-                                                                put_below_idx), put_above_idx))
-                                                        
-                    insert_indent_level = get_line_indent_level(lines[trans_insert_location - 1]) \
-                        if torchvision_indent == -1 else torchvision_indent
+                            trans_insert_location = max(
+                                trans_insert_location, min(max(input_def_line_idx + 1, put_below_idx), put_above_idx)
+                            )
+
+                    insert_indent_level = (
+                        get_line_indent_level(lines[trans_insert_location - 1])
+                        if torchvision_indent == -1
+                        else torchvision_indent
+                    )
                     ### content
                     # lines to insert
                     lines_to_insert = bk_trans_content_this
-                    if domain_ == 'transformers_trainer':
-                        lines_to_insert = lines_to_insert \
-                            .replace("EVAL_FUNC_LINES", globals.list_eval_func_lines[0]) \
-                            .replace("DATALOADER_NAME", globals.list_calib_dataloader_name[0])
-                    elif domain_ == 'transformers_no_trainer':
+                    if globals.code_domain == "transformers_trainer":
+                        lines_to_insert = lines_to_insert.replace(
+                            "EVAL_FUNC_LINES", globals.list_eval_func_lines[0]
+                        ).replace("DATALOADER_NAME", globals.list_calib_dataloader_name[0])
+                    elif globals.code_domain == "transformers_no_trainer":
                         pass
-                    elif domain_ == 'torchvision':
-                        lines_to_insert = lines_to_insert \
-                            .replace("EVAL_FUNC_LINES", globals.list_eval_func_lines[0]) \
-                            .replace("DATALOADER_NAME", globals.list_calib_dataloader_name[0])
+                    elif globals.code_domain == "torchvision":
+                        lines_to_insert = lines_to_insert.replace(
+                            "EVAL_FUNC_LINES", globals.list_eval_func_lines[0]
+                        ).replace("DATALOADER_NAME", globals.list_calib_dataloader_name[0])
+                    elif globals.code_domain == "onnx":
+                        lines_to_insert = lines_to_insert.replace(
+                            "EVAL_FUNCTION_NAME", globals.list_eval_func_name[0]
+                        ).replace("DATALOADER_NAME", globals.list_calib_dataloader_name[0])
                     else:
-                        lines_to_insert = lines_to_insert \
-                            .replace("DATALOADER_NAME", dataloader_name)
+                        lines_to_insert = lines_to_insert.replace("DATALOADER_NAME", dataloader_name).replace(
+                            "def eval_func", "# def eval_func"
+                        )
+
+                    optimum_quant_config_line = (
+                        'IncQuantizationConfig.from_pretrained("' + globals.optimum_quant_config + '")'
+                    )
 
                     # replace [+] indication with empty
-                    lines_to_insert = lines_to_insert.replace(
-                        "[+] ", " " * insert_indent_level)
+                    lines_to_insert = lines_to_insert.replace("[+] ", " " * insert_indent_level)
                     # add begin indicator
-                    lines_to_insert = " " * insert_indent_level + "# [NeuralCoder] " + \
-                        self.backend + " for " + model_name + " [Beginning Line]\n" + lines_to_insert
+                    lines_to_insert = (
+                        " " * insert_indent_level
+                        + "# [NeuralCoder] "
+                        + self.backend
+                        + " for "
+                        + model_name
+                        + " [Beginning Line]\n"
+                        + lines_to_insert
+                    )
                     # replace INDICATIONS with real stuff
-                    lines_to_insert = lines_to_insert \
-                        .replace("MODEL_NAME", model_name) \
-                        .replace("INPUT_NAME", input_name) \
-                        .replace("EVAL_FUNC_LINES", "return 1") \
+                    lines_to_insert = (
+                        lines_to_insert.replace("MODEL_NAME", model_name)
+                        .replace("INPUT_NAME", input_name)
+                        .replace("EVAL_FUNC_LINES", "# return 1")
+                        .replace("OPTIMUM_QUANT_CONFIG", optimum_quant_config_line)
                         .replace("\n", " # [coder-enabled]\n")
+                    )
                     # add end indicator
-                    lines_to_insert += " # [coder-enabled]\n" + \
-                        " " * insert_indent_level + "# [NeuralCoder] " + self.backend + " for " + \
-                        model_name + " [Ending Line] # [coder-enabled]"
+                    lines_to_insert += (
+                        " # [coder-enabled]\n"
+                        + " " * insert_indent_level
+                        + "# [NeuralCoder] "
+                        + self.backend
+                        + " for "
+                        + model_name
+                        + " [Ending Line] # [coder-enabled]"
+                    )
 
                     ### register
 
@@ -297,13 +345,14 @@ class AutoInc_Harness(object):
                         globals.list_trans_insert_lines_to_insert[idx].append(lines_to_insert)
 
             # PART 2 - "inference line"
-            if "indent_inference_line" in loc or \
-                "insert_above_inference_line" in loc or \
-                "insert_below_inference_line" in loc:
-
+            if (
+                "indent_inference_line" in loc
+                or "insert_above_inference_line" in loc
+                or "insert_below_inference_line" in loc
+            ):
                 for file_path in globals.list_code_path:
-                    code = open(file_path, 'r').read()
-                    lines = code.split('\n')
+                    code = open(file_path, "r").read()
+                    lines = code.split("\n")
                     line_idx = 0
                     for i in range(len(lines)):
                         line = lines[i]
@@ -311,15 +360,15 @@ class AutoInc_Harness(object):
                             is_eval_func, eval_func_type = is_eval_func_model_name(model_name, line)
                             if is_eval_func and "[coder-enabled]" not in line:
                                 if eval_func_type == "non-forward":
-                                    pass # do something
-                                
+                                    pass  # do something
+
                                 inference_line_indent_level = get_line_indent_level(line)
 
                                 if "indent_inference_line" in loc:
                                     bk_trans_content_this = bk_trans_content[bk_trans_location.index(loc)]
                                     add_indent_level = int(bk_trans_content_this)
 
-                                    trans_indent_location = [] 
+                                    trans_indent_location = []
                                     # indent can have multiple location, so is a list of numbers
                                     trans_indent_level = []
 
@@ -345,7 +394,7 @@ class AutoInc_Harness(object):
                                         globals.list_trans_indent_modified_file.append(file_path)
                                         globals.list_trans_indent_location_idxs.append(trans_indent_location)
                                         globals.list_trans_indent_level.append(trans_indent_level)
-                                    else:                            
+                                    else:
                                         idx = globals.list_trans_indent_modified_file.index(file_path)
                                         for i in trans_indent_location:
                                             globals.list_trans_indent_location_idxs[idx].append(i)
@@ -356,7 +405,7 @@ class AutoInc_Harness(object):
                                     idx_offset = 0
                                 elif "insert_below_inference_line" in loc:
                                     idx_offset = 1
-                                
+
                                 if "insert_above_inference_line" in loc or "insert_below_inference_line" in loc:
                                     bk_trans_content_this = bk_trans_content[bk_trans_location.index(loc)]
 
@@ -369,32 +418,39 @@ class AutoInc_Harness(object):
                                     # lines to insert
                                     lines_to_insert = bk_trans_content_this
                                     # replace [+] indication with empty
-                                    lines_to_insert = lines_to_insert.replace(
-                                        "[+] ", " " * insert_indent_level)
+                                    lines_to_insert = lines_to_insert.replace("[+] ", " " * insert_indent_level)
                                     # add begin indicator
-                                    lines_to_insert = " " * insert_indent_level + "# [NeuralCoder] " + \
-                                        self.backend + " [Beginning Line] \n" + lines_to_insert
-                                    # replace INDICATIONS with real stuff 
+                                    lines_to_insert = (
+                                        " " * insert_indent_level
+                                        + "# [NeuralCoder] "
+                                        + self.backend
+                                        + " [Beginning Line] \n"
+                                        + lines_to_insert
+                                    )
+                                    # replace INDICATIONS with real stuff
                                     # (for now, inference_line related transformations )
                                     # (have nothing to do with input, dataloader etc, )
                                     # (so no need to put replaces here.)
                                     lines_to_insert = lines_to_insert.replace("\n", " # [coder-enabled]\n")
                                     # add end indicator
-                                    lines_to_insert += " # [coder-enabled]\n" + \
-                                        " " * insert_indent_level + "# [NeuralCoder] " + \
-                                        self.backend + " [Ending Line] # [coder-enabled]"
+                                    lines_to_insert += (
+                                        " # [coder-enabled]\n"
+                                        + " " * insert_indent_level
+                                        + "# [NeuralCoder] "
+                                        + self.backend
+                                        + " [Ending Line] # [coder-enabled]"
+                                    )
 
                                     # customized argument
                                     if self.backend == "pytorch_benchmark":
-                                        lines_to_insert = lines_to_insert.replace("NUM_BENCHMARK_ITERATION", 
-                                                                                    globals.num_benchmark_iteration)
-                                        lines_to_insert = lines_to_insert.replace("ACCURACY_MODE", 
-                                                                                    str(globals.eval_accuracy))
-                                        lines_to_insert = lines_to_insert.replace("EVAL_FUNC_LINES", 
-                                                                                    line.strip())
+                                        lines_to_insert = lines_to_insert.replace(
+                                            "NUM_BENCHMARK_ITERATION", globals.num_benchmark_iteration
+                                        )
+                                        lines_to_insert = lines_to_insert.replace("ACCURACY_MODE", str(False))
+                                        lines_to_insert = lines_to_insert.replace("EVAL_FUNC_LINES", line.strip())
 
                                     ### register
-                                    
+
                                     if file_path not in globals.list_trans_insert_modified_file:
                                         globals.list_trans_insert_modified_file.append(file_path)
                                         globals.list_trans_insert_location_idxs.append([trans_insert_location])
@@ -414,12 +470,7 @@ class AutoInc_Harness(object):
 
             # PART 3 - for customized location
 
-
-        logger.debug(
-            f"globals.list_trans_insert_modified_file: {globals.list_trans_insert_modified_file}")
-        logger.debug(
-            f"globals.list_trans_insert_location_idxs: {globals.list_trans_insert_location_idxs}")
-        logger.debug(
-            f"globals.list_trans_insert_number_insert_lines: {globals.list_trans_insert_number_insert_lines}")
-        logger.debug(
-            f"globals.list_trans_insert_lines_to_insert: {globals.list_trans_insert_lines_to_insert}")
+        logger.debug(f"globals.list_trans_insert_modified_file: {globals.list_trans_insert_modified_file}")
+        logger.debug(f"globals.list_trans_insert_location_idxs: {globals.list_trans_insert_location_idxs}")
+        logger.debug(f"globals.list_trans_insert_number_insert_lines: {globals.list_trans_insert_number_insert_lines}")
+        logger.debug(f"globals.list_trans_insert_lines_to_insert: {globals.list_trans_insert_lines_to_insert}")
