@@ -12,7 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from ...utils.line_operation import get_line_left_hand_side, get_line_indent_level
+from ...utils.line_operation import get_line_indent_level, get_line_left_hand_side
+
 
 class TensorFlowKerasINC(object):
     def __init__(self, file) -> None:
@@ -22,30 +23,28 @@ class TensorFlowKerasINC(object):
     def transform(self):
         # import pdb
         # pdb.set_trace()
-        lines = self.file.split('\n')
+        lines = self.file.split("\n")
         for line in lines:
             if self.is_modify(line):
                 model_name = "model"
                 indent_level = get_line_indent_level(line)
                 self.result.append(line)
-                self.result.append(" " * indent_level + "from neural_compressor.conf.config import QuantConf")
-                self.result.append(" " * indent_level + "from neural_compressor.experimental import Quantization")
-                self.result.append(" " * indent_level + "from neural_compressor.experimental import common")
-                self.result.append(" " * indent_level + "quant_config = QuantConf()")
-                self.result.append(" " * indent_level + "quant_config.usr_cfg.model.framework = 'tensorflow'")
-                self.result.append(" " * indent_level + "quantizer = Quantization(quant_config)")
-                self.result.append(" " * indent_level + "quantizer.model = common.Model(" + model_name + ")")
-                self.result.append(" " * indent_level + model_name + " = quantizer.fit()")
+                self.result.append(" " * indent_level + "from neural_compressor.quantization import fit")
+                self.result.append(" " * indent_level + "from neural_compressor.config import PostTrainingQuantConfig")
+                self.result.append(" " * indent_level + "from neural_compressor import common")
+                self.result.append(" " * indent_level + "config = PostTrainingQuantConfig(quant_level=1)")
+                self.result.append(" " * indent_level + model_name + " = fit(" + model_name + ", conf=config)")
+                self.result.append(" " * indent_level + model_name + '.save("./quantized_model")')
             else:
                 self.result.append(line)
         for index, line in enumerate(self.result):
-            if index != len(self.result)-1:
-                self.result[index] += '\n'
-        return ''.join(self.result)
+            if index != len(self.result) - 1:
+                self.result[index] += "\n"
+        return "".join(self.result)
 
     def is_modify(self, s):
-        if 'model = tf.' in s or 'model = load_model(' in s:
-            if 'self.model' not in s:
+        if "model = tf." in s or "model = load_model(" in s:
+            if "self.model" not in s:
                 return True
         else:
             return False
