@@ -12,12 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import os
-import subprocess
 import logging
-import time
-import yaml
+import os
 import re
+import subprocess
+import time
+
+import yaml
 
 from . import globals
 
@@ -27,19 +28,20 @@ if not os.path.exists("neural_coder_workspace"):
 
 def detect_device_(logger):
     # device detection
-    logger.info(f"Device detection started ...")
+    logger.info("Device detection started ...")
     from .utils.device import detect_device
+
     detect_device()
     if globals.device == "cpu_with_amx":
-        logger.info(f"Device: CPU with AMX")
+        logger.info("Device: CPU with AMX")
     elif globals.device == "cpu_without_amx":
-        logger.info(f"Device: CPU without AMX")
+        logger.info("Device: CPU without AMX")
     elif globals.device == "intel_gpu":
-        logger.info(f"Device: Intel(R) GPU")
+        logger.info("Device: Intel(R) GPU")
     elif globals.device == "cuda":
-        logger.info(f"Device: CUDA")
+        logger.info("Device: CUDA")
     elif globals.device == "mutli":
-        logger.info(f"Device: Multi-Device")
+        logger.info("Device: Multi-Device")
 
 
 def enable(
@@ -63,22 +65,19 @@ def enable(
     ncore_per_instance=-1,  # only for "self_defined" mode
     ninstances=-1,  # only for "self_defined" mode
     bench_batch_size=-1,  # only for "self_defined" mode
-    test_code_line=False, # print code line info for debug use
+    test_code_line=False,  # print code line info for debug use
     cache_load_transformers=True,
-    optimum_quant_config="", # only for HF optimum optimizations, yaml or hub path
+    optimum_quant_config="",  # only for HF optimum optimizations, yaml or hub path
     use_inc=True,
     use_modular=False,
     modular_item="",
 ):
-    """enable a feature or a couple of features for the code
-
-    """
+    """Enable a feature or a couple of features for the code."""
 
     ### Preparation
 
     # set up workspace
-    ws_path = "neural_coder_workspace/" + \
-        "enable" + str(time.time()).replace(".","") + "/"
+    ws_path = "neural_coder_workspace/" + "enable" + str(time.time()).replace(".", "") + "/"
     os.makedirs(ws_path)
 
     # user parameters
@@ -89,10 +88,9 @@ def enable(
     # set up logging
     logger = logging.getLogger(ws_path)
     logger.setLevel(globals.logging_level)
-    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s: - %(message)s',
-                                  datefmt='%Y-%m-%d %H:%M:%S')
+    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s: - %(message)s", datefmt="%Y-%m-%d %H:%M:%S")
 
-    fh = logging.FileHandler(ws_path + 'enable.log')
+    fh = logging.FileHandler(ws_path + "enable.log")
     fh.setLevel(globals.logging_level)
     fh.setFormatter(formatter)
     ch = logging.StreamHandler()
@@ -106,12 +104,12 @@ def enable(
     detect_device_(logger)
 
     # print key inputs
-    logger.info(f"Enabling started ...")
+    logger.info("Enabling started ...")
     logger.info(f"code: {code}")
     logger.info(f"features: {features}")
 
     # feature list for reference
-    '''
+    """
     feature_list = [
         "pytorch_jit_script",
         "pytorch_jit_script_ofi",
@@ -149,13 +147,14 @@ def enable(
         "onnx_inc_dynamic_quant",
         "inc_auto",
     ]
-    '''
+    """
 
     ### Enable Benchmark (if run_bench)
-    
+
     if run_bench:
         # add "pytorch_change_batch_size" to features
         from .utils.cpu_info import get_num_cpu_cores
+
         ncores = get_num_cpu_cores()
         if mode == "throughput":
             target_batch_size = 2 * ncores
@@ -173,21 +172,21 @@ def enable(
         if "pytorch_benchmark" not in features:
             features.append("pytorch_benchmark")
 
-        logger.info(
-            f"Will perform benchmark on [{mode}] mode with batch size [{target_batch_size}] ...")
+        logger.info(f"Will perform benchmark on [{mode}] mode with batch size [{target_batch_size}] ...")
 
     #### Feature Enabling
 
-    globals.num_benchmark_iteration = str(num_benchmark_iteration + 10) # 10: warmup iteration number
+    globals.num_benchmark_iteration = str(num_benchmark_iteration + 10)  # 10: warmup iteration number
 
     globals.cache_load_transformers = cache_load_transformers
     globals.optimum_quant_config = optimum_quant_config
 
     globals.use_modular = use_modular
     globals.modular_item = modular_item
-    
+
     # move "pytorch_benchmark" to the last
     from .utils.common import move_element_to_last
+
     features = move_element_to_last(features, "pytorch_benchmark")
 
     # not in harness scope
@@ -199,17 +198,19 @@ def enable(
         "tensorflow_inc",
         "change_trainer_to_nlptrainer",
     ]
-    
+
     # # features that need creating dummy dataloader (when needed) first
     # if "pytorch_inc_static_quant_fx" in features or \
     #     "pytorch_inc_static_quant_ipex" in features:
     #     features = ["pytorch_dummy_dataloader"] + features
-    
+
     # features that need reclaiming inputs first (e.g. for "for step, inputs in enumerate(dataloader)")
-    if "pytorch_jit_trace" in features or \
-        "pytorch_jit_trace_ofi" in features or \
-        "pytorch_inc_static_quant_fx" in features or \
-        "pytorch_inc_static_quant_ipex" in features:
+    if (
+        "pytorch_jit_trace" in features
+        or "pytorch_jit_trace_ofi" in features
+        or "pytorch_inc_static_quant_fx" in features
+        or "pytorch_inc_static_quant_ipex" in features
+    ):
         features = ["pytorch_reclaim_inputs"] + features
 
     # intel_extension_for_transformers
@@ -223,9 +224,11 @@ def enable(
     globals.reset_globals()
 
     from .utils import handle_user_input
+
     globals.list_code_path, num_user_code_path = handle_user_input.get_all_code_path(code)
 
     from .coders.autoinc import domain
+
     code_domain = domain.determine_domain(globals.list_code_path[0])
     if code_domain == "transformers_trainer":
         if "pytorch_benchmark" in features:
@@ -236,10 +239,10 @@ def enable(
 
     ## Feature Transformation
     for idx_feature, feature in enumerate(features):
-
         # "inc_auto" auto selection of feature according to fwk
         if feature == "inc_auto":
             from .coders.autoinc import domain
+
             code_domain = domain.determine_domain(globals.list_code_path[0])
             if code_domain == "keras_script":
                 feature = "keras_inc"
@@ -254,6 +257,7 @@ def enable(
         globals.reset_globals()
 
         from .utils import handle_user_input
+
         globals.list_code_path, num_user_code_path = handle_user_input.get_all_code_path(code)
         if len(transformed_list_code_path) > 0:
             globals.list_code_path = transformed_list_code_path
@@ -265,56 +269,59 @@ def enable(
         # by the order in code_path
 
         # global behaviors
-        logger.info(
-            f"Performing code transformation for feature: [{feature}] ...")
+        logger.info(f"Performing code transformation for feature: [{feature}] ...")
 
         for i in globals.list_code_path:
-            list_transformed_code.append(open(i, 'r').read())
+            list_transformed_code.append(open(i, "r").read())
 
         ## 1. Features in Harness Scope
         if feature not in features_outside_harness:
+            from .coders.transform import execute_indent_transformation, execute_insert_transformation
             from .graphers.code_line import register_code_line
-            from .graphers.model import register_nnModule_class, register_nnModule_instance_definition
             from .graphers.function import register_func_wrap_pair
-            from .coders.transform import execute_insert_transformation, execute_indent_transformation
+            from .graphers.model import register_nnModule_class, register_nnModule_instance_definition
 
             # code analysis (call graph, type inference etc)
             register_code_line()
             register_func_wrap_pair()
             register_nnModule_class()
             if cache_load_transformers:
-                preload_file = open(os.path.dirname(__file__) +
-                    "/graphers/preloads/" + "transformers" + ".yaml")
+                preload_file = open(os.path.dirname(__file__) + "/graphers/preloads/" + "transformers" + ".yaml")
                 preload_dict = yaml.load(preload_file, Loader=yaml.BaseLoader)
                 globals.list_class_name += preload_dict["class"]
             register_nnModule_instance_definition()
             # register transformation
-            if feature == "pytorch_dummy_dataloader": # is not in harness scope, but needs call graph and type inference
+            if (
+                feature == "pytorch_dummy_dataloader"
+            ):  # is not in harness scope, but needs call graph and type inference
                 from .coders.pytorch.dummy_dataloader import DummyDataLoader
+
                 opt = DummyDataLoader(globals.list_model_def_instance)
                 opt.register_transformation()
             elif feature == "pytorch_reclaim_inputs":
                 from .coders.pytorch.reclaim_inputs import ReclaimInputs
+
                 opt = ReclaimInputs(globals.list_model_def_instance)
                 opt.register_transformation()
             elif feature == "pytorch_reclaim_inference_transformers_trainer":
                 from .coders.pytorch.reclaim_inference_transformers_trainer import ReclaimInferenceTransformersTrainer
+
                 opt = ReclaimInferenceTransformersTrainer(globals.list_model_def_instance)
                 opt.register_transformation()
             elif feature in [
-                    "pytorch_inc_dynamic_quant",
-                    "pytorch_inc_static_quant_fx",
-                    "pytorch_inc_static_quant_ipex",
-                    "pytorch_inc_huggingface_optimum_static",
-                    "pytorch_inc_huggingface_optimum_dynamic",
-                    "onnx_inc_static_quant_qlinear",
-                    "onnx_inc_static_quant_qdq",
-                    "onnx_inc_dynamic_quant",
-                    "intel_extension_for_transformers",
-                ]:
-
+                "pytorch_inc_dynamic_quant",
+                "pytorch_inc_static_quant_fx",
+                "pytorch_inc_static_quant_ipex",
+                "pytorch_inc_huggingface_optimum_static",
+                "pytorch_inc_huggingface_optimum_dynamic",
+                "onnx_inc_static_quant_qlinear",
+                "onnx_inc_static_quant_qdq",
+                "onnx_inc_dynamic_quant",
+                "intel_extension_for_transformers",
+            ]:
                 # determine domain
                 from .coders.autoinc.domain import determine_domain
+
                 globals.code_domain = determine_domain(globals.list_code_path[0])
 
                 # for transformers code, enable optimum-intel api by default
@@ -336,6 +343,7 @@ def enable(
                 from .coders.autoinc.autoinc_harness import AutoInc_Harness
                 from .coders.autoinc.calib_dataloader import Calib_Dataloader
                 from .coders.autoinc.eval_func import Eval_Func
+
                 opt = Calib_Dataloader()
                 opt.register_transformation()
 
@@ -346,6 +354,7 @@ def enable(
                 opt.register_transformation()
             else:
                 from .coders.pytorch.harness import Harness
+
                 opt = Harness(backend=feature)
                 opt.register_transformation()
 
@@ -361,26 +370,32 @@ def enable(
                     if "batch_size" in list_transformed_code[0]:  # entry code has "batch_size"
                         globals.batch_size_changed = True
                     from .coders.pytorch.batch_size import BatchSizeCoder
+
                     globals.target_batch_size = str(target_batch_size)
                     list_transformed_code[i] = BatchSizeCoder(list_transformed_code[i]).transform()
                 # CUDA to CPU
                 if "pytorch_cuda_to_cpu" in features:
                     from .coders.pytorch.cuda_to_cpu import CudaToCpu
+
                     list_transformed_code[i] = CudaToCpu(list_transformed_code[i]).transform()
                 # Lightning
                 if "pytorch_lightning_bf16_cpu" in features:
                     from .coders.pytorch.lightning import Lightning
+
                     list_transformed_code[i] = Lightning(list_transformed_code[i]).transform()
                 # TF & Keras AMP
                 if "tensorflow_mixed_precision" in features:
                     from .coders.tensorflow.amp import TensorFlowKerasAMP
+
                     list_transformed_code[i] = TensorFlowKerasAMP(list_transformed_code[i]).transform()
                 if feature == "tensorflow_inc":
                     from .coders.tensorflow.inc import TensorFlowKerasINC
+
                     list_transformed_code[i] = TensorFlowKerasINC(list_transformed_code[i]).transform()
                 # Change Trainer to NLPTrainer (only for intel_extension_for_pytorch)
                 if "change_trainer_to_nlptrainer" in features:
                     from .coders.pytorch.change_trainer_to_nlptrainer import TrainerToNLPTrainer
+
                     list_transformed_code[i] = TrainerToNLPTrainer(list_transformed_code[i]).transform()
 
         logger.info(f"Code transformation for feature: [{feature}] finished.")
@@ -404,6 +419,7 @@ def enable(
         globals.print_code_line_info = True
 
         from .utils import handle_user_input
+
         globals.list_code_path, num_user_code_path = handle_user_input.get_all_code_path(code)
         if len(transformed_list_code_path) > 0:
             globals.list_code_path = transformed_list_code_path
@@ -415,12 +431,12 @@ def enable(
         # by the order in code_path
 
         for i in globals.list_code_path:
-            list_transformed_code.append(open(i, 'r').read())
-        
+            list_transformed_code.append(open(i, "r").read())
+
+        from .coders.transform import execute_indent_transformation, execute_insert_transformation
         from .graphers.code_line import register_code_line
-        from .graphers.model import register_nnModule_class, register_nnModule_instance_definition
         from .graphers.function import register_func_wrap_pair
-        from .coders.transform import execute_insert_transformation, execute_indent_transformation
+        from .graphers.model import register_nnModule_class, register_nnModule_instance_definition
 
         # code analysis (call graph, type inference etc)
         register_code_line()
@@ -438,8 +454,7 @@ def enable(
             if path_transformed[-25:] == "_nc_enabled_nc_enabled.py":
                 continue
             cmd_gen_patch = "diff -up " + path + " " + path_transformed
-            sp_gen_patch = subprocess.Popen(
-                cmd_gen_patch, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
+            sp_gen_patch = subprocess.Popen(cmd_gen_patch, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
             sp_gen_patch.wait()
             this_patch, _ = sp_gen_patch.communicate()
             this_patch = str(this_patch)[2:-1]
@@ -447,14 +462,15 @@ def enable(
         if save_patch_path == "":
             save_patch_path = ws_path + "neural_coder_patch"
         open(save_patch_path + patch_suffix, "w").write(
-            whole_patch_user_code.replace(r'\n', '\n').replace(r'\t', '\t').replace(r"\'", "\'"))
-        abs_patch_path = os.path.abspath(
-            save_patch_path + patch_suffix)
+            whole_patch_user_code.replace(r"\n", "\n").replace(r"\t", "\t").replace(r"\'", "'")
+        )
+        abs_patch_path = os.path.abspath(save_patch_path + patch_suffix)
         logger.info(f"The patch is saved to: [{abs_patch_path}]")
 
         if overwrite:
             sp_overwrite = subprocess.Popen(
-                "patch -d/ -p0 < " + abs_patch_path, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
+                "patch -d/ -p0 < " + abs_patch_path, env=os.environ, shell=True, stdout=subprocess.PIPE
+            )  # nosec
             sp_overwrite.wait()
             # os.remove(abs_patch_path)  # remove patch after overwrite
 
@@ -464,7 +480,8 @@ def enable(
                 path_transformed = path[:-3] + "_nc_enabled.py"
                 cmd_gen_patch = "diff -up " + path + " " + path_transformed
                 sp_gen_patch = subprocess.Popen(
-                    cmd_gen_patch, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
+                    cmd_gen_patch, env=os.environ, shell=True, stdout=subprocess.PIPE
+                )  # nosec
                 sp_gen_patch.wait()
                 this_patch, _ = sp_gen_patch.communicate()
                 this_patch = str(this_patch)[2:-1]
@@ -472,11 +489,10 @@ def enable(
             if save_patch_path == "":
                 save_patch_path = ws_path + "neural_coder_patch_import_modules"
             open(save_patch_path + patch_suffix, "w").write(
-                whole_patch_import_modules.replace(r'\n', '\n').replace(r'\t', '\t').replace(r"\'", "\'"))
-            abs_patch_path = os.path.abspath(
-                save_patch_path + patch_suffix)
-            logger.info(
-                f"The patch for imported modules is saved to: [{abs_patch_path}]")
+                whole_patch_import_modules.replace(r"\n", "\n").replace(r"\t", "\t").replace(r"\'", "'")
+            )
+            abs_patch_path = os.path.abspath(save_patch_path + patch_suffix)
+            logger.info(f"The patch for imported modules is saved to: [{abs_patch_path}]")
 
     # remove copy for imports
     if remove_copy:
@@ -520,16 +536,15 @@ def bench(
     ninstances=-1,  # only for "self_defined" mode
     bench_batch_size=-1,  # only for "self_defined" mode
 ):
-    """benchmark on either "optimized code", or "patch" + "original code"
+    """Benchmark on either "optimized code", or "patch" + "original code"
     it does not enable benchmark code lines, or enable change of batch size
     all the enabling should be done within enable API
     which means the "optimized code" should already have
     "pytorch_benchmark" and "pytorch_change_batch_size" enabled
     or the "patch" should already have the code modification
-    for "pytorch_benchmark" and "pytorch_change_batch_size" in it
-    """
+    for "pytorch_benchmark" and "pytorch_change_batch_size" in it."""
     # set up workspace
-    ws_path = "neural_coder_workspace/" + "bench" + str(time.time()).replace(".","") + "/"
+    ws_path = "neural_coder_workspace/" + "bench" + str(time.time()).replace(".", "") + "/"
     os.makedirs(ws_path)
 
     # set up logging
@@ -538,10 +553,9 @@ def bench(
 
     logger = logging.getLogger(ws_path)
     logger.setLevel(globals.logging_level)
-    formatter = logging.Formatter(
-        '%(asctime)s - %(name)s - %(levelname)s: - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s: - %(message)s", datefmt="%Y-%m-%d %H:%M:%S")
 
-    fh = logging.FileHandler(ws_path + 'bench.log')
+    fh = logging.FileHandler(ws_path + "bench.log")
     fh.setLevel(globals.logging_level)
     fh.setFormatter(formatter)
     ch = logging.StreamHandler()
@@ -555,7 +569,7 @@ def bench(
     detect_device_(logger)
 
     # print key inputs
-    logger.info(f"Benchmarking started ...")
+    logger.info("Benchmarking started ...")
     logger.info(f"code: {code}")
     logger.info(f"mode: {mode}")
 
@@ -568,28 +582,29 @@ def bench(
         elif type(code) == str:
             entry_code = code
         else:
-            logger.error(
-                f"You have to specify an entry_code of your code: [{code}]")
+            logger.error(f"You have to specify an entry_code of your code: [{code}]")
             quit()
 
     # patch
     if patch_path != "":
         sp_patch = subprocess.Popen(
-            "patch -d/ -p0 < " + patch_path, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
+            "patch -d/ -p0 < " + patch_path, env=os.environ, shell=True, stdout=subprocess.PIPE
+        )  # nosec
         sp_patch.wait()
 
     # if mode is "self_defined", user must specify ncpi, nins and bs
     if mode == "self_defined":
         if ncore_per_instance == -1 or ninstances == -1 or bench_batch_size == -1:
             logger.error(
-                f"You have to specify ncore_per_instance,"
-                f"ninstances and bench_batch_size for self-defined benchmark mode.")
+                "You have to specify ncore_per_instance,"
+                "ninstances and bench_batch_size for self-defined benchmark mode."
+            )
             quit()
 
     # numactl
     from .utils import numa_launcher
-
     from .utils.cpu_info import get_num_cpu_cores
+
     ncores = get_num_cpu_cores()
 
     # numactl setup for different modes
@@ -612,38 +627,36 @@ def bench(
 
     # set cpu env variables
     if cpu_set_env:
-        cmd_env = ''
-        cmd_env += 'export LD_PRELOAD=${CONDA_PREFIX}/lib/libjemalloc.so'
-        cmd_env += ' && '
-        cmd_env += 'export LD_PRELOAD=${LD_PRELOAD}:${CONDA_PREFIX}/lib/libiomp5.so'
-        cmd_env += ' && '
+        cmd_env = ""
+        cmd_env += "export LD_PRELOAD=${CONDA_PREFIX}/lib/libjemalloc.so"
+        cmd_env += " && "
+        cmd_env += "export LD_PRELOAD=${LD_PRELOAD}:${CONDA_PREFIX}/lib/libiomp5.so"
+        cmd_env += " && "
         cmd_env += 'export MALLOC_CONF="oversize_threshold:1,background_thread:true,metadata_thp:auto,'
         cmd_env += 'dirty_decay_ms:9000000000,muzzy_decay_ms:9000000000"'
-        cmd_env += ' && '
+        cmd_env += " && "
         cmd_env += 'export KMP_AFFINITY="granularity=fine,compact,1,0"'
-        cmd_env += ' && '
-        cmd_env += 'export KMP_BLOCKTIME=1'
-        cmd_env += ' && '
-        cmd_env += 'export DNNL_PRIMITIVE_CACHE_CAPACITY=1024'
-        cmd_env += ' && '
-        cmd_env += 'export KMP_SETTINGS=1'
+        cmd_env += " && "
+        cmd_env += "export KMP_BLOCKTIME=1"
+        cmd_env += " && "
+        cmd_env += "export DNNL_PRIMITIVE_CACHE_CAPACITY=1024"
+        cmd_env += " && "
+        cmd_env += "export KMP_SETTINGS=1"
 
-        sp_set_env = subprocess.Popen(
-            cmd_env, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
+        sp_set_env = subprocess.Popen(cmd_env, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
         sp_set_env.wait()
 
     # benchmark
-    logger.info(f"Start benchmark on the code ...")
+    logger.info("Start benchmark on the code ...")
 
     bench_log_path = ws_path + "performance.log"
     os.remove(bench_log_path) if os.path.exists(bench_log_path) else 0
 
     args = [args]
-    numa_launcher.exec_launcher(
-        ncore_per_instance, ninstances, entry_code, args, bench_log_path)
+    numa_launcher.exec_launcher(ncore_per_instance, ninstances, entry_code, args, bench_log_path)
 
     # get performance (throughput and latency)
-    bench_log = open(bench_log_path, "r", encoding='unicode_escape').read().split('\n')
+    bench_log = open(bench_log_path, "r", encoding="unicode_escape").read().split("\n")
     IPS = []
     MSPI = 0
     count_MSPI = 0
@@ -657,30 +670,30 @@ def bench(
     for line in bench_log:
         if "Neural_Coder_Bench_IPS" in line:
             try:
-                IPS.append(float(line[line.find(":")+3:]))
+                IPS.append(float(line[line.find(":") + 3 :]))
             except ValueError as ve:
                 pass
         if "Neural_Coder_Bench_MSPI" in line:
             try:
-                MSPI += float(line[line.find(":")+3:])
+                MSPI += float(line[line.find(":") + 3 :])
                 count_MSPI += 1
             except ValueError as ve:
                 pass
         if "Neural_Coder_Bench_P50" in line:
             try:
-                P50 += float(line[line.find(":")+3:])
+                P50 += float(line[line.find(":") + 3 :])
                 count_P50 += 1
             except ValueError as ve:
                 pass
         if "Neural_Coder_Bench_P90" in line:
             try:
-                P90 += float(line[line.find(":")+3:])
+                P90 += float(line[line.find(":") + 3 :])
                 count_P90 += 1
             except ValueError as ve:
                 pass
         if "Neural_Coder_Bench_P99" in line:
             try:
-                P99 += float(line[line.find(":")+3:])
+                P99 += float(line[line.find(":") + 3 :])
                 count_P99 += 1
             except ValueError as ve:
                 pass
@@ -688,7 +701,7 @@ def bench(
             try:
                 acc_int8 = float(re.search(r"\d+\.\d+", line).group())
                 acc_fp32 = float(re.search(r"(?<=\|)\d+\.\d+", line).group())
-                acc_delta = round((acc_int8 - acc_fp32) / acc_fp32 * 100, 2) # percent of increase/decrease
+                acc_delta = round((acc_int8 - acc_fp32) / acc_fp32 * 100, 2)  # percent of increase/decrease
             except ValueError as ve:
                 pass
 
@@ -698,7 +711,7 @@ def bench(
         IPS[-1] = IPS[-2]
 
     try:
-        if globals.batch_size_changed: # only times BS if BS has been modified, otherwise times 1
+        if globals.batch_size_changed:  # only times BS if BS has been modified, otherwise times 1
             FPS = round(sum(IPS) / len(IPS) * ninstances * bench_batch_size, 3)
         else:
             FPS = round(sum(IPS) / len(IPS) * ninstances * 1, 3)
@@ -731,7 +744,8 @@ def bench(
     # unpatch
     if patch_path != "":
         sp_unpatch = subprocess.Popen(
-            "patch -R -d/ -p0 < " + patch_path, env=os.environ, shell=True, stdout=subprocess.PIPE)  # nosec
+            "patch -R -d/ -p0 < " + patch_path, env=os.environ, shell=True, stdout=subprocess.PIPE
+        )  # nosec
         sp_unpatch.wait()
 
     return [FPS, MSPI, P50, P90, P99, acc_delta], mode, os.path.abspath(ws_path)
@@ -755,10 +769,8 @@ def superbench(
     use_inc=True,
     auto_quant=False,
 ):
-
     # set up workspace
-    ws_path = "neural_coder_workspace/" + \
-        "superbench" + str(time.time()).replace(".","") + "/"
+    ws_path = "neural_coder_workspace/" + "superbench" + str(time.time()).replace(".", "") + "/"
     os.makedirs(ws_path)
 
     # set up logging
@@ -767,10 +779,9 @@ def superbench(
 
     logger = logging.getLogger(ws_path)
     logger.setLevel(globals.logging_level)
-    formatter = logging.Formatter(
-        '%(asctime)s - %(name)s - %(levelname)s: - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s: - %(message)s", datefmt="%Y-%m-%d %H:%M:%S")
 
-    fh = logging.FileHandler(ws_path+'superbench.log')
+    fh = logging.FileHandler(ws_path + "superbench.log")
     fh.setLevel(globals.logging_level)
     fh.setFormatter(formatter)
     ch = logging.StreamHandler()
@@ -785,12 +796,12 @@ def superbench(
 
     # print key inputs
     if auto_quant:
-        logger.info(f"Auto-Quant started ...")
+        logger.info("Auto-Quant started ...")
         logger.info(f"Code: {code}")
         logger.info(f"Benchmark Mode: {mode} mode")
         logger.debug(f"Number of benchmark iterations: {num_benchmark_iteration}")
     else:
-        logger.info(f"SuperBench started ...")
+        logger.info("SuperBench started ...")
         logger.info(f"Code: {code}")
         logger.info(f"Benchmark Mode: {mode} mode")
         logger.debug(f"Sweep Objective: {sweep_objective}")
@@ -806,12 +817,12 @@ def superbench(
         elif type(code) == str:
             entry_code = code
         else:
-            logger.error(
-                f"You have to specify an entry_code of your code: [{code}]")
+            logger.error(f"You have to specify an entry_code of your code: [{code}]")
             quit()
 
     # detect device compatibility of entry code
     from .utils.device import detect_code_device_compatibility
+
     detect_code_device_compatibility(entry_code)
 
     if sweep_objective == "feature":
@@ -859,6 +870,7 @@ def superbench(
         standalones = []
         standalones.append("")
         from itertools import combinations
+
         for num_items in range(len(standalones_pool)):
             list_comb = list(combinations(standalones_pool, num_items + 1))
             for item in list_comb:
@@ -927,7 +939,8 @@ def superbench(
                     if iteration_dynamic_adjust:
                         num_benchmark_iteration = max(int(300 / (t_end - t_start)), 5)
                         logger.debug(
-                            f"Adjusted number of benchmark iterations after dry-run is {num_benchmark_iteration}")
+                            f"Adjusted number of benchmark iterations after dry-run is {num_benchmark_iteration}"
+                        )
                     dry_run = False
 
                 def remove_if_have(list, element):
@@ -941,29 +954,30 @@ def superbench(
 
                 if auto_quant:
                     # convert feature name to display name for better user experience
-                    if features == ['pytorch_inc_dynamic_quant']:
+                    if features == ["pytorch_inc_dynamic_quant"]:
                         features_display = "Intel INT8 (Dynamic)"
-                    elif features == ['pytorch_inc_static_quant_fx']:
+                    elif features == ["pytorch_inc_static_quant_fx"]:
                         features_display = "Intel INT8 (Static)"
-                    elif features == ['pytorch_inc_static_quant_ipex']:
+                    elif features == ["pytorch_inc_static_quant_ipex"]:
                         features_display = "Intel INT8 (IPEX)"
-                    elif features == ['pytorch_inc_bf16']:
+                    elif features == ["pytorch_inc_bf16"]:
                         features_display = "Intel BF16"
                     elif features == []:
                         features_display = "The Original Model"
 
                     logger.info(
-                        f"Benchmark result (performance) of {features_display}"
-                        f" is {bench_performance[0]} (FPS)")
-                    logger.info(
-                        f"Benchmark result (accuracy delta) of {features_display} is {bench_performance[5]} %")
+                        f"Benchmark result (performance) of {features_display}" f" is {bench_performance[0]} (FPS)"
+                    )
+                    logger.info(f"Benchmark result (accuracy delta) of {features_display} is {bench_performance[5]} %")
                 else:
                     logger.info(
                         f"Benchmark result (performance) of optimization set [{features}]"
-                        f" is [{bench_performance[0]}] (FPS)")
+                        f" is [{bench_performance[0]}] (FPS)"
+                    )
                     logger.info(
                         f"Benchmark result (accuracy delta) of optimization set [{features}]"
-                        f" is [{bench_performance[5]}] %")
+                        f" is [{bench_performance[5]}] %"
+                    )
 
                 d = {}  # initialize dict
                 d["features"] = features
@@ -981,8 +995,11 @@ def superbench(
 
         # print result
         print(f"Superbench result of sweeping [{sweep_objective}] printed below with sorted FPS: ")
-        print("{:<20} {:<20} {:<20} {:<120}".format(
-            'Numactl Mode', 'Performance (FPS)', 'Accuracy Delta (%)', 'Features Applied'))
+        print(
+            "{:<20} {:<20} {:<20} {:<120}".format(
+                "Numactl Mode", "Performance (FPS)", "Accuracy Delta (%)", "Features Applied"
+            )
+        )
 
         sort_index = sorted(
             range(len(list_FPS)),
@@ -1021,16 +1038,16 @@ def superbench(
                 if list_features[i] == []:
                     original_model_performance = list_FPS[i]
                     break
-        
+
         if auto_quant:
             # convert feature name to display name for better user experience
-            if list_optimization_set_top3[0] == ['pytorch_inc_dynamic_quant']:
+            if list_optimization_set_top3[0] == ["pytorch_inc_dynamic_quant"]:
                 best_optimization_display = "Intel INT8 (Dynamic)"
-            elif list_optimization_set_top3[0] == ['pytorch_inc_static_quant_fx']:
+            elif list_optimization_set_top3[0] == ["pytorch_inc_static_quant_fx"]:
                 best_optimization_display = "Intel INT8 (Static)"
-            elif list_optimization_set_top3[0] == ['pytorch_inc_static_quant_ipex']:
+            elif list_optimization_set_top3[0] == ["pytorch_inc_static_quant_ipex"]:
                 best_optimization_display = "Intel INT8 (IPEX)"
-            elif list_optimization_set_top3[0] == ['pytorch_inc_bf16']:
+            elif list_optimization_set_top3[0] == ["pytorch_inc_bf16"]:
                 best_optimization_display = "Intel BF16"
             elif list_optimization_set_top3[0] == []:
                 best_optimization_display = "The Original Model"
@@ -1072,11 +1089,13 @@ def superbench(
         result_p99_thp = []
         if bench_feature == []:
             logger.error(
-                f'You must specify a feature (optimization set) '
-                f'for benchmark when "sweep_objective" is "bench_config"')
+                "You must specify a feature (optimization set) "
+                'for benchmark when "sweep_objective" is "bench_config"'
+            )
             quit()
         else:
             from .utils.cpu_info import get_num_cpu_cores
+
             ncores = get_num_cpu_cores()
             list_ncpi = [1, 2, 4, 8]
             for i in [1, 2, 4, 8]:
@@ -1089,8 +1108,19 @@ def superbench(
             for this_ncpi in list_ncpi:
                 ncore_per_instance = this_ncpi
                 ninstances = int(ncores / this_ncpi)
-                list_bs = [1, 2, 4, 8, this_ncpi * 1, this_ncpi * 2, this_ncpi *
-                           4, this_ncpi * 8, this_ncpi * 16, this_ncpi * 32, this_ncpi * 64]
+                list_bs = [
+                    1,
+                    2,
+                    4,
+                    8,
+                    this_ncpi * 1,
+                    this_ncpi * 2,
+                    this_ncpi * 4,
+                    this_ncpi * 8,
+                    this_ncpi * 16,
+                    this_ncpi * 32,
+                    this_ncpi * 64,
+                ]
                 list_bs = list(set(list_bs))
                 list_bs.sort()
                 if logging_level == "debug":
@@ -1100,7 +1130,6 @@ def superbench(
                 for this_bs in list_bs:
                     bench_batch_size = this_bs
                     try:
-
                         if dry_run:
                             t_start = time.time()
 
@@ -1125,16 +1154,14 @@ def superbench(
                                 num_benchmark_iteration = max(int(300 / (t_end - t_start)), 5)
                                 logger.debug(
                                     f"Adjusted number of benchmark iterations after dry-run is "
-                                    f"{num_benchmark_iteration}")
+                                    f"{num_benchmark_iteration}"
+                                )
                             dry_run = False
 
                         socket_regular_thp = bench_performance[0]
-                        socket_p50_thp = round(
-                            1000 / bench_performance[2] * ninstances * bench_batch_size, 3)
-                        socket_p90_thp = round(
-                            1000 / bench_performance[3] * ninstances * bench_batch_size, 3)
-                        socket_p99_thp = round(
-                            1000 / bench_performance[4] * ninstances * bench_batch_size, 3)
+                        socket_p50_thp = round(1000 / bench_performance[2] * ninstances * bench_batch_size, 3)
+                        socket_p90_thp = round(1000 / bench_performance[3] * ninstances * bench_batch_size, 3)
+                        socket_p99_thp = round(1000 / bench_performance[4] * ninstances * bench_batch_size, 3)
 
                         result_ncpi.append(ncore_per_instance)
                         result_nins.append(ninstances)
@@ -1168,21 +1195,25 @@ def superbench(
             elif item is result_p99_thp:
                 display_item_name = "Throughput based on P99-Latency"
 
-            print("{:<30} {:<30} {:<30} {:<30}".format(
-                'Num Cores Per Instance', 'Num of Instances', 'Batch Size', display_item_name))
-            sort_index = sorted(
-                range(len(item)), key=lambda k: item[k], reverse=True)
+            print(
+                "{:<30} {:<30} {:<30} {:<30}".format(
+                    "Num Cores Per Instance", "Num of Instances", "Batch Size", display_item_name
+                )
+            )
+            sort_index = sorted(range(len(item)), key=lambda k: item[k], reverse=True)
             for i in sort_index:
-                print("{:<30} {:<30} {:<30} {:<30}".format(str(result_ncpi[i]), str(
-                    result_nins[i]), str(result_bs[i]), str(item[i])))
+                print(
+                    "{:<30} {:<30} {:<30} {:<30}".format(
+                        str(result_ncpi[i]), str(result_nins[i]), str(result_bs[i]), str(item[i])
+                    )
+                )
 
         list_config_best_ncpi = []
         list_config_best_nins = []
         list_config_best_bs = []
         list_config_best_performance = []
         for item in [result_regular_thp, result_p50_thp, result_p90_thp, result_p99_thp]:
-            sort_index = sorted(
-                range(len(item)), key=lambda k: item[k], reverse=True)
+            sort_index = sorted(range(len(item)), key=lambda k: item[k], reverse=True)
             for i in sort_index:
                 list_config_best_ncpi.append(result_ncpi[i])
                 list_config_best_nins.append(result_nins[i])
@@ -1224,13 +1255,13 @@ def superbench(
 #         # pricing: https://aws.amazon.com/ec2/pricing/on-demand/
 #         import subprocess
 #         res = subprocess.Popen(
-#             "grep 'DMI' /var/log/dmesg", 
-#             shell=True,                  
-#             stdout=subprocess.PIPE,      
-#             stderr=subprocess.PIPE,      
+#             "grep 'DMI' /var/log/dmesg",
+#             shell=True,
+#             stdout=subprocess.PIPE,
+#             stderr=subprocess.PIPE,
 #         )
 #         res.wait()
-#         result = res.stdout.read()       
+#         result = res.stdout.read()
 #         result = str(result, encoding="utf-8")
 #         cloud_vendor = result.split()[4] + ' ' + result.split()[5]
 #         if cloud_vendor == 'Amazon EC2':
@@ -1250,7 +1281,7 @@ def superbench(
 #         cloud_vendor="Intel internal machine"
 #         cloud_instance_type=bare_metal_machine_type
 #         cloud_unit_price="1"
-            
+
 #     report = PDFReport(
 #         path=save_path,
 #         list_optimization_set_top3=res1,
