@@ -18,3 +18,10 @@ def move_element_to_front(list, element):
         idx = list.index(element)
         list.insert(0, list.pop(idx))
     return list
+
+
+def move_element_to_last(list, element):
+    if element in list:
+        idx = list.index(element)
+        list.insert(len(list), list.pop(idx))
+    return list
