@@ -14,16 +14,19 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Intel® Neural Compressor: An open-source Python library supporting popular model compression techniques."""
-from .benchmark import _Benchmark
 from .version import __version__
-from .contrib import *
+
 # we need to set a global 'NA' backend, or Model can't be used
-from .utils.utility import set_random_seed, set_tensorboard, set_workspace
+from .config import (
+    DistillationConfig,
+    PostTrainingQuantConfig,
+    WeightPruningConfig,
+    QuantizationAwareTrainingConfig,
+    MixedPrecisionConfig,
+)
+from .contrib import *
+from .model import *
+from .metric import *
 from .utils import options
-from .conf.config import conf
-from .conf.pythonic_config import config
-from .config import DistillationConfig, PostTrainingQuantConfig, \
-                    WeightPruningConfig, QuantizationAwareTrainingConfig, \
-                    MixedPrecisionConfig
+from .utils.utility import set_random_seed, set_tensorboard, set_workspace, set_resume_from
