@@ -1,4 +1,4 @@
-"""mxnet util init."""
+"""Mxnet util init."""
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
@@ -15,4 +15,3 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
