@@ -16,7 +16,8 @@
 # limitations under the License.
 """MaxPool Operator."""
 
-from neural_compressor.adaptor.ox_utils.operators.ops import op_registry, Operator, QOperator, qop_registry
+from neural_compressor.adaptor.ox_utils.operators.ops import Operator, QOperator, op_registry, qop_registry
+
 
 @op_registry(op_types="MaxPool")
 class MaxPoolOperator(Operator):
@@ -25,35 +26,34 @@ class MaxPoolOperator(Operator):
     def __init__(self, onnx_quantizer, onnx_node):
         """Initialization."""
         super(MaxPoolOperator, self).__init__(onnx_quantizer, onnx_node)
-    
+
     def quantize_check(self):
         """Check if quantizaion can be done."""
         node = self.node
         # if opset version is less than 12, just no change
-        if self.quantizer.opset_version < 12: # pragma: no cover
+        if self.quantizer.opset_version < 12:  # pragma: no cover
             return False
 
-        if not self.quantizer.is_valid_quantize_weight(node.input[0]): # pragma: no cover
+        if not self.quantizer.is_valid_quantize_weight(node.input[0]):  # pragma: no cover
             return False
-            
+
         return True
 
     def quantize(self):
         """Do quantizaion."""
         node = self.node
         self.quantizer.quantize_inputs(self.node, direct_int8=True)
-        if not self.disable_qdq_for_node_output or self.quantizer.mode != 'qdq':
+        if not self.disable_qdq_for_node_output or self.quantizer.mode != "qdq":
             self.quantizer.quantize_outputs(self.node, direct_int8=True)
         node.name = node.name + "_quant"
 
     def convert_check(self, convert_format):
         """Check if conversion can be done."""
         node = self.node
-        assert convert_format in ['static'], \
-            "convert format for {} should be in ['static']".format(node.op_type)
+        assert convert_format in ["static"], "convert format for {} should be in ['static']".format(node.op_type)
 
         children = self.quantizer.model.get_children(node)
-        if len(children) == 0 or not node.name.endswith('_quant'): # pragma: no cover
+        if len(children) == 0 or not node.name.endswith("_quant"):  # pragma: no cover
             return False
         return True
 
@@ -62,24 +62,25 @@ class MaxPoolOperator(Operator):
         node = self.node
         parent = self.quantizer.model.get_parents(node)[0]
         children = self.quantizer.model.get_children(node)
-        if parent.op_type != 'DequantizeLinear' or \
-            all([i.op_type != 'QuantizeLinear' for i in children]): # pragma: no cover
+        if parent.op_type != "DequantizeLinear" or all(
+            [i.op_type != "QuantizeLinear" for i in children]
+        ):  # pragma: no cover
             return
         node.input[0] = parent.input[0]
-        node.output[0] = node.output[0] + '_quantized'
+        node.output[0] = node.output[0].replace("_QuantizeInput", "_quantized")
         for child in children:
-            if child.op_type == 'QuantizeLinear':
+            if child.op_type == "QuantizeLinear":
                 self.quantizer.remove_nodes.append(child)
                 for n in self.quantizer.model.get_children(child):
-                    self.quantizer.model.replace_node_input(n,
-                                    child.output[0], node.output[0])
+                    self.quantizer.model.replace_node_input(n, child.output[0], node.output[0])
 
         self.quantizer.remove_nodes.append(parent)
 
+
 @qop_registry(op_types="MaxPool")
 class QMaxPoolOperator(QOperator):
     """QMaxPool Operator."""
 
     def __init__(self, onnx_node, children, initializers):
         """Initialization."""
-        super().__init__(onnx_node, children, initializers)
\ No newline at end of file
+        super().__init__(onnx_node, children, initializers)
