@@ -17,15 +17,19 @@
 """ExpandDims Graph Rewriter."""
 
 
-from ..graph_base import GraphRewriterBase
+import numpy as np
+from tensorflow.python.framework import dtypes
+
 from neural_compressor.adaptor.tf_utils.graph_util import GraphAnalyzer
 from neural_compressor.adaptor.tf_utils.graph_util import GraphRewriterHelper as Helper
 from neural_compressor.utils.utility import dump_elapsed_time
-from tensorflow.python.framework import dtypes
-import numpy as np
+
+from ..graph_base import GraphRewriterBase
+
 
 class ExpandDimsOptimizer(GraphRewriterBase):
     """Calculate ExpandDims and remove it if its input is weight and next node is Conv2D."""
+
     @dump_elapsed_time("Pass ExpandDimsOptimizer")
     def do_transformation(self):
         """Handle all ExpandDims ops whose input is weight and output is Conv2D.
@@ -44,15 +48,15 @@ class ExpandDimsOptimizer(GraphRewriterBase):
 
         for node_combination in target_nodes:
             expanddims_node = graph_info[node_combination[0]].node
-            dims_node =  graph_info[expanddims_node.input[1]].node
-            next_node =  graph_info[graph_info[node_combination[0]].outputs[0]].node
+            dims_node = graph_info[expanddims_node.input[1]].node
+            next_node = graph_info[graph_info[node_combination[0]].outputs[0]].node
             # to solve the case that input 0 of ExpandDims is a tensor, not a node
             if expanddims_node.input[0] in graph_info:
-                weight_node =  graph_info[expanddims_node.input[0]].node
+                weight_node = graph_info[expanddims_node.input[0]].node
             else:
                 continue
 
-            if weight_node.op == 'Const' and next_node.op == 'Conv2D':
+            if weight_node.op == "Const" and next_node.op == "Conv2D":
                 dims = Helper.values_from_const(dims_node)
                 weight_value = np.array(Helper.values_from_const(weight_node))
                 new_weight_value = np.expand_dims(weight_value, axis=dims)
@@ -66,9 +70,9 @@ class ExpandDimsOptimizer(GraphRewriterBase):
                         if value == expanddims_node.name:
                             replace_index = index
                             break
-                    # weight->conv2d 
+                    # weight->conv2d
                     cur_graph.add_node(new_weight_node, None, [successor_node.name])
-                    successor_node.input[replace_index] = new_weight_node.name 
+                    successor_node.input[replace_index] = new_weight_node.name
                 # remove ExpandDims and weight_node
                 cur_graph.remove_node(expanddims_node.name)
             else:
