@@ -17,11 +17,12 @@
 """Fuse BiasAdd and Add Graph Rewriter."""
 
 import tensorflow as tf
-from ..graph_base import GraphRewriterBase
+from tensorflow.python.framework import dtypes, tensor_util
+
 from neural_compressor.adaptor.tf_utils.graph_util import GraphAnalyzer
 from neural_compressor.adaptor.tf_utils.graph_util import GraphRewriterHelper as Helper
-from tensorflow.python.framework import dtypes
-from tensorflow.python.framework import tensor_util
+
+from ..graph_base import GraphRewriterBase
 
 
 class FuseBiasAddAndAddOptimizer(GraphRewriterBase):
@@ -35,7 +36,8 @@ class FuseBiasAddAndAddOptimizer(GraphRewriterBase):
         graph_info = cur_graph.parse_graph()
 
         target_nodes = cur_graph.query_fusion_pattern_nodes(
-            [["Conv2D", "Conv3D"], "BiasAdd", ["Add", "AddV2"], ["Relu", "Relu6", "swish_f32"], ["Mul"], ["Mul"]])
+            [["Conv2D", "Conv3D"], "BiasAdd", ["Add", "AddV2"], ["Relu", "Relu6", "swish_f32"], ["Mul"], ["Mul"]]
+        )
 
         for i in target_nodes:
             biasadd_const_name = graph_info[i[1]].node.input[1]
@@ -53,19 +55,16 @@ class FuseBiasAddAndAddOptimizer(GraphRewriterBase):
 
             add_const_node = graph_info[add_node_const_name].node
 
-            if add_const_node.op != 'Const':
+            if add_const_node.op != "Const":
                 continue
-            value= tensor_util.MakeNdarray(
-                                biasadd_const_node.attr['value'].tensor)
-            add_value =  tensor_util.MakeNdarray(
-                                add_const_node.attr['value'].tensor)
+            value = tensor_util.MakeNdarray(biasadd_const_node.attr["value"].tensor)
+            add_value = tensor_util.MakeNdarray(add_const_node.attr["value"].tensor)
 
-            new_bias_tensor = (value+add_value)
-            fused_const_node = Helper.create_constant_node(
-                        i[2]+'_fused', new_bias_tensor, dtypes.float32)
+            new_bias_tensor = value + add_value
+            fused_const_node = Helper.create_constant_node(i[2] + "_fused", new_bias_tensor, dtypes.float32)
             cur_graph.remove_node(graph_info[i[1]].node.input[1])
 
-            graph_info[i[1]].node.input[1] = i[2] + '_fused'
+            graph_info[i[1]].node.input[1] = i[2] + "_fused"
 
             cur_graph.remove_node(add_node_const_name)
 
