@@ -21,11 +21,13 @@ import logging
 global_config = {}
 logger = logging.getLogger("neural_compressor")
 
-class QuantizeConfig():
+
+class QuantizeConfig:
     """Class for building custom quantize config.
 
     There should be only one QuantizeConfig instance for global setting.
     """
+
     def __new__(cls):
         """Created a QuantizeConfig instance and add it to the global_config dict.
 
@@ -33,7 +35,7 @@ class QuantizeConfig():
             instance (QuantizeConfig) : The created QuantizeConfig instance.
         """
         instance = super().__new__(cls)
-        global_config['quantize_config'] = instance
+        global_config["quantize_config"] = instance
         return instance
 
     def __init__(self):
@@ -41,13 +43,13 @@ class QuantizeConfig():
         self.quantize_recipe = {}
         self.model_name = None
 
-    def add_quantize_recipe(self, quantize_recipe):   # pragma: no cover
+    def add_quantize_recipe(self, quantize_recipe):  # pragma: no cover
         """Add custom recipe for quantization to the QuantizeConfig instance.
 
         Args:
             quantize_recipe (dict): A dict that decide whether given layers should be quantized.
                                     A typical quantize_recipe will be a dict of layer_name and
-                                    dict as key-value pairs. In each value dict, there should be 
+                                    dict as key-value pairs. In each value dict, there should be
                                     a {'quantize': bool} key-value pair and a {'index': list} pair.
                                     The latter one is used to decide which inputs should be quantized
                                     in some layers with multiple inputs.
@@ -56,7 +58,7 @@ class QuantizeConfig():
                                          'conv5_block3_3_add' : {'quantize': True, 'index': [1, 3]}
                                         }
         """
-        self.quantize_recipe.update(quantize_recipe)                    
+        self.quantize_recipe.update(quantize_recipe)
 
     def query_layer(self, layer_name):
         """Query if a specific layer is in the quantize_recipe dict.
@@ -71,7 +73,7 @@ class QuantizeConfig():
             return self.quantize_recipe[layer_name]
         return {}
 
-    def remove_layer(self, layer_name):   # pragma: no cover
+    def remove_layer(self, layer_name):  # pragma: no cover
         """Remove a specific layer from the quantize_recipe dict.
 
         Args:
@@ -80,7 +82,7 @@ class QuantizeConfig():
         if layer_name in self.quantize_recipe:
             del self.quantize_recipe[layer_name]
 
-    def remove_layers(self, layer_names):   # pragma: no cover
+    def remove_layers(self, layer_names):  # pragma: no cover
         """Remove a batch of layers from the quantize_recipe dict.
 
         Args:
@@ -89,7 +91,7 @@ class QuantizeConfig():
         for layer_name in layer_names:
             self.remove_layer(layer_name)
 
-    def get_quantize_recipe(self):   # pragma: no cover
+    def get_quantize_recipe(self):  # pragma: no cover
         """Get the current recipe dict for quantization.
 
         Returns:
@@ -97,7 +99,7 @@ class QuantizeConfig():
         """
         return self.quantize_recipe
 
-    def is_empty(self):   # pragma: no cover
+    def is_empty(self):  # pragma: no cover
         """Check if the recipe of quantization is an empty dict.
 
         Returns:
@@ -107,15 +109,21 @@ class QuantizeConfig():
             return False
         return True
 
-    def clear_quantize_recipe(self):   # pragma: no cover
+    def clear_quantize_recipe(self):  # pragma: no cover
         """Clear recipe of quantization to be an empty dict."""
         self.quantize_recipe.clear()
 
-layer_wise_config = {
-    'quantize_layers': {'Conv2D', 'Dense', 'DepthwiseConv2D', 'MaxPooling2D',  
-                        'AveragePooling2D', 'GlobalAveragePooling2D'},
-    'possible_quantize_layers': {'Multiply', 'Concatenate', 'Add', 'BatchNormalization'},
-    'weighted_layers': {'Conv2D', 'Dense', 'DepthwiseConv2D'},
-    'multiple_inputs_layers': {'Multiply', 'Concatenate', 'Add'}
-}
 
+layer_wise_config = {
+    "quantize_layers": {
+        "Conv2D",
+        "Dense",
+        "DepthwiseConv2D",
+        "MaxPooling2D",
+        "AveragePooling2D",
+        "GlobalAveragePooling2D",
+    },
+    "possible_quantize_layers": {"Multiply", "Concatenate", "Add", "BatchNormalization"},
+    "weighted_layers": {"Conv2D", "Dense", "DepthwiseConv2D"},
+    "multiple_inputs_layers": {"Multiply", "Concatenate", "Add"},
+}
