@@ -16,32 +16,31 @@
 # limitations under the License.
 """Quantize Conv2DBackpropInput and Conv3DBackpropInputV2."""
 
+import numpy as np
 import tensorflow as tf
-from tensorflow.core.framework import graph_pb2
-from tensorflow.core.framework import node_def_pb2
-from tensorflow.python.framework import dtypes
-from tensorflow.python.framework import tensor_util
+from tensorflow.core.framework import graph_pb2, node_def_pb2
+from tensorflow.python.framework import dtypes, tensor_util
 
 from neural_compressor.adaptor.tf_utils.quantize_graph_common import QuantizeGraphHelper as helper
+
 from ..quantize_graph_base import QuantizeNodeBase
-import numpy as np
+
 
 class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
     """Quantize Conv2DBackpropInput and Conv3DBackpropInputV2 and apply the fusion."""
+
     exclude_deconv_nodes = []
 
     def __init__(self, **kwargs):
-        """Initilization."""
+        """Initialization."""
         super().__init__(**kwargs)
-        self.sorted_patterns = sorted(self.patterns,
-                                      key=lambda i: len(i),
-                                      reverse=True)
+        self.sorted_patterns = sorted(self.patterns, key=lambda i: len(i), reverse=True)
         if self.new_api:
             self.fusion_mapping = {
-                'DequantizeConv2DBackpropInputQuantizeV2': self.apply_single_deconv2d_fusion,
-                'DequantizeConv2DBackpropInputBiasAddQuantizeV2': self.apply_deconv2d_biasadd_fusion,
-                'DequantizeConv3DBackpropInputV2QuantizeV2': self.apply_single_deconv3d_fusion,
-                'DequantizeConv3DBackpropInputV2BiasAddQuantizeV2': self.apply_deconv3d_biasadd_fusion
+                "DequantizeConv2DBackpropInputQuantizeV2": self.apply_single_deconv2d_fusion,
+                "DequantizeConv2DBackpropInputBiasAddQuantizeV2": self.apply_deconv2d_biasadd_fusion,
+                "DequantizeConv3DBackpropInputV2QuantizeV2": self.apply_single_deconv3d_fusion,
+                "DequantizeConv3DBackpropInputV2BiasAddQuantizeV2": self.apply_deconv3d_biasadd_fusion,
             }
 
     def apply_single_deconv2d_fusion(self, match_node_name):
@@ -61,9 +60,9 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
         weights_min_name = weights_name[1]
         weights_max_name = weights_name[2]
 
-        q_weights_name, q_weights_min_name, q_weights_max_name = \
-            self._intel_cpu_quantize_weight_eightbit(
-                matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel)
+        q_weights_name, q_weights_min_name, q_weights_max_name = self._intel_cpu_quantize_weight_eightbit(
+            matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel
+        )
 
         all_input_names = [normal_inputs[0]] + [q_weights_name] + q_inputs[:1]
         all_input_names.append(q_weights_min_name)
@@ -84,46 +83,50 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
 
                 quantized_node_name = node.name + "_eightbit_quantized_deconv"
 
-                quantized_node_input_names = all_input_names[:2] + \
-                    all_input_names[2:] + control_inputs
+                quantized_node_input_names = all_input_names[:2] + all_input_names[2:] + control_inputs
 
                 node_op = "_FusedQuantizedDeconv2D"
-                quantized_deconv_node = helper.create_node(node_op, quantized_node_name,
-                    quantized_node_input_names)
+                quantized_deconv_node = helper.create_node(node_op, quantized_node_name, quantized_node_input_names)
 
                 helper.copy_attr(quantized_deconv_node, "strides", node.attr["strides"])
                 helper.copy_attr(quantized_deconv_node, "padding", node.attr["padding"])
                 helper.copy_attr(quantized_deconv_node, "data_format", node.attr["data_format"])
                 if "explicit_paddings" in node.attr:
-                    helper.copy_attr(quantized_deconv_node, "explicit_paddings",
-                    node.attr["explicit_paddings"])
+                    helper.copy_attr(quantized_deconv_node, "explicit_paddings", node.attr["explicit_paddings"])
                 helper.copy_attr(quantized_deconv_node, "dilations", node.attr["dilations"])
                 input_data_type = dtypes.quint8 if self._find_relu_node(node) else dtypes.qint8
                 helper.set_attr_dtype(quantized_deconv_node, "Tinput", input_data_type)
-                helper.set_attr_dtype(quantized_deconv_node, "Tfilter",dtypes.qint8)
+                helper.set_attr_dtype(quantized_deconv_node, "Tfilter", dtypes.qint8)
                 # helper.set_attr_string(quantized_conv_node, '_kernel', b'QuantizedMklOp')
                 helper.set_attr_dtype(quantized_deconv_node, "out_type", dtypes.qint32)
                 # helper.set_attr_dtype(quantized_conv_node, "alpha", dtypes.quint8)
 
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_inputs', [
-                    dtypes.int32.as_datatype_enum,
-                    dtypes.qint8.as_datatype_enum,
-                    input_data_type.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                 ])
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_outputs', [
-                                          dtypes.qint32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum, ])
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_inputs",
+                    [
+                        dtypes.int32.as_datatype_enum,
+                        dtypes.qint8.as_datatype_enum,
+                        input_data_type.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_outputs",
+                    [
+                        dtypes.qint32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
 
                 self.add_output_graph_node(quantized_deconv_node)
-                quantize_down_name = self._add_quantize_down_nodes(
-                    node, quantized_node_name, dtypes.qint8, False)
-                self._intel_cpu_add_dequantize_result_node(
-                    quantize_down_name, match_node_name[1], dtypes.qint8)
+                quantize_down_name = self._add_quantize_down_nodes(node, quantized_node_name, dtypes.qint8, False)
+                self._intel_cpu_add_dequantize_result_node(quantize_down_name, match_node_name[1], dtypes.qint8)
 
             else:
                 new_node = node_def_pb2.NodeDef()
@@ -161,9 +164,9 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
         weights_min_name = weights_name[1]
         weights_max_name = weights_name[2]
 
-        q_weights_name, q_weights_min_name, q_weights_max_name = \
-            self._intel_cpu_quantize_weight_eightbit(
-                matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel)
+        q_weights_name, q_weights_min_name, q_weights_max_name = self._intel_cpu_quantize_weight_eightbit(
+            matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel
+        )
 
         all_input_names = [normal_inputs[0]] + [q_weights_name] + q_inputs[:1]
         all_input_names.append(q_weights_min_name)
@@ -185,50 +188,56 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
                 quantized_node_name = node.name + "_eightbit_quantized_deconv"
 
                 bias_node_name = self.node_name_mapping[match_node_name[2]].node.input[1]
-                quantized_node_input_names = all_input_names[:3] + \
-                    [bias_node_name] + all_input_names[3:] + control_inputs
+                quantized_node_input_names = (
+                    all_input_names[:3] + [bias_node_name] + all_input_names[3:] + control_inputs
+                )
 
                 node_op = "_FusedQuantizedDeconv2D"
-                quantized_deconv_node = helper.create_node(node_op, quantized_node_name,
-                    quantized_node_input_names)
+                quantized_deconv_node = helper.create_node(node_op, quantized_node_name, quantized_node_input_names)
 
                 helper.copy_attr(quantized_deconv_node, "strides", node.attr["strides"])
                 helper.copy_attr(quantized_deconv_node, "padding", node.attr["padding"])
                 helper.copy_attr(quantized_deconv_node, "data_format", node.attr["data_format"])
                 if "explicit_paddings" in node.attr:
-                    helper.copy_attr(quantized_deconv_node, "explicit_paddings",
-                    node.attr["explicit_paddings"])
+                    helper.copy_attr(quantized_deconv_node, "explicit_paddings", node.attr["explicit_paddings"])
                 helper.copy_attr(quantized_deconv_node, "dilations", node.attr["dilations"])
                 input_data_type = dtypes.quint8 if self._find_relu_node(node) else dtypes.qint8
                 helper.set_attr_dtype(quantized_deconv_node, "Tinput", input_data_type)
-                helper.set_attr_dtype(quantized_deconv_node, "Tfilter",dtypes.qint8)
+                helper.set_attr_dtype(quantized_deconv_node, "Tfilter", dtypes.qint8)
                 # helper.set_attr_string(quantized_conv_node, '_kernel', b'QuantizedMklOp')
                 helper.set_attr_dtype(quantized_deconv_node, "out_type", dtypes.qint32)
                 # helper.set_attr_dtype(quantized_conv_node, "alpha", dtypes.quint8)
                 helper.set_attr_dtype(quantized_deconv_node, "Tbias", dtypes.float32)
-                                                #if self.device == 'gpu' else dtypes.qint32)
-                helper.set_attr_string_list(quantized_deconv_node, 'fused_ops', [b'BiasAdd'])
+                # if self.device == 'gpu' else dtypes.qint32)
+                helper.set_attr_string_list(quantized_deconv_node, "fused_ops", [b"BiasAdd"])
 
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_inputs', [
-                    dtypes.int32.as_datatype_enum,
-                    dtypes.qint8.as_datatype_enum,
-                    input_data_type.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,# if self.device == 'gpu' else dtypes.qint32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                 ])
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_outputs', [
-                                          dtypes.qint32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum, ])
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_inputs",
+                    [
+                        dtypes.int32.as_datatype_enum,
+                        dtypes.qint8.as_datatype_enum,
+                        input_data_type.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,  # if self.device == 'gpu' else dtypes.qint32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_outputs",
+                    [
+                        dtypes.qint32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
 
                 self.add_output_graph_node(quantized_deconv_node)
-                quantize_down_name = self._add_quantize_down_nodes(
-                    node, quantized_node_name, dtypes.qint8, False)
-                self._intel_cpu_add_dequantize_result_node(
-                    quantize_down_name, match_node_name[2], dtypes.qint8)
+                quantize_down_name = self._add_quantize_down_nodes(node, quantized_node_name, dtypes.qint8, False)
+                self._intel_cpu_add_dequantize_result_node(quantize_down_name, match_node_name[2], dtypes.qint8)
 
             else:
                 new_node = node_def_pb2.NodeDef()
@@ -252,9 +261,9 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
         weights_min_name = weights_name[1]
         weights_max_name = weights_name[2]
 
-        q_weights_name, q_weights_min_name, q_weights_max_name = \
-            self._intel_cpu_quantize_weight_eightbit(
-                matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel)
+        q_weights_name, q_weights_min_name, q_weights_max_name = self._intel_cpu_quantize_weight_eightbit(
+            matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel
+        )
 
         all_input_names = [normal_inputs[0]] + [q_weights_name] + q_inputs[:1]
         all_input_names.append(q_weights_min_name)
@@ -275,46 +284,50 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
 
                 quantized_node_name = node.name + "_eightbit_quantized_deconv"
 
-                quantized_node_input_names = all_input_names[:2] + \
-                    all_input_names[2:] + control_inputs
+                quantized_node_input_names = all_input_names[:2] + all_input_names[2:] + control_inputs
 
                 node_op = "_FusedQuantizedDeconv3D"
-                quantized_deconv_node = helper.create_node(node_op, quantized_node_name,
-                    quantized_node_input_names)
+                quantized_deconv_node = helper.create_node(node_op, quantized_node_name, quantized_node_input_names)
 
                 helper.copy_attr(quantized_deconv_node, "strides", node.attr["strides"])
                 helper.copy_attr(quantized_deconv_node, "padding", node.attr["padding"])
                 helper.copy_attr(quantized_deconv_node, "data_format", node.attr["data_format"])
                 if "explicit_paddings" in node.attr:
-                    helper.copy_attr(quantized_deconv_node, "explicit_paddings",
-                    node.attr["explicit_paddings"])
+                    helper.copy_attr(quantized_deconv_node, "explicit_paddings", node.attr["explicit_paddings"])
                 helper.copy_attr(quantized_deconv_node, "dilations", node.attr["dilations"])
                 input_data_type = dtypes.quint8 if self._find_relu_node(node) else dtypes.qint8
                 helper.set_attr_dtype(quantized_deconv_node, "Tinput", input_data_type)
-                helper.set_attr_dtype(quantized_deconv_node, "Tfilter",dtypes.qint8)
+                helper.set_attr_dtype(quantized_deconv_node, "Tfilter", dtypes.qint8)
                 # helper.set_attr_string(quantized_conv_node, '_kernel', b'QuantizedMklOp')
                 helper.set_attr_dtype(quantized_deconv_node, "out_type", dtypes.qint32)
                 # helper.set_attr_dtype(quantized_conv_node, "alpha", dtypes.quint8)
 
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_inputs', [
-                    dtypes.int32.as_datatype_enum,
-                    dtypes.qint8.as_datatype_enum,
-                    input_data_type.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                 ])
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_outputs', [
-                                          dtypes.qint32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum, ])
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_inputs",
+                    [
+                        dtypes.int32.as_datatype_enum,
+                        dtypes.qint8.as_datatype_enum,
+                        input_data_type.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_outputs",
+                    [
+                        dtypes.qint32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
 
                 self.add_output_graph_node(quantized_deconv_node)
-                quantize_down_name = self._add_quantize_down_nodes(
-                    node, quantized_node_name, dtypes.qint8, False)
-                self._intel_cpu_add_dequantize_result_node(
-                    quantize_down_name, match_node_name[1], dtypes.qint8)
+                quantize_down_name = self._add_quantize_down_nodes(node, quantized_node_name, dtypes.qint8, False)
+                self._intel_cpu_add_dequantize_result_node(quantize_down_name, match_node_name[1], dtypes.qint8)
 
             else:
                 new_node = node_def_pb2.NodeDef()
@@ -338,9 +351,9 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
         weights_min_name = weights_name[1]
         weights_max_name = weights_name[2]
 
-        q_weights_name, q_weights_min_name, q_weights_max_name = \
-            self._intel_cpu_quantize_weight_eightbit(
-                matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel)
+        q_weights_name, q_weights_min_name, q_weights_max_name = self._intel_cpu_quantize_weight_eightbit(
+            matched_node.node.op, self.node_name_mapping[weights_name[0]].node, self.per_channel
+        )
 
         all_input_names = [normal_inputs[0]] + [q_weights_name] + q_inputs[:1]
         all_input_names.append(q_weights_min_name)
@@ -362,50 +375,56 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
                 quantized_node_name = node.name + "_eightbit_quantized_deconv"
 
                 bias_node_name = self.node_name_mapping[match_node_name[2]].node.input[1]
-                quantized_node_input_names = all_input_names[:3] + \
-                    [bias_node_name] + all_input_names[3:] + control_inputs
+                quantized_node_input_names = (
+                    all_input_names[:3] + [bias_node_name] + all_input_names[3:] + control_inputs
+                )
 
                 node_op = "_FusedQuantizedDeconv3D"
-                quantized_deconv_node = helper.create_node(node_op, quantized_node_name,
-                    quantized_node_input_names)
+                quantized_deconv_node = helper.create_node(node_op, quantized_node_name, quantized_node_input_names)
 
                 helper.copy_attr(quantized_deconv_node, "strides", node.attr["strides"])
                 helper.copy_attr(quantized_deconv_node, "padding", node.attr["padding"])
                 helper.copy_attr(quantized_deconv_node, "data_format", node.attr["data_format"])
                 if "explicit_paddings" in node.attr:
-                    helper.copy_attr(quantized_deconv_node, "explicit_paddings",
-                    node.attr["explicit_paddings"])
+                    helper.copy_attr(quantized_deconv_node, "explicit_paddings", node.attr["explicit_paddings"])
                 helper.copy_attr(quantized_deconv_node, "dilations", node.attr["dilations"])
                 input_data_type = dtypes.quint8 if self._find_relu_node(node) else dtypes.qint8
                 helper.set_attr_dtype(quantized_deconv_node, "Tinput", input_data_type)
-                helper.set_attr_dtype(quantized_deconv_node, "Tfilter",dtypes.qint8)
+                helper.set_attr_dtype(quantized_deconv_node, "Tfilter", dtypes.qint8)
                 # helper.set_attr_string(quantized_conv_node, '_kernel', b'QuantizedMklOp')
                 helper.set_attr_dtype(quantized_deconv_node, "out_type", dtypes.qint32)
                 # helper.set_attr_dtype(quantized_conv_node, "alpha", dtypes.quint8)
                 helper.set_attr_dtype(quantized_deconv_node, "Tbias", dtypes.float32)
-                                                #if self.device == 'gpu' else dtypes.qint32)
-                helper.set_attr_string_list(quantized_deconv_node, 'fused_ops', [b'BiasAdd'])
+                # if self.device == 'gpu' else dtypes.qint32)
+                helper.set_attr_string_list(quantized_deconv_node, "fused_ops", [b"BiasAdd"])
 
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_inputs', [
-                    dtypes.int32.as_datatype_enum,
-                    dtypes.qint8.as_datatype_enum,
-                    input_data_type.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,# if self.device == 'gpu' else dtypes.qint32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                    dtypes.float32.as_datatype_enum,
-                 ])
-                helper.set_attr_type_list(quantized_deconv_node, 'Thost_outputs', [
-                                          dtypes.qint32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum,
-                                          dtypes.float32.as_datatype_enum, ])
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_inputs",
+                    [
+                        dtypes.int32.as_datatype_enum,
+                        dtypes.qint8.as_datatype_enum,
+                        input_data_type.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,  # if self.device == 'gpu' else dtypes.qint32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
+                helper.set_attr_type_list(
+                    quantized_deconv_node,
+                    "Thost_outputs",
+                    [
+                        dtypes.qint32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                        dtypes.float32.as_datatype_enum,
+                    ],
+                )
 
                 self.add_output_graph_node(quantized_deconv_node)
-                quantize_down_name = self._add_quantize_down_nodes(
-                    node, quantized_node_name, dtypes.qint8, False)
-                self._intel_cpu_add_dequantize_result_node(
-                    quantize_down_name, match_node_name[2], dtypes.qint8)
+                quantize_down_name = self._add_quantize_down_nodes(node, quantized_node_name, dtypes.qint8, False)
+                self._intel_cpu_add_dequantize_result_node(quantize_down_name, match_node_name[2], dtypes.qint8)
 
             else:
                 new_node = node_def_pb2.NodeDef()
@@ -425,10 +444,10 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
         matched_rule, matched_node_name = self._is_match_deconv(self.sorted_patterns, True)
         if matched_node_name:
             self.output_graph = graph_pb2.GraphDef()
-            fusion_name = ''.join(matched_rule)
+            fusion_name = "".join(matched_rule)
             if fusion_name in self.fusion_mapping:
                 self.fusion_mapping[fusion_name](matched_node_name)
-            else: # pragma: no cover
+            else:  # pragma: no cover
                 self.logger.info("Unknown fusion pattern {}.".format(fusion_name))
                 if self.remove_redundant_quant_flag:
                     self.input_graph = self.remove_redundant_quantization(self.input_graph)
@@ -456,8 +475,7 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
 
         for k, v in enumerate(self.op_list):
             if v in set(fusion[1] for fusion in patterns):
-                cur_node = self.node_name_mapping[list(
-                    self.node_name_mapping.keys())[k]].node
+                cur_node = self.node_name_mapping[list(self.node_name_mapping.keys())[k]].node
                 if cur_node.name != self.start_node_name:
                     continue
 
@@ -476,8 +494,10 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
                         input_index = 0
                         if sub_rule[1] in ("Conv2DBackpropInput", "Conv3DBackpropInputV2"):
                             input_index = 2
-                        if self.node_name_mapping[normal_inputs[input_index]].node.op != "Dequantize" or \
-                           self.node_name_mapping[normal_inputs[1]].node.op != "Dequantize":
+                        if (
+                            self.node_name_mapping[normal_inputs[input_index]].node.op != "Dequantize"
+                            or self.node_name_mapping[normal_inputs[1]].node.op != "Dequantize"
+                        ):
                             continue
 
                     sub_rule_len = len(sub_rule) - 2
@@ -494,15 +514,11 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
                             self.logger.debug("Fail to match {}".format(sub_rule))
                             break
 
-                        next_node_name = self.node_name_mapping[
-                            cur_node_name].output[0]
+                        next_node_name = self.node_name_mapping[cur_node_name].output[0]
 
-                        is_shared_output = True if len(
-                            self.node_name_mapping[cur_node_name].output
-                        ) > 1 else False
+                        is_shared_output = True if len(self.node_name_mapping[cur_node_name].output) > 1 else False
 
-                        next_node_op = self.node_name_mapping[
-                            next_node_name].node.op
+                        next_node_op = self.node_name_mapping[next_node_name].node.op
                         if next_node_op == sub_rule[-sub_rule_len]:
                             if not is_shared_output:
                                 matched_node_name.append(next_node_name)
@@ -519,8 +535,7 @@ class FuseNodeStartWithDeconv2d(QuantizeNodeBase):
 
                     if sub_rule_len == 1:
                         matched_node_name.append(sub_rule[-1])
-                        self.logger.debug("Match {} on nodes {}.".
-                                          format(sub_rule, matched_node_name))
+                        self.logger.debug("Match {} on nodes {}.".format(sub_rule, matched_node_name))
                         return sub_rule, matched_node_name
 
         return None, None
