@@ -14,7 +14,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Fetch all files and init all algorithms."""
 
 from .algorithm import ALGORITHMS, Algorithm, AlgorithmScheduler, algorithm_registry
@@ -24,9 +23,8 @@ import glob
 modules = glob.glob(join(dirname(__file__), "*.py"))
 
 for f in modules:
-    if isfile(f) and not f.startswith('__') and not f.endswith('__init__.py'):
+    if isfile(f) and not f.startswith("__") and not f.endswith("__init__.py"):
         __import__(basename(f)[:-3], globals(), locals(), level=1)
 
 
 __all__ = ["ALGORITHMS", "Algorithm", "AlgorithmScheduler", "algorithm_registry"]
-
