@@ -16,5 +16,3 @@
 # limitations under the License.
 
 from .callbacks import QuantizationAwareTrainingCallbacks, DistillationCallbacks, PruningCallbacks
-from ..experimental.compression import prepare_pruning
-from .. import WeightPruningConfig
\ No newline at end of file
