@@ -1,4 +1,4 @@
-"""distillation init."""
+"""Distillation init."""
 # !/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
@@ -14,4 +14,4 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
-# limitations under the License.
\ No newline at end of file
+# limitations under the License.
