@@ -15,19 +15,26 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import copy
+import datetime
+import itertools
+import os
+import re
+from collections import OrderedDict
+
 import yaml
-from schema import Schema, And, Use, Optional, Or, Hook
+from schema import And, Hook, Optional, Or, Schema, Use
+
 from ..adaptor import FRAMEWORKS
-from ..strategy import STRATEGIES
 from ..objective import OBJECTIVES
 from ..utils import logger
 from ..version import __version__
-import re
-import copy
-import itertools
-from collections import OrderedDict
 from .dotdict import DotDict, deep_set
-import os, datetime
+
+# TODO WA for avoid circular import
+# from ..experimental.strategy import EXP_STRATEGIES
+EXP_STRATEGIES = ['basic', 'auto_mixed_precision', 'bayesian', 'conservative',\
+    'exhaustive', 'hawq_v2', 'mse', 'mse_v2', 'random', 'sigopt', 'tpe', 'fake']
 
 def constructor_register(cls):
     yaml_key = "!{}".format(cls.__name__)
@@ -79,9 +86,7 @@ class Pruner():
 
 @constructor_register
 class PrunerV2:
-    """
-    similiar to torch optimizer's interface
-    """
+    """Similar to torch optimizer's interface."""
 
     def __init__(self,
                  target_sparsity=None, pruning_type=None, pattern=None, op_names=None,
@@ -277,7 +282,7 @@ ops_schema = Schema({
         # placeholder are only for PyTorch framework
         Optional('algorithm'): And(
             list,
-            lambda s: all(i in ['minmax', 'kl', 'placeholder'] for i in s))
+            lambda s: all(i in ['minmax', 'kl', 'placeholder', 'percentile'] for i in s))
     }
 })
 
@@ -807,7 +812,7 @@ schema = Schema({
         Optional('approach', default='post_training_static_quant'): And(
             str,
             # TODO check if framework support dynamic quantize
-            # Now only onnruntime and pytorch supoort
+            # Now only onnruntime and pytorch support
             lambda s: s in ['post_training_static_quant',
                             'post_training_dynamic_quant',
                             'post_training_auto_quant',
@@ -887,7 +892,7 @@ schema = Schema({
                 Optional('algorithm', default=None): And(
                     Or(str, list),
                     Use(input_to_list),
-                    lambda s: all(i in ['minmax', 'kl', 'placeholder'] for i in s)),
+                    lambda s: all(i in ['minmax', 'kl', 'placeholder', 'percentile'] for i in s)),
             }
         },
         Optional('optype_wise', default=None): {
@@ -914,7 +919,7 @@ schema = Schema({
         'diagnosis': False,
         }): {
         Optional('strategy', default={'name': 'basic'}): {
-            'name': And(str, lambda s: s in STRATEGIES),
+            'name': And(str, lambda s: s in EXP_STRATEGIES),
             Optional('sigopt_api_token'): str,
             Optional('sigopt_project_id'): str,
             Optional('sigopt_experiment_name', default='nc-tune'): str,
@@ -951,21 +956,7 @@ schema = Schema({
             Optional('path', default=None): str,
             Optional('resume'): str
         },
-        Optional('diagnosis', default = {
-            'diagnosis_after_tuning': False,
-            'op_list': [],
-            'iteration_list': [1],
-            'inspect_type': 'activation',
-            'save_to_disk': True,
-            'save_path': './nc_workspace/inspect_saved/',
-        }):{
-            Optional('diagnosis_after_tuning', default=False): And(bool, lambda s: s in [True, False]),
-            Optional('op_list', default=[]): And(Or(str, list), Use(input_to_list)),
-            Optional('iteration_list', default=[1]): And(Or(int, list), Use(input_to_list_int)),
-            Optional('inspect_type', default='all'): And(str, lambda s : s in ['all', 'activation', 'weight']),
-            Optional('save_to_disk', default=True): And(bool, lambda s: s in [True, False]),
-            Optional('save_path', default='./nc_workspace/inspect_saved/'): str,
-        },
+        Optional('diagnosis', default=False): And(bool, lambda s: s in [True, False]),
     },
     Optional('evaluation'): {
         Hook('accuracy', handler=_valid_multi_metrics): object,
@@ -1088,6 +1079,7 @@ schema = Schema({
                 Optional('transform'): postprocess_schema
             }
         },
+        Optional('diagnosis', default=False): And(bool, lambda s: s in [True, False]),
     },
     Optional('pruning'): {
         Hook('train', handler=_valid_prune_epoch): object,
@@ -1147,8 +1139,10 @@ schema = Schema({
             Optional("dataset_path", default=None): str,
             Optional("supernet_ckpt_path", default=None): str,
             Optional("batch_size", default=64): int,
+            Optional("eval_batch_size", default=64): int,
             Optional("num_workers", default=20): int,
             Optional("distributed", default=False): bool,
+            Optional("test_fraction", default=1.0): float,
             },
     },
 
@@ -1334,15 +1328,14 @@ distillation_default_schema = Schema({
                                   'loss_weights': [0.5, 0.5]}}}}): dict,
 
     Optional('evaluation', default={'accuracy': {'metric': {'topk': 1}}}): dict
- 
+
 })
 
 class Conf(object):
-    """config parser.
+    """Config parser.
 
     Args:
         cfg_fname (string): The path to the configuration file.
-
     """
     def __init__(self, cfg_fname):
         assert cfg_fname is not None
@@ -1351,8 +1344,8 @@ class Conf(object):
     def _read_cfg(self, cfg_fname):
         """Load a config file following yaml syntax.
 
-           Args:
-               cfg_fname(string): The name of configuration yaml file
+        Args:
+            cfg_fname(string): The name of configuration yaml file
         """
         try:
             with open(cfg_fname, 'r') as f:
@@ -1414,11 +1407,17 @@ class Conf(object):
                 'tuning.exit_policy.timeout': pythonic_config.quantization.timeout,
                 'tuning.exit_policy.max_trials': pythonic_config.quantization.max_trials,
                 'tuning.exit_policy.performance_only': pythonic_config.quantization.performance_only,
-                'tuning.use_distributed_tuning': pythonic_config.quantization.use_distributed_tuning,
                 'use_bf16': pythonic_config.quantization.use_bf16,
                 'quantization.quant_level': pythonic_config.quantization.quant_level,
                 'reduce_range': pythonic_config.quantization.reduce_range
             })
+
+            if pythonic_config.quantization.diagnosis:
+                mapping.update({
+                    'tuning.diagnosis': True,
+                    'tuning.exit_policy.max_trials': 1,
+                })
+
             if pythonic_config.quantization.strategy_kwargs:
                 st_kwargs = pythonic_config.quantization.strategy_kwargs
                 for st_key in ['sigopt_api_token', 'sigopt_project_id', 'sigopt_experiment_name', \
@@ -1474,6 +1473,9 @@ class Conf(object):
                 'evaluation.accuracy.configs.intra_num_of_threads':
                     pythonic_config.benchmark.intra_num_of_threads,
             })
+            if pythonic_config.benchmark.diagnosis:
+                mapping.update({'evaluation.diagnosis': pythonic_config.benchmark.diagnosis})
+
             if "model.backend" not in mapping:
                 mapping.update({
                     'model.backend': pythonic_config.benchmark.backend,
@@ -1540,11 +1542,10 @@ class Conf(object):
         return dst
 
 class Quantization_Conf(Conf):
-    """config parser.
+    """Config parser.
 
     Args:
         cfg: The path to the configuration file or DotDict object or None.
-
     """
 
     def __init__(self, cfg=None):
@@ -1603,11 +1604,10 @@ class Quantization_Conf(Conf):
         return self._model_wise_tune_space
 
 class Pruning_Conf(Conf):
-    """config parser.
+    """Config parser.
 
     Args:
         cfg: The path to the configuration file or DotDict object or None.
-
     """
 
     def __init__(self, cfg=None):
@@ -1621,11 +1621,10 @@ class Pruning_Conf(Conf):
             self.usr_cfg = DotDict(pruning_default_schema.validate(dict()))
 
 class Graph_Optimization_Conf(Quantization_Conf):
-    """config parser.
+    """Config parser.
 
     Args:
         cfg: The path to the configuration file or DotDict object or None.
-
     """
 
     def __init__(self, cfg=None):
@@ -1638,11 +1637,10 @@ class Graph_Optimization_Conf(Quantization_Conf):
             self.usr_cfg = DotDict(graph_optimization_default_schema.validate(dict()))
 
 class MixedPrecision_Conf(Quantization_Conf):
-    """config parser.
+    """Config parser.
 
     Args:
         cfg: The path to the configuration file or DotDict object or None.
-
     """
 
     def __init__(self, cfg=None):
@@ -1655,11 +1653,10 @@ class MixedPrecision_Conf(Quantization_Conf):
             self.usr_cfg = DotDict(mixed_precision_default_schema.validate(dict()))
 
 class Benchmark_Conf(Conf):
-    """config parser.
+    """Config parser.
 
     Args:
         cfg: The path to the configuration file or DotDict object or None.
-
     """
 
     def __init__(self, cfg=None):
@@ -1672,11 +1669,10 @@ class Benchmark_Conf(Conf):
             self.usr_cfg = DotDict(benchmark_default_schema.validate(dict()))
 
 class Distillation_Conf(Conf):
-    """config parser.
+    """Config parser.
 
     Args:
         cfg: The path to the configuration file or DotDict object or None.
-
     """
 
     def __init__(self, cfg=None):
@@ -1689,12 +1685,11 @@ class Distillation_Conf(Conf):
             self.usr_cfg = DotDict(distillation_default_schema.validate(dict()))
 
 class NASConfig(Conf):
-    """config parser.
+    """Config parser.
 
     Args:
         approach: The approach of the NAS.
         search_algorithm: The search algorithm for NAS procedure.
-
     """
 
     def __init__(self, approach=None, search_space=None, search_algorithm=None):
