@@ -14,24 +14,26 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """This is the base class for each framework."""
 
-from abc import abstractmethod
 import os
-from neural_compressor.utils.utility import LazyImport, singleton
+from abc import abstractmethod
+
 from PIL import Image
-torch = LazyImport('torch')
-torchvision = LazyImport('torchvision')
-tf = LazyImport('tensorflow')
-mx = LazyImport('mxnet')
-np = LazyImport('numpy')
-hashlib = LazyImport('hashlib')
-gzip = LazyImport('gzip')
-tarfile = LazyImport('tarfile')
-zipfile = LazyImport('zipfile')
-pickle = LazyImport('pickle')
-glob = LazyImport('glob')
+
+from neural_compressor.utils.utility import LazyImport, singleton
+
+torch = LazyImport("torch")
+torchvision = LazyImport("torchvision")
+tf = LazyImport("tensorflow")
+mx = LazyImport("mxnet")
+np = LazyImport("numpy")
+hashlib = LazyImport("hashlib")
+gzip = LazyImport("gzip")
+tarfile = LazyImport("tarfile")
+zipfile = LazyImport("zipfile")
+pickle = LazyImport("pickle")
+glob = LazyImport("glob")
 
 
 @singleton
@@ -51,8 +53,7 @@ class PyTorchDatasets(object):
     def __init__(self):
         """Initialize the attributes of class."""
         self.datasets = {
-            'ImageFolder': PytorchMxnetWrapDataset(
-                    torchvision.datasets.ImageFolder),
+            "ImageFolder": PytorchMxnetWrapDataset(torchvision.datasets.ImageFolder),
         }
         self.datasets.update(PYTORCH_DATASETS)
 
@@ -87,7 +88,7 @@ class ONNXRTITDatasets(object):
         self.datasets.update(ONNXRTIT_DATASETS)
 
 
-class PytorchMxnetWrapDataset():
+class PytorchMxnetWrapDataset:
     """The base class for PyTorch and MXNet frameworks.
 
     Args:
@@ -100,11 +101,10 @@ class PytorchMxnetWrapDataset():
 
     def __call__(self, transform=None, filter=None, *args, **kwargs):
         """Wrap the dataset for PyTorch and MXNet framework."""
-        return PytorchMxnetWrapFunction(self.datafunc, transform=transform, \
-                        filter=filter, *args, **kwargs)
+        return PytorchMxnetWrapFunction(self.datafunc, transform=transform, filter=filter, *args, **kwargs)
 
 
-class PytorchMxnetWrapFunction():
+class PytorchMxnetWrapFunction:
     """The Helper class for PytorchMxnetWrapDataset.
 
     Args:
@@ -135,26 +135,26 @@ class PytorchMxnetWrapFunction():
         return sample
 
 
-framework_datasets = {"tensorflow": TensorflowDatasets,
-                      "tensorflow_itex": TensorflowDatasets,
-                      "mxnet": MXNetDatasets,
-                      "pytorch": PyTorchDatasets,
-                      "pytorch_ipex": PyTorchDatasets,
-                      "pytorch_fx": PyTorchDatasets,
-                      "onnxrt_qdq": ONNXRTQLDatasets,
-                      "onnxrt_qlinearops": ONNXRTQLDatasets,
-                      "onnxruntime": ONNXRTQLDatasets,
-                      "onnxrt_integerops": ONNXRTITDatasets,
-                      }
-
+framework_datasets = {
+    "tensorflow": TensorflowDatasets,
+    "tensorflow_itex": TensorflowDatasets,
+    "mxnet": MXNetDatasets,
+    "pytorch": PyTorchDatasets,
+    "pytorch_ipex": PyTorchDatasets,
+    "pytorch_fx": PyTorchDatasets,
+    "onnxrt_qdq": ONNXRTQLDatasets,
+    "onnxrt_qlinearops": ONNXRTQLDatasets,
+    "onnxruntime": ONNXRTQLDatasets,
+    "onnxrt_integerops": ONNXRTITDatasets,
+}
 """The datasets supported by neural_compressor, it's model specific and can be configured by yaml file.
 
-   User could add new datasets by implementing new Dataset subclass under this directory.
-   The naming convention of new dataset subclass should be something like ImageClassifier, user
-   could choose this dataset by setting "imageclassifier" string in tuning.strategy field of yaml.
+User could add new datasets by implementing new Dataset subclass under this directory.
+The naming convention of new dataset subclass should be something like ImageClassifier, user
+could choose this dataset by setting "imageclassifier" string in tuning.strategy field of yaml.
 
-   Datasets variable is used to store all implemented Dataset subclasses to support
-   model specific dataset.
+Datasets variable is used to store all implemented Dataset subclasses to support
+model specific dataset.
 """
 
 
@@ -169,10 +169,19 @@ class Datasets(object):
 
     def __init__(self, framework):
         """Initialize the attributes of class."""
-        assert framework in ["tensorflow", "tensorflow_itex", "keras", \
-                             "mxnet", "onnxrt_qdq", "onnxrt_qlinearops", "onnxrt_integerops", \
-                             "pytorch", "pytorch_ipex", "pytorch_fx", "onnxruntime"], \
-                             "framework support tensorflow pytorch mxnet onnxrt"
+        assert framework in [
+            "tensorflow",
+            "tensorflow_itex",
+            "keras",
+            "mxnet",
+            "onnxrt_qdq",
+            "onnxrt_qlinearops",
+            "onnxrt_integerops",
+            "pytorch",
+            "pytorch_ipex",
+            "pytorch_fx",
+            "onnxruntime",
+        ], "framework support tensorflow pytorch mxnet onnxrt"
         self.datasets = framework_datasets[framework]().datasets
 
     def __getitem__(self, dataset_type):
@@ -180,8 +189,7 @@ class Datasets(object):
 
         x[i] is roughly equivalent to type(x).__getitem__(x, index)
         """
-        assert dataset_type in self.datasets.keys(), "dataset type only support {}".\
-            format(self.datasets.keys())
+        assert dataset_type in self.datasets.keys(), "dataset type only support {}".format(self.datasets.keys())
         return self.datasets[dataset_type]
 
 
@@ -195,20 +203,21 @@ PYTORCHFX_DATASETS = {}
 ONNXRTQL_DATASETS = {}
 ONNXRTIT_DATASETS = {}
 
-registry_datasets = {"tensorflow": TENSORFLOW_DATASETS,
-                     "tensorflow_itex": TENSORFLOWITEX_DATASETS,
-                     "mxnet": MXNET_DATASETS,
-                     "pytorch": PYTORCH_DATASETS,
-                     "pytorch_ipex": PYTORCHIPEX_DATASETS,
-                     "pytorch_fx": PYTORCHFX_DATASETS,
-                     "onnxrt_integerops": ONNXRTIT_DATASETS,
-                     "onnxrt_qdq": ONNXRTQL_DATASETS,
-                     "onnxruntime": ONNXRTQL_DATASETS,
-                     "onnxrt_qlinearops": ONNXRTQL_DATASETS,
-                    }
+registry_datasets = {
+    "tensorflow": TENSORFLOW_DATASETS,
+    "tensorflow_itex": TENSORFLOWITEX_DATASETS,
+    "mxnet": MXNET_DATASETS,
+    "pytorch": PYTORCH_DATASETS,
+    "pytorch_ipex": PYTORCHIPEX_DATASETS,
+    "pytorch_fx": PYTORCHFX_DATASETS,
+    "onnxrt_integerops": ONNXRTIT_DATASETS,
+    "onnxrt_qdq": ONNXRTQL_DATASETS,
+    "onnxruntime": ONNXRTQL_DATASETS,
+    "onnxrt_qlinearops": ONNXRTQL_DATASETS,
+}
 
 
-def dataset_registry(dataset_type, framework, dataset_format=''):
+def dataset_registry(dataset_type, framework, dataset_format=""):
     """Register dataset subclasses.
 
     Args:
@@ -220,8 +229,9 @@ def dataset_registry(dataset_type, framework, dataset_format=''):
     Returns:
         cls: The class of register.
     """
+
     def decorator_dataset(cls):
-        for single_framework in [fwk.strip() for fwk in framework.split(',')]:
+        for single_framework in [fwk.strip() for fwk in framework.split(",")]:
             assert single_framework in [
                 "tensorflow",
                 "tensorflow_itex",
@@ -236,9 +246,10 @@ def dataset_registry(dataset_type, framework, dataset_format=''):
             ], "The framework support tensorflow mxnet pytorch onnxrt"
             dataset_name = dataset_type + dataset_format
             if dataset_name in registry_datasets[single_framework].keys():
-                raise ValueError('Cannot have two datasets with the same name')
+                raise ValueError("Cannot have two datasets with the same name")
             registry_datasets[single_framework][dataset_name] = cls
         return cls
+
     return decorator_dataset
 
 
@@ -267,7 +278,7 @@ class IterableDataset(object):
     """An iterable Dataset.
 
     Subclass iterable dataset should also implement a method:
-    `__iter__` for interating over the samples of the dataset.
+    `__iter__` for iterating over the samples of the dataset.
     """
 
     @abstractmethod
@@ -289,6 +300,7 @@ def download_url(url, root, filename=None, md5=None):  # pragma: no cover
         md5 (str): the md5 string.
     """
     import urllib
+
     root = os.path.expanduser(root)
     if not filename:
         filename = os.path.basename(url)
@@ -297,23 +309,16 @@ def download_url(url, root, filename=None, md5=None):  # pragma: no cover
     os.makedirs(root, exist_ok=True)
 
     if check_integrity(fpath, md5):
-        print('Using downloaded and verified file: ' + fpath)
+        print("Using downloaded and verified file: " + fpath)
     else:
         try:
-            print('Downloading ' + url + ' to ' + fpath)
-            urllib.request.urlretrieve(
-                url, fpath,
-                reporthook=gen_bar_updater()
-            )
+            print("Downloading " + url + " to " + fpath)
+            urllib.request.urlretrieve(url, fpath, reporthook=gen_bar_updater())
         except (urllib.error.URLError, IOError) as e:
-            if url[:5] == 'https':
-                url = url.replace('https:', 'http:')
-                print('Failed download. Trying https -> http instead.'
-                      ' Downloading ' + url + ' to ' + fpath)
-                urllib.request.urlretrieve(
-                    url, fpath,
-                    reporthook=gen_bar_updater()
-                )
+            if url[:5] == "https":
+                url = url.replace("https:", "http:")
+                print("Failed download. Trying https -> http instead." " Downloading " + url + " to " + fpath)
+                urllib.request.urlretrieve(url, fpath, reporthook=gen_bar_updater())
             else:
                 raise e
         if not check_integrity(fpath, md5):
@@ -323,6 +328,7 @@ def download_url(url, root, filename=None, md5=None):  # pragma: no cover
 def gen_bar_updater():
     """Generate progress bar."""
     from tqdm import tqdm
+
     pbar = tqdm(total=None)
 
     def bar_update(count, block_size, total_size):
@@ -331,6 +337,7 @@ def gen_bar_updater():
             pbar.total = total_size
         progress_bytes = count * block_size
         pbar.update(progress_bytes - pbar.n)
+
     return bar_update
 
 
@@ -343,16 +350,21 @@ def check_integrity(fpath, md5):
     return md5 == calculate_md5(fpath)
 
 
-def calculate_md5(fpath, chunk_size=1024*1024):
+def calculate_md5(fpath, chunk_size=1024 * 1024):
     """Generate MD5 checksum for a file."""
     md5 = hashlib.md5()
-    with open(fpath, 'rb') as f:
-        for chunk in iter(lambda: f.read(chunk_size), b''):
+    with open(fpath, "rb") as f:
+        for chunk in iter(lambda: f.read(chunk_size), b""):
             md5.update(chunk)
     return md5.hexdigest()
 
-@dataset_registry(dataset_type="CIFAR10", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+
+@dataset_registry(
+    dataset_type="CIFAR10",
+    framework="onnxrt_qlinearops, \
+                    onnxrt_integerops",
+    dataset_format="",
+)
 class CIFAR10(Dataset):
     """The CIFAR10 and CIFAR100 database.
 
@@ -379,39 +391,33 @@ class CIFAR10(Dataset):
 
     url = "https://www.cs.toronto.edu/~kriz/cifar-10-python.tar.gz"
     filename = "cifar-10-python.tar.gz"
-    tgz_md5 = 'c58f30108f718f92721af3b95e74349a'
+    tgz_md5 = "c58f30108f718f92721af3b95e74349a"
     train_list = [
-        ['data_batch_1', 'c99cafc152244af753f735de768cd75f'],
-        ['data_batch_2', 'd4bba439e000b95fd0a9bffe97cbabec'],
-        ['data_batch_3', '54ebc095f3ab1f0389bbae665268c751'],
-        ['data_batch_4', '634d18415352ddfa80567beed471001a'],
-        ['data_batch_5', '482c414d41f54cd18b22e5b47cb7c3cb'],
+        ["data_batch_1", "c99cafc152244af753f735de768cd75f"],
+        ["data_batch_2", "d4bba439e000b95fd0a9bffe97cbabec"],
+        ["data_batch_3", "54ebc095f3ab1f0389bbae665268c751"],
+        ["data_batch_4", "634d18415352ddfa80567beed471001a"],
+        ["data_batch_5", "482c414d41f54cd18b22e5b47cb7c3cb"],
     ]
 
     test_list = [
-        ['test_batch', '40351d587109b95175f43aff81a1287e'],
+        ["test_batch", "40351d587109b95175f43aff81a1287e"],
     ]
 
     meta = {
-        'filename': 'batches.meta',
-        'key': 'label_names',
-        'md5': '5ff9c542aee3614f3951f8cda6e48888',
+        "filename": "batches.meta",
+        "key": "label_names",
+        "md5": "5ff9c542aee3614f3951f8cda6e48888",
     }
 
-    def __init__(self,
-                 root,
-                 train=False,
-                 transform=None,
-                 filter=None,
-                 download=True):  # pragma: no cover
+    def __init__(self, root, train=False, transform=None, filter=None, download=True):  # pragma: no cover
         """Initialize the attributes of class."""
         self.root = root
         if download:
             self.download()
 
         if not self._check_integrity():
-            raise RuntimeError(
-                'Dataset not found or corrupted. You can use download=True to download it')
+            raise RuntimeError("Dataset not found or corrupted. You can use download=True to download it")
         if train:
             downloaded_list = self.train_list
         else:
@@ -421,13 +427,13 @@ class CIFAR10(Dataset):
         self.targets = []
         for file_name, checksum in downloaded_list:
             file_path = os.path.join(self.root, file_name)
-            with open(file_path, 'rb') as f:
-                entry = pickle.load(f, encoding='latin1')
-                self.data.append(entry['data'])
-                if 'labels' in entry:
-                    self.targets.extend(entry['labels'])
+            with open(file_path, "rb") as f:
+                entry = pickle.load(f, encoding="latin1")
+                self.data.append(entry["data"])
+                if "labels" in entry:
+                    self.targets.extend(entry["labels"])
                 else:
-                    self.targets.extend(entry['fine_labels'])
+                    self.targets.extend(entry["fine_labels"])
         self.data = np.vstack(self.data).reshape(-1, 3, 32, 32)
         self.data = self.data.transpose((0, 2, 3, 1))  # convert to HWC
 
@@ -436,13 +442,14 @@ class CIFAR10(Dataset):
 
     def load_meta(self):  # pragma: no cover
         """Load meta."""
-        path = os.path.join(self.root, self.meta['filename'])
-        if not check_integrity(path, self.meta['md5']):
-            raise RuntimeError('Dataset metadata file not found or corrupted.' +
-                               ' You can use download=True to download it')
-        with open(path, 'rb') as infile:
-            data = pickle.load(infile, encoding='latin1')
-            self.classes = data[self.meta['key']]
+        path = os.path.join(self.root, self.meta["filename"])
+        if not check_integrity(path, self.meta["md5"]):
+            raise RuntimeError(
+                "Dataset metadata file not found or corrupted." + " You can use download=True to download it"
+            )
+        with open(path, "rb") as infile:
+            data = pickle.load(infile, encoding="latin1")
+            self.classes = data[self.meta["key"]]
         self.class_to_idx = {_class: i for i, _class in enumerate(self.classes)}
 
     def __getitem__(self, index):  # pragma: no cover
@@ -462,20 +469,20 @@ class CIFAR10(Dataset):
     def download(self):  # pragma: no cover
         """Download a file."""
         if self._check_integrity():
-            print('Files already downloaded and verified')
+            print("Files already downloaded and verified")
             return
         download_root = os.path.expanduser(self.root)
         filename = os.path.basename(self.url)
         download_url(self.url, download_root, filename, self.tgz_md5)
         archive = os.path.join(download_root, filename)
         print("Extracting {} to {}".format(archive, download_root))
-        with tarfile.open(archive, 'r:gz') as tar:
+        with tarfile.open(archive, "r:gz") as tar:
             tar.extractall(path=download_root)
 
     def _check_integrity(self):  # pragma: no cover
         """Check MD5 checksum."""
         root = self.root
-        for fentry in (self.train_list + self.test_list):
+        for fentry in self.train_list + self.test_list:
             filename, md5 = fentry[0], fentry[1]
             fpath = os.path.join(root, filename)
             if not check_integrity(fpath, md5):
@@ -483,7 +490,7 @@ class CIFAR10(Dataset):
             return True
 
 
-@dataset_registry(dataset_type="CIFAR10", framework="pytorch", dataset_format='')
+@dataset_registry(dataset_type="CIFAR10", framework="pytorch", dataset_format="")
 class PytorchCIFAR10(CIFAR10):
     """The PyTorch datasets for CIFAR10."""
 
@@ -499,7 +506,7 @@ class PytorchCIFAR10(CIFAR10):
         return (image, label)
 
 
-@dataset_registry(dataset_type="CIFAR10", framework="mxnet", dataset_format='')
+@dataset_registry(dataset_type="CIFAR10", framework="mxnet", dataset_format="")
 class MXNetCIFAR10(CIFAR10):
     """The MXNet datasets for CIFAR10."""
 
@@ -515,7 +522,7 @@ class MXNetCIFAR10(CIFAR10):
         return (image, label)
 
 
-@dataset_registry(dataset_type="CIFAR10", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="CIFAR10", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowCIFAR10(CIFAR10):
     """The Tensorflow datasets for CIFAR10."""
 
@@ -527,16 +534,20 @@ class TensorflowCIFAR10(CIFAR10):
         image, label = self.data[index], self.targets[index]
         if self.transform is not None:
             image, label = self.transform((image, label))
-        if type(image).__name__ == 'Tensor':
+        if type(image).__name__ == "Tensor":
             with tf.compat.v1.Session() as sess:
                 image = sess.run(image)
-        elif type(image).__name__ == 'EagerTensor':
+        elif type(image).__name__ == "EagerTensor":
             image = image.numpy()
         return (image, label)
 
 
-@dataset_registry(dataset_type="CIFAR100", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+@dataset_registry(
+    dataset_type="CIFAR100",
+    framework="onnxrt_qlinearops, \
+                    onnxrt_integerops",
+    dataset_format="",
+)
 class CIFAR100(CIFAR10):
     """CIFAR100 database.
 
@@ -559,21 +570,21 @@ class CIFAR100(CIFAR10):
 
     url = "https://www.cs.toronto.edu/~kriz/cifar-100-python.tar.gz"
     filename = "cifar-100-python.tar.gz"
-    tgz_md5 = 'eb9058c3a382ffc7106e4002c42a8d85'
+    tgz_md5 = "eb9058c3a382ffc7106e4002c42a8d85"
     train_list = [
-        ['train', '16019d7e3df5f24257cddd939b257f8d'],
+        ["train", "16019d7e3df5f24257cddd939b257f8d"],
     ]
     test_list = [
-        ['test', 'f0ef6b0ae62326f3e7ffdfab6717acfc'],
+        ["test", "f0ef6b0ae62326f3e7ffdfab6717acfc"],
     ]
     meta = {
-        'filename': 'meta',
-        'key': 'fine_label_names',
-        'md5': '7973b15100ade9c7d40fb424638fde48',
+        "filename": "meta",
+        "key": "fine_label_names",
+        "md5": "7973b15100ade9c7d40fb424638fde48",
     }
 
 
-@dataset_registry(dataset_type="CIFAR100", framework="pytorch", dataset_format='')
+@dataset_registry(dataset_type="CIFAR100", framework="pytorch", dataset_format="")
 class PytorchCIFAR100(CIFAR100):
     """The PyTorch datasets for CIFAR100."""
 
@@ -590,7 +601,7 @@ class PytorchCIFAR100(CIFAR100):
         return (image, label)
 
 
-@dataset_registry(dataset_type="CIFAR100", framework="mxnet", dataset_format='')
+@dataset_registry(dataset_type="CIFAR100", framework="mxnet", dataset_format="")
 class MXNetCIFAR100(CIFAR100):
     """The MXNet datasets for CIFAR100."""
 
@@ -606,11 +617,11 @@ class MXNetCIFAR100(CIFAR100):
         return (image, label)
 
 
-@dataset_registry(dataset_type="CIFAR100", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="CIFAR100", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowCIFAR100(CIFAR100):
     """The Tensorflow datasets for CIFAR100."""
 
-    def __getitem__(self, index): # pragma: no cover
+    def __getitem__(self, index):  # pragma: no cover
         """Magic method.
 
         x[i] is roughly equivalent to type(x).__getitem__(x, index)
@@ -618,15 +629,20 @@ class TensorflowCIFAR100(CIFAR100):
         image, label = self.data[index], self.targets[index]
         if self.transform is not None:
             image, label = self.transform((image, label))
-        if type(image).__name__ == 'Tensor':
+        if type(image).__name__ == "Tensor":
             with tf.compat.v1.Session() as sess:
                 image = sess.run(image)
-        elif type(image).__name__ == 'EagerTensor':
+        elif type(image).__name__ == "EagerTensor":
             image = image.numpy()
         return (image, label)
 
-@dataset_registry(dataset_type="MNIST", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+
+@dataset_registry(
+    dataset_type="MNIST",
+    framework="onnxrt_qlinearops, \
+                    onnxrt_integerops",
+    dataset_format="",
+)
 class MNIST(Dataset):
     """Modified National Institute of Standards and Technology database and FashionMNIST database.
 
@@ -649,11 +665,20 @@ class MNIST(Dataset):
                                        downloaded, it is not downloaded again.
     """
 
-    classes = ['0 - zero', '1 - one', '2 - two', '3 - three', '4 - four',
-                   '5 - five', '6 - six', '7 - seven', '8 - eight', '9 - nine']
+    classes = [
+        "0 - zero",
+        "1 - one",
+        "2 - two",
+        "3 - three",
+        "4 - four",
+        "5 - five",
+        "6 - six",
+        "7 - seven",
+        "8 - eight",
+        "9 - nine",
+    ]
     resource = [
-        ('https://storage.googleapis.com/tensorflow/tf-keras-datasets/mnist.npz',
-            '8a61469f7ea1b51cbae51d4f78837e45')
+        ("https://storage.googleapis.com/tensorflow/tf-keras-datasets/mnist.npz", "8a61469f7ea1b51cbae51d4f78837e45")
     ]
 
     def __init__(self, root, train=False, transform=None, filter=None, download=True):
@@ -671,13 +696,12 @@ class MNIST(Dataset):
         for file_name, checksum in self.resource:
             file_path = os.path.join(self.root, os.path.basename(file_name))
             if not os.path.exists(file_path):
-                raise RuntimeError(
-                    'Dataset not found. You can use download=True to download it')
+                raise RuntimeError("Dataset not found. You can use download=True to download it")
             with np.load(file_path, allow_pickle=True) as f:
                 if self.train:
-                    self.data, self.targets = f['x_train'], f['y_train']
+                    self.data, self.targets = f["x_train"], f["y_train"]
                 else:
-                    self.data, self.targets = f['x_test'], f['y_test']
+                    self.data, self.targets = f["x_test"], f["y_test"]
 
     def __len__(self):
         """Length of the dataset."""
@@ -706,11 +730,10 @@ class MNIST(Dataset):
             if os.path.exists(os.path.join(self.root, filename)):
                 continue
             else:
-                download_url(url, root=self.root,
-                            filename=filename, md5=md5)
+                download_url(url, root=self.root, filename=filename, md5=md5)
 
 
-@dataset_registry(dataset_type="MNIST", framework="pytorch", dataset_format='')
+@dataset_registry(dataset_type="MNIST", framework="pytorch", dataset_format="")
 class PytorchMNIST(MNIST):
     """The PyTorch datasets for MNIST."""
 
@@ -720,14 +743,14 @@ class PytorchMNIST(MNIST):
         x[i] is roughly equivalent to type(x).__getitem__(x, index)
         """
         image, label = self.data[index], int(self.targets[index])
-        image = Image.fromarray(image, mode='L')
+        image = Image.fromarray(image, mode="L")
         if self.transform is not None:
             image, label = self.transform((image, label))
         image = np.array(image)
         return (image, label)
 
 
-@dataset_registry(dataset_type="MNIST", framework="mxnet", dataset_format='')
+@dataset_registry(dataset_type="MNIST", framework="mxnet", dataset_format="")
 class MXNetMNIST(MNIST):
     """The MXNet datasets for MNIST."""
 
@@ -744,7 +767,7 @@ class MXNetMNIST(MNIST):
         return (image, label)
 
 
-@dataset_registry(dataset_type="MNIST", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="MNIST", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowMNIST(MNIST):
     """The Tensorflow datasets for MNIST."""
 
@@ -757,16 +780,20 @@ class TensorflowMNIST(MNIST):
         image = np.expand_dims(image, -1)
         if self.transform is not None:
             image, label = self.transform((image, label))
-        if type(image).__name__ == 'Tensor':
+        if type(image).__name__ == "Tensor":
             with tf.compat.v1.Session() as sess:
                 image = sess.run(image)
-        elif type(image).__name__ == 'EagerTensor':
+        elif type(image).__name__ == "EagerTensor":
             image = image.numpy()
         return (image, label)
 
 
-@dataset_registry(dataset_type="FashionMNIST", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+@dataset_registry(
+    dataset_type="FashionMNIST",
+    framework="onnxrt_qlinearops, \
+                    onnxrt_integerops",
+    dataset_format="",
+)
 class FashionMNIST(MNIST):
     """FashionMNIST database.
 
@@ -788,35 +815,37 @@ class FashionMNIST(MNIST):
     """
 
     resource = [
-        ('https://storage.googleapis.com/tensorflow/tf-keras-datasets/' + file_name, None)
+        ("https://storage.googleapis.com/tensorflow/tf-keras-datasets/" + file_name, None)
         for file_name in [
-            'train-labels-idx1-ubyte.gz', 'train-images-idx3-ubyte.gz',
-            't10k-labels-idx1-ubyte.gz', 't10k-images-idx3-ubyte.gz'
-            ]
+            "train-labels-idx1-ubyte.gz",
+            "train-images-idx3-ubyte.gz",
+            "t10k-labels-idx1-ubyte.gz",
+            "t10k-images-idx3-ubyte.gz",
+        ]
     ]
 
-    classes = ['T-shirt/top', 'Trouser', 'Pullover', 'Dress', 'Coat', 'Sandal',
-               'Shirt', 'Sneaker', 'Bag', 'Ankle boot']
+    classes = ["T-shirt/top", "Trouser", "Pullover", "Dress", "Coat", "Sandal", "Shirt", "Sneaker", "Bag", "Ankle boot"]
 
     def read_data(self):
         """Read data from a file."""
         import struct
+
         if self.train:
-            label_path = os.path.join(self.root, 'train-labels-idx1-ubyte.gz')
-            image_path = os.path.join(self.root, 'train-images-idx3-ubyte.gz')
+            label_path = os.path.join(self.root, "train-labels-idx1-ubyte.gz")
+            image_path = os.path.join(self.root, "train-images-idx3-ubyte.gz")
         else:
-            label_path = os.path.join(self.root, 't10k-labels-idx1-ubyte.gz')
-            image_path = os.path.join(self.root, 't10k-images-idx3-ubyte.gz')
-        with gzip.open(label_path, 'rb') as f:
+            label_path = os.path.join(self.root, "t10k-labels-idx1-ubyte.gz")
+            image_path = os.path.join(self.root, "t10k-images-idx3-ubyte.gz")
+        with gzip.open(label_path, "rb") as f:
             struct.unpack(">II", f.read(8))
             self.targets = np.frombuffer(f.read(), dtype=np.uint8).astype(np.int32)
-        with gzip.open(image_path, 'rb') as f:
+        with gzip.open(image_path, "rb") as f:
             struct.unpack(">IIII", f.read(16))
             data = np.frombuffer(f.read(), dtype=np.uint8)
             self.data = data.reshape(len(self.targets), 28, 28)
 
 
-@dataset_registry(dataset_type="FashionMNIST", framework="pytorch", dataset_format='')
+@dataset_registry(dataset_type="FashionMNIST", framework="pytorch", dataset_format="")
 class PytorchFashionMNIST(FashionMNIST):
     """The PyTorch datasets for FashionMNIST."""
 
@@ -826,14 +855,14 @@ class PytorchFashionMNIST(FashionMNIST):
         x[i] is roughly equivalent to type(x).__getitem__(x, index)
         """
         image, label = self.data[index], int(self.targets[index])
-        image = Image.fromarray(image, mode='L')
+        image = Image.fromarray(image, mode="L")
         if self.transform is not None:
             image, label = self.transform((image, label))
         image = np.array(image)
         return (image, label)
 
 
-@dataset_registry(dataset_type="FashionMNIST", framework="mxnet", dataset_format='')
+@dataset_registry(dataset_type="FashionMNIST", framework="mxnet", dataset_format="")
 class MXNetFashionMNIST(FashionMNIST):
     """The MXNet Dataset for FashionMNIST."""
 
@@ -850,7 +879,7 @@ class MXNetFashionMNIST(FashionMNIST):
         return (image, label)
 
 
-@dataset_registry(dataset_type="FashionMNIST", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="FashionMNIST", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowFashionMNIST(FashionMNIST):
     """The Tensorflow Dataset for FashionMNIST."""
 
@@ -863,16 +892,20 @@ class TensorflowFashionMNIST(FashionMNIST):
         image = np.expand_dims(image, -1)
         if self.transform is not None:
             image, label = self.transform((image, label))
-        if type(image).__name__ == 'Tensor':
+        if type(image).__name__ == "Tensor":
             with tf.compat.v1.Session() as sess:
                 image = sess.run(image)
-        elif type(image).__name__ == 'EagerTensor':
+        elif type(image).__name__ == "EagerTensor":
             image = image.numpy()
         return (image, label)
 
 
-@dataset_registry(dataset_type="ImageFolder", framework="onnxrt_qlinearops, \
-                    onnxrt_integerops", dataset_format='')
+@dataset_registry(
+    dataset_type="ImageFolder",
+    framework="onnxrt_qlinearops, \
+                    onnxrt_integerops",
+    dataset_format="",
+)
 class ImageFolder(Dataset):
     """The base class for ImageFolder.
 
@@ -902,10 +935,10 @@ class ImageFolder(Dataset):
 
         self.transform = transform
         self.image_list = []
-        files = glob.glob(os.path.join(self.root, '*'))
+        files = glob.glob(os.path.join(self.root, "*"))
         files.sort()
         for idx, file in enumerate(files):
-            imgs = glob.glob(os.path.join(file, '*'))
+            imgs = glob.glob(os.path.join(file, "*"))
             imgs.sort()
             for img in imgs:
                 self.image_list.append((img, idx))
@@ -928,7 +961,7 @@ class ImageFolder(Dataset):
             return (image, label)
 
 
-@dataset_registry(dataset_type="ImageFolder", framework="mxnet", dataset_format='')
+@dataset_registry(dataset_type="ImageFolder", framework="mxnet", dataset_format="")
 class MXNetImageFolder(ImageFolder):
     """The MXNet Dataset for image folder.
 
@@ -964,7 +997,7 @@ class MXNetImageFolder(ImageFolder):
         return (image, label)
 
 
-@dataset_registry(dataset_type="ImageFolder", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="ImageFolder", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowImageFolder(ImageFolder):
     """The Tensorflow Dataset for image folder.
 
@@ -995,20 +1028,20 @@ class TensorflowImageFolder(ImageFolder):
         sample = self.image_list[index]
         label = sample[1]
         with Image.open(sample[0]) as image:
-            if image.mode != 'RGB':
-                image = image.convert('RGB')
+            if image.mode != "RGB":
+                image = image.convert("RGB")
             image = np.array(image)
             if self.transform is not None:
                 image, label = self.transform((image, label))
-            if type(image).__name__ == 'Tensor':
+            if type(image).__name__ == "Tensor":
                 with tf.compat.v1.Session() as sess:
                     image = sess.run(image)
-            elif type(image).__name__ == 'EagerTensor':
+            elif type(image).__name__ == "EagerTensor":
                 image = image.numpy()
             return (image, label)
 
 
-@dataset_registry(dataset_type="TFRecordDataset", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="TFRecordDataset", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowTFRecordDataset(IterableDataset):
     """The Tensorflow TFRecord Dataset.
 
@@ -1025,17 +1058,17 @@ class TensorflowTFRecordDataset(IterableDataset):
         # pylint: disable=no-name-in-module
         from tensorflow.python.data.experimental import parallel_interleave
         from tensorflow.python.platform import gfile
+
         file_names = gfile.Glob(root)
         ds = tf.data.Dataset.from_tensor_slices(file_names)
-        ds = ds.apply(parallel_interleave(
-                tf.data.TFRecordDataset, cycle_length=len(file_names)))
+        ds = ds.apply(parallel_interleave(tf.data.TFRecordDataset, cycle_length=len(file_names)))
         if transform is not None:
             ds = ds.map(transform, num_parallel_calls=None)
         ds = ds.prefetch(buffer_size=tf.data.experimental.AUTOTUNE)  # this number can be tuned
         return ds
 
 
-@dataset_registry(dataset_type="ImageRecord", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="ImageRecord", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowImageRecord(IterableDataset):
     """Tensorflow imageNet database in tf record format.
 
@@ -1053,20 +1086,23 @@ class TensorflowImageRecord(IterableDataset):
     """
 
     """Configuration for Imagenet dataset."""
+
     def __new__(cls, root, transform=None, filter=None):
         """Build a new object of TensorflowImageRecord class."""
         from tensorflow.python.platform import gfile  # pylint: disable=no-name-in-module
-        glob_pattern = os.path.join(root, '*-*-of-*')
+
+        glob_pattern = os.path.join(root, "*-*-of-*")
         file_names = gfile.Glob(glob_pattern)
         if not file_names:
-            raise ValueError('Found no files in --root matching: {}'.format(glob_pattern))
+            raise ValueError("Found no files in --root matching: {}".format(glob_pattern))
 
         # pylint: disable=no-name-in-module
         from tensorflow.python.data.experimental import parallel_interleave
+
         from neural_compressor.experimental.data.transforms.imagenet_transform import ParseDecodeImagenet
+
         ds = tf.data.TFRecordDataset.list_files(file_names, shuffle=False)
-        ds = ds.apply(parallel_interleave(
-                tf.data.TFRecordDataset, cycle_length=len(file_names)))
+        ds = ds.apply(parallel_interleave(tf.data.TFRecordDataset, cycle_length=len(file_names)))
 
         if transform is not None:
             transform.transform_list.insert(0, ParseDecodeImagenet())
@@ -1077,7 +1113,7 @@ class TensorflowImageRecord(IterableDataset):
         return ds
 
 
-@dataset_registry(dataset_type="VOCRecord", framework="tensorflow, tensorflow_itex", dataset_format='')
+@dataset_registry(dataset_type="VOCRecord", framework="tensorflow, tensorflow_itex", dataset_format="")
 class TensorflowVOCRecord(IterableDataset):
     """The Tensorflow PASCAL VOC 2012 database in tf record format.
 
@@ -1097,16 +1133,17 @@ class TensorflowVOCRecord(IterableDataset):
     def __new__(cls, root, transform=None, filter=None):
         """Build a new object of TensorflowVOCRecord class."""
         from tensorflow.python.platform import gfile  # pylint: disable=no-name-in-module
-        glob_pattern = os.path.join(root, '%s-*' % 'val')
+
+        glob_pattern = os.path.join(root, "%s-*" % "val")
         file_names = gfile.Glob(glob_pattern)
         if not file_names:
-            raise ValueError('Found no files in --root matching: {}'.format(glob_pattern))
+            raise ValueError("Found no files in --root matching: {}".format(glob_pattern))
 
         # pylint: disable=no-name-in-module
         from tensorflow.python.data.experimental import parallel_interleave
+
         ds = tf.data.TFRecordDataset.list_files(file_names, shuffle=False)
-        ds = ds.apply(parallel_interleave(
-                tf.data.TFRecordDataset, cycle_length=len(file_names)))
+        ds = ds.apply(parallel_interleave(tf.data.TFRecordDataset, cycle_length=len(file_names)))
 
         if transform is not None:
             ds = ds.map(transform, num_parallel_calls=None)
