@@ -18,30 +18,33 @@
 # limitations under the License.
 
 import copy
-from .component import Component
+
+from neural_compressor.experimental.common import Criterions, Optimizers
+
+from ..adaptor import FRAMEWORKS
+from ..conf.config import DistillationConf
+from ..conf.pythonic_config import Config, DotDict
+from ..model import BaseModel
 from ..utils import logger
 from ..utils.create_obj_from_config import create_dataloader, create_eval_func, create_train_func
-from ..model import BaseModel
 from .common import Model
-from ..adaptor import FRAMEWORKS
-from neural_compressor.experimental.common import Criterions, Optimizers
-from ..conf.config import DistillationConf
-from ..conf.pythonic_config import Config
+from .component import Component
+
 
 class Distillation(Component):
     """Distillation class derived from Component class.
-    
-    Distillation class abstracted the pipeline of knowledge distillation, 
+
+    Distillation class abstracted the pipeline of knowledge distillation,
     transfer the knowledge of the teacher model to the student model.
-       
+
     Args:
         conf_fname_or_obj (string or obj): The path to the YAML configuration file or
             Distillation_Conf containing accuracy goal, distillation objective and related
             dataloaders etc.
-            
+
     Attributes:
         _epoch_ran: A integer indicating how much epochs ran.
-        eval_frequency: The frequency for doing evaluation of the student model 
+        eval_frequency: The frequency for doing evaluation of the student model
             in terms of epoch.
         best_score: The best metric of the student model in the training.
         best_model: The best student model found in the training.
@@ -69,22 +72,19 @@ class Distillation(Component):
         self._train_cfg = None
 
     def _on_train_begin(self, dataloader=None):
-        """Operations called on the begining of the training.
+        """Operations called on the beginning of the training.
 
-        Called before training, evaluate the teacher model and the student model. 
+        Called before training, evaluate the teacher model and the student model.
         """
-        assert self._model, 'student_model must be set.'
+        assert self._model, "student_model must be set."
         if self._eval_func is not None:
             if self.teacher_model:
                 score = self._eval_func(
-                    self.teacher_model if getattr(self._eval_func, 'builtin', None)
-                    else self.teacher_model.model
+                    self.teacher_model if getattr(self._eval_func, "builtin", None) else self.teacher_model.model
                 )
                 logger.info("teacher model score is {}.".format(str(score)))
 
-            score = self._eval_func(
-                self._model if getattr(self._eval_func, 'builtin', None) else self._model.model
-            )
+            score = self._eval_func(self._model if getattr(self._eval_func, "builtin", None) else self._model.model)
             logger.info("initial model score is {}.".format(str(score)))
             if self.eval_frequency > 0:
                 self.best_score = score
@@ -95,7 +95,7 @@ class Distillation(Component):
 
     def _on_step_begin(self, batch_id):
         """Operations called on the beginning of batches."""
-        if self.criterion is not None and hasattr(self.criterion, 'clear_features'):
+        if self.criterion is not None and hasattr(self.criterion, "clear_features"):
             self.criterion.clear_features()
 
     def _on_after_compute_loss(self, input, student_output, student_loss, teacher_output=None):
@@ -112,13 +112,10 @@ class Distillation(Component):
         """
         if self.criterion is None:
             self.create_criterion()
-        assert self.criterion, \
-            'criterion must be set in yaml config file.'
+        assert self.criterion, "criterion must be set in yaml config file."
         if teacher_output is None:
-            assert self.teacher_model, 'teacher_model must be set.'
-            teacher_output = self.criterion.teacher_model_forward(
-                input, teacher_model=self.teacher_model._model
-            )
+            assert self.teacher_model, "teacher_model must be set."
+            teacher_output = self.criterion.teacher_model_forward(input, teacher_model=self.teacher_model._model)
         return self.criterion.loss_cal_sloss(student_output, teacher_output, student_loss)
 
     def on_post_forward(self, input, teacher_output=None):  # pragma: no cover
@@ -126,24 +123,24 @@ class Distillation(Component):
 
         Deprecated.
         """
-        assert False, "This method is deprecated. please use `on_after_compute_loss` instead." \
-                      "on_after_compute_loss(input, student_output, student_loss, teacher_output=None)"
+        assert False, (
+            "This method is deprecated. please use `on_after_compute_loss` instead."
+            "on_after_compute_loss(input, student_output, student_loss, teacher_output=None)"
+        )
 
     def _on_epoch_end(self):
         """Operations called on the end of every epochs.
 
-        Called on the end of every epochs, evaluate the student model 
+        Called on the end of every epochs, evaluate the student model
         and record the best one regularly.
         """
         self._epoch_ran += 1
-        if self._eval_func is not None and self.eval_frequency > 0 and \
-           self._epoch_ran % self.eval_frequency == 0:
-            score = self._eval_func(
-                self._model if getattr(self._eval_func, 'builtin', None) else self._model.model
-            )
+        if self._eval_func is not None and self.eval_frequency > 0 and self._epoch_ran % self.eval_frequency == 0:
+            score = self._eval_func(self._model if getattr(self._eval_func, "builtin", None) else self._model.model)
             logger.info("model score of epoch {} is {}.".format(self._epoch_ran, str(score)))
-            if (isinstance(score, list) and all([s > b_s for s, b_s in
-                zip(score, self.best_score)])) or score > self.best_score:
+            if (
+                isinstance(score, list) and all([s > b_s for s, b_s in zip(score, self.best_score)])
+            ) or score > self.best_score:
                 self.best_score = score
                 if self.framework == "pytorch":
                     self.best_model = copy.deepcopy(self._model)
@@ -155,25 +152,34 @@ class Distillation(Component):
         if self._train_cfg is None:
             # train section of distillation section in yaml file should be configured.
             self._train_cfg = self.cfg.distillation.train
-        assert self._train_cfg, "train field of distillation section in yaml file must " \
-                                "be configured for distillation if train_func is NOT set."
+        assert self._train_cfg, (
+            "train field of distillation section in yaml file must "
+            "be configured for distillation if train_func is NOT set."
+        )
 
     def create_criterion(self):
         """Create the criterion for training."""
         self.init_train_cfg()
         if self.criterion is None:
-            assert 'criterion' in self._train_cfg.keys(), \
-                "criterion part in train field of distillation section in yaml file " \
+            assert "criterion" in self._train_cfg.keys(), (
+                "criterion part in train field of distillation section in yaml file "
                 "must be configured for distillation if criterion is NOT set."
-            criterion_cfg = self._train_cfg.criterion
-            assert len(criterion_cfg) == 1, "There must be exactly one loss in " \
-                "criterion part, instead got {} loss.".format(len(criterion_cfg))
-            loss = list(criterion_cfg.keys())[0]
+            )
+
+            if isinstance(self._train_cfg.criterion, DotDict):
+                criterion_cfg = self._train_cfg.criterion
+            else:
+                criterion_cfg = self._train_cfg.criterion.config
+
+            assert (
+                len(criterion_cfg) == 1
+            ), "There must be exactly one loss in " "criterion part, instead got {} loss.".format(len(criterion_cfg))
+            loss = [i for i in criterion_cfg.keys()][0]
             loss_cfg = criterion_cfg[loss]
             criterion_builder = Criterions(self.framework)[loss](loss_cfg)
             criterion_tuple = criterion_builder()
             if self.teacher_model and self.student_model:
-                if self.framework == 'tensorflow':  # new, for tf
+                if self.framework == "tensorflow":  # new, for tf
                     teacher_model = self.teacher_model._model
                     student_model = self.student_model._model
                 else:  # for pytorch and other frameworks
@@ -183,8 +189,7 @@ class Distillation(Component):
                 criterion_tuple[1]["teacher_model"] = teacher_model
             self.criterion = criterion_tuple[0](**criterion_tuple[1])
         else:
-            logger.warning("Use user defined criterion, "
-                           "ignoring the criterion setting in yaml file.")
+            logger.warning("Use user defined criterion, " "ignoring the criterion setting in yaml file.")
 
         self._train_cfg.criterion = self.criterion
 
@@ -192,25 +197,27 @@ class Distillation(Component):
         """Create the optimizer for training."""
         self.init_train_cfg()
         if self.optimizer is None:
-            assert 'optimizer' in self._train_cfg.keys(), \
-                "optimizer part in train field of distillation section in yaml file " \
+            assert "optimizer" in self._train_cfg.keys(), (
+                "optimizer part in train field of distillation section in yaml file "
                 "must be configured for distillation if optimizer is NOT set."
+            )
             optimizer_cfg = self._train_cfg.optimizer
-            assert len(optimizer_cfg) == 1, "There must be exactly one optimizer in " \
-                "optimizer part, instead got {} optimizer.".format(len(optimizer_cfg))
+            assert (
+                len(optimizer_cfg) == 1
+            ), "There must be exactly one optimizer in " "optimizer part, instead got {} optimizer.".format(
+                len(optimizer_cfg)
+            )
             optimizer_name = list(optimizer_cfg.keys())[0]
             optimizer_cfg_ = optimizer_cfg[optimizer_name]
             optimizer_builder = Optimizers(self.framework)[optimizer_name](optimizer_cfg_)
             optimizer_tuple = optimizer_builder()
-            if self.framework == 'tensorflow':
+            if self.framework == "tensorflow":
                 self.optimizer = optimizer_tuple[0](**optimizer_tuple[1])
-            elif self.framework == 'pytorch':
+            elif self.framework == "pytorch":
                 # pylint: disable=no-member
-                self.optimizer = optimizer_tuple[0](self.model.model.parameters(),
-                                                    **optimizer_tuple[1])
+                self.optimizer = optimizer_tuple[0](self.model.model.parameters(), **optimizer_tuple[1])
         else:
-            logger.warning("Use user defined optimizer, "
-                           "ignoring the optimizer setting in yaml file.")
+            logger.warning("Use user defined optimizer, " "ignoring the optimizer setting in yaml file.")
 
         self._train_cfg.optimizer = self.optimizer
 
@@ -221,38 +228,47 @@ class Distillation(Component):
 
     def pre_process(self):
         """Preprocessing before the disillation pipeline.
-        
-        Initialize necessary parts for distillation pipeline. 
-        """
-        framework_specific_info = {'device': self.cfg.device,
-                                   'random_seed': self.cfg.tuning.random_seed,
-                                   'workspace_path': self.cfg.tuning.workspace.path,
-                                   'q_dataloader': None,
-                                   'format': 'default',
-                                   'backend': 'default'}
 
-        if self.framework == 'tensorflow':
-            framework_specific_info.update(
-                {"inputs": self.cfg.model.inputs, "outputs": self.cfg.model.outputs})
+        Initialize necessary parts for distillation pipeline.
+        """
+        framework_specific_info = {
+            "device": self.cfg.device,
+            "random_seed": self.cfg.tuning.random_seed,
+            "workspace_path": self.cfg.tuning.workspace.path,
+            "q_dataloader": None,
+            "format": "default",
+            "backend": "default",
+        }
+
+        if self.framework == "tensorflow":
+            framework_specific_info.update({"inputs": self.cfg.model.inputs, "outputs": self.cfg.model.outputs})
 
         self.adaptor = FRAMEWORKS[self.framework](framework_specific_info)
 
         self.generate_hooks()
-        assert isinstance(self._model, BaseModel), 'need set neural_compressor Model for distillation....'
+        assert isinstance(self._model, BaseModel), "need set neural_compressor Model for distillation...."
 
-        if self._train_dataloader is None and self._train_func is None and \
-            self.cfg.distillation.train.dataloader is not None:
+        if (
+            self._train_dataloader is None
+            and self._train_func is None
+            and self.cfg.distillation.train.dataloader is not None
+        ):
             train_dataloader_cfg = self.cfg.distillation.train.dataloader
 
             self._train_dataloader = create_dataloader(self.framework, train_dataloader_cfg)
 
-        if self.cfg.evaluation and self.cfg.evaluation.accuracy and \
-           self.cfg.evaluation.accuracy.dataloader and \
-           self._eval_dataloader is None and self._eval_func is None:
+        if (
+            self.cfg.evaluation
+            and self.cfg.evaluation.accuracy
+            and self.cfg.evaluation.accuracy.dataloader
+            and self._eval_dataloader is None
+            and self._eval_func is None
+        ):
             eval_dataloader_cfg = self.cfg.evaluation.accuracy.dataloader
-            assert eval_dataloader_cfg is not None, \
-                   'dataloader field of evaluation ' \
-                   'in yaml file should be configured as eval_dataloader property is NOT set!'
+            assert eval_dataloader_cfg is not None, (
+                "dataloader field of evaluation "
+                "in yaml file should be configured as eval_dataloader property is NOT set!"
+            )
 
             self._eval_dataloader = create_dataloader(self.framework, eval_dataloader_cfg)
 
@@ -261,44 +277,42 @@ class Distillation(Component):
                 self.create_criterion()
             self.create_optimizer()
             if self._train_dataloader is not None:
-                self._train_func = create_train_func(self.framework, \
-                                                     self.train_dataloader, \
-                                                     self.adaptor, \
-                                                     self._train_cfg, \
-                                                     hooks=self.hooks)
+                self._train_func = create_train_func(
+                    self.framework, self.train_dataloader, self.adaptor, self._train_cfg, hooks=self.hooks
+                )
         if self.cfg.evaluation and self.eval_dataloader and self._eval_func is None:
             # eval section in yaml file should be configured.
             eval_cfg = self.cfg.evaluation
-            assert eval_cfg, "eval field of distillation section in yaml file must " \
-                             "be configured for distillation if eval_func is NOT set."
-            self._eval_func = create_eval_func(self.framework,
-                                               self.eval_dataloader,
-                                               self.adaptor,
-                                               eval_cfg.accuracy.metric,
-                                               eval_cfg.accuracy.postprocess,
-                                               fp32_baseline=False)
+            assert eval_cfg, (
+                "eval field of distillation section in yaml file must "
+                "be configured for distillation if eval_func is NOT set."
+            )
+            self._eval_func = create_eval_func(
+                self.framework,
+                self.eval_dataloader,
+                self.adaptor,
+                eval_cfg.accuracy.metric,
+                eval_cfg.accuracy.postprocess,
+                fp32_baseline=False,
+            )
 
     def execute(self):
         """Do distillation pipeline.
 
-        First train the student model with the teacher model, after training, 
+        First train the student model with the teacher model, after training,
         evaluating the best student model if any.
 
         Returns:
             Best distilled model found.
         """
-        self._train_func(
-            self._model if getattr(self._train_func, 'builtin', None) else self._model.model
-        )
-        if self.criterion is not None and hasattr(self.criterion, 'remove_all_hooks'):
+        self._train_func(self._model if getattr(self._train_func, "builtin", None) else self._model.model)
+        if self.criterion is not None and hasattr(self.criterion, "remove_all_hooks"):
             self.criterion.remove_all_hooks()
         logger.info("Model distillation is done.")
         if self._eval_func is not None:
             logger.info("Start to evaluate the distilled model.")
             self._model = self.best_model if self.best_model else self._model
-            score = self._eval_func(
-                self._model if getattr(self._eval_func, 'builtin', None) else self._model.model
-            )
+            score = self._eval_func(self._model if getattr(self._eval_func, "builtin", None) else self._model.model)
 
             logger.info("distilled model score is {}.".format(str(score)))
         return self._model
@@ -308,10 +322,10 @@ class Distillation(Component):
 
         Register necessary hooks for distillation pipeline.
         """
-        self.register_hook('on_train_begin', self._on_train_begin)
-        self.register_hook('on_step_begin', self._on_step_begin)
-        self.register_hook('on_after_compute_loss', self._on_after_compute_loss)
-        self.register_hook('on_epoch_end', self._on_epoch_end)
+        self.register_hook("on_train_begin", self._on_train_begin)
+        self.register_hook("on_step_begin", self._on_step_begin)
+        self.register_hook("on_after_compute_loss", self._on_after_compute_loss)
+        self.register_hook("on_epoch_end", self._on_epoch_end)
 
     def __call__(self):
         """Do distillation workflow.
@@ -334,7 +348,7 @@ class Distillation(Component):
               After that, User specifies fp32 "model", training dataset "train_dataloader"
               and evaluation dataset "eval_dataloader".
 
-              For this usage, student_model, teacher_model, train_dataloader and eval_dataloader 
+              For this usage, student_model, teacher_model, train_dataloader and eval_dataloader
               parameters are mandatory.
 
            c) Partial yaml configuration: User specifies dataloaders used in training phase
@@ -345,12 +359,11 @@ class Distillation(Component):
               The "eval_func" tells the tuner whether the distilled model meets
               the accuracy criteria. If not, the Tuner starts a new training and tuning flow.
 
-              For this usage, student_model, teacher_model, train_dataloader and eval_func 
+              For this usage, student_model, teacher_model, train_dataloader and eval_func
               parameters are mandatory.
 
         Returns:
             distilled model: best distilled model found, otherwise return None
-
         """
         return super(Distillation, self).__call__()
 
@@ -368,8 +381,8 @@ class Distillation(Component):
     @criterion.setter
     def criterion(self, user_criterion):
         """Setter of criterion used in the distillation process.
-        
-        Set the user defined criterion. When using built-in train_func, user can 
+
+        Set the user defined criterion. When using built-in train_func, user can
         specify the customized criterion through this setter.
 
         Args:
@@ -389,8 +402,8 @@ class Distillation(Component):
     @optimizer.setter
     def optimizer(self, user_optimizer):
         """Setter of optimizer used in the distillation process.
-        
-        Set the user defined optimizer. When using built-in train_func, user can 
+
+        Set the user defined optimizer. When using built-in train_func, user can
         specify the customized optimizer through this setter.
 
         Args:
@@ -423,7 +436,6 @@ class Distillation(Component):
                        Another corner case is slim model of tensorflow,
                        be careful of the name of model configured in yaml file,
                        make sure the name is in supported slim model list.
-
         """
         if not isinstance(user_model, BaseModel):
             logger.warning("Force convert framework model to neural_compressor model.")
@@ -456,7 +468,6 @@ class Distillation(Component):
                        Another corner case is slim model of tensorflow,
                        be careful of the name of model configured in yaml file,
                        make sure the name is in supported slim model list.
-
         """
         if not isinstance(user_model, BaseModel):
             logger.warning("Force convert framework model to neural_compressor model.")
@@ -495,4 +506,4 @@ class Distillation(Component):
 
     def __repr__(self):
         """Class representation."""
-        return 'Distillation'
+        return "Distillation"
