@@ -19,23 +19,26 @@
 import os
 import pickle
 import random
-import tempfile
 import sys
+import tempfile
+
 import numpy as np
 import yaml
+
 from ..conf.config import Graph_Optimization_Conf
-from ..conf.dotdict import deep_get, deep_set, DotDict
-from ..strategy import STRATEGIES
+from ..conf.dotdict import DotDict, deep_get, deep_set
+from ..model import BaseModel
+from ..model.model import get_model_fwk_name
 from ..utils import logger
 from ..utils.create_obj_from_config import create_dataloader
 from ..utils.utility import CpuInfo, time_limit
 from .common import Model as NCModel
-from ..model import BaseModel
-from ..model.model import get_model_fwk_name
+from .strategy import EXP_STRATEGIES
 
-class Graph_Optimization(): 
+
+class Graph_Optimization:
     """Graph_Optimization class.
-        
+
     automatically searches for optimal quantization recipes for low
     precision model inference, achieving best tuning objectives like inference performance
     within accuracy loss constraints.
@@ -59,7 +62,7 @@ class Graph_Optimization():
         self._model = None
         self._eval_dataloader = None
         self._eval_func = None
-        self._precisions = 'fp32'
+        self._precisions = "fp32"
         self._input = []
         self._output = []
         self.conf = None
@@ -69,10 +72,10 @@ class Graph_Optimization():
         else:
             self.conf = Graph_Optimization_Conf(conf_fname_or_obj)
         cfg = self.conf.usr_cfg
-        if cfg.model.framework != 'NA':
+        if cfg.model.framework != "NA":
             self.framework = cfg.model.framework.lower()
 
-        cfg.tuning.strategy.name = 'automixedprecision'
+        cfg.tuning.strategy.name = "automixedprecision"
         seed = cfg.tuning.random_seed
         random.seed(seed)
         np.random.seed(seed)
@@ -107,22 +110,24 @@ class Graph_Optimization():
             The "eval_func" tells the tuner whether the converted model meets
             the accuracy criteria. If not, the Tuner starts a new calibration and tuning flow.
             For this usage, model, calib_dataloader and eval_func parameters are mandatory.
-        
+
         Returns:
             converted model: best converted model found, otherwise return None
         """
-        assert isinstance(self._model, BaseModel), 'need set your Model for quantization....'
+        assert isinstance(self._model, BaseModel), "need set your Model for quantization...."
 
         cfg = self.conf.usr_cfg
-        if self.framework == 'tensorflow':
+        if self.framework == "tensorflow":
             self._model.name = cfg.model.name
             self._model.output_tensor_names = cfg.model.outputs
             self._model.input_tensor_names = cfg.model.inputs
             self._model.workspace_path = cfg.tuning.workspace.path
 
-            if 'bf16' in self._precisions or \
-               (cfg.mixed_precision and 'bf16' in cfg.mixed_precision.precisions) or \
-               (cfg.graph_optimization and 'bf16' in cfg.graph_optimization.precisions):
+            if (
+                "bf16" in self._precisions
+                or (cfg.mixed_precision and "bf16" in cfg.mixed_precision.precisions)
+                or (cfg.graph_optimization and "bf16" in cfg.graph_optimization.precisions)
+            ):
                 cfg.use_bf16 = True
         else:
             logger.warning("Only TensorFlow graph optimization is supported at current stage.")
@@ -131,7 +136,7 @@ class Graph_Optimization():
         # when eval_func is set, will be directly used and eval_dataloader can be None
         if self._eval_func is None:
             if self._eval_dataloader is None:
-                eval_dataloader_cfg = deep_get(cfg, 'evaluation.accuracy.dataloader')
+                eval_dataloader_cfg = deep_get(cfg, "evaluation.accuracy.dataloader")
                 if eval_dataloader_cfg is None:
                     self._eval_func = None
                 else:
@@ -139,27 +144,26 @@ class Graph_Optimization():
 
         strategy = cfg.tuning.strategy.name.lower()
 
-        assert strategy in STRATEGIES, "Tuning strategy {} is NOT supported".format(strategy)
+        assert strategy in EXP_STRATEGIES, "Tuning strategy {} is NOT supported".format(strategy)
 
         _resume = None
         # check if interrupted tuning procedure exists. if yes, it will resume the
         # whole auto tune process.
-        self.resume_file = os.path.abspath(os.path.expanduser(cfg.tuning.workspace.resume)) \
-                           if cfg.tuning.workspace and cfg.tuning.workspace.resume else None
+        self.resume_file = (
+            os.path.abspath(os.path.expanduser(cfg.tuning.workspace.resume))
+            if cfg.tuning.workspace and cfg.tuning.workspace.resume
+            else None
+        )
         if self.resume_file:
-            assert os.path.exists(self.resume_file), \
-                "The specified resume file {} doesn't exist!".format(self.resume_file)
-            with open(self.resume_file, 'rb') as f:
+            assert os.path.exists(self.resume_file), "The specified resume file {} doesn't exist!".format(
+                self.resume_file
+            )
+            with open(self.resume_file, "rb") as f:
                 _resume = pickle.load(f).__dict__
 
-        self.strategy = STRATEGIES[strategy](
-            self._model,
-            self.conf,
-            None,
-            None,
-            self._eval_dataloader,
-            self._eval_func,
-            _resume)
+        self.strategy = EXP_STRATEGIES[strategy](
+            self._model, self.conf, None, None, self._eval_dataloader, self._eval_func, _resume
+        )
 
         try:
             with time_limit(self.conf.usr_cfg.tuning.exit_policy.timeout):
@@ -168,19 +172,20 @@ class Graph_Optimization():
             pass
         except Exception as e:
             logger.info("Unexpected exception {} happened during turing.".format(repr(e)))
-        finally: 
+        finally:
             if self.strategy.best_qmodel:
                 logger.info(
                     "Specified timeout or max trials is reached! "
-                    "Found a converted model which meet accuracy goal. Exit.")
+                    "Found a converted model which meet accuracy goal. Exit."
+                )
                 self.strategy.deploy_config()
             else:
                 logger.info(
                     "Specified timeout or max trials is reached! "
-                    "Not found any converted model which meet accuracy goal. Exit.")
+                    "Not found any converted model which meet accuracy goal. Exit."
+                )
 
-            logger.info("Graph optimization is done. Please invoke model.save() to save " \
-                        "optimized model to disk.")
+            logger.info("Graph optimization is done. Please invoke model.save() to save " "optimized model to disk.")
 
             return self.strategy.best_qmodel
 
@@ -189,29 +194,32 @@ class Graph_Optimization():
     def dataset(self, dataset_type, *args, **kwargs):
         """Get dataset."""
         from .data import Datasets
+
         return Datasets(self.framework)[dataset_type](*args, **kwargs)
 
     def set_config_by_model(self, model_obj):
         """Set model config."""
-        if model_obj.framework() != 'tensorflow':
+        if model_obj.framework() != "tensorflow":
             logger.warning("Only TensorFlow graph optimization is supported at current stage.")
             sys.exit(0)
         self.conf.usr_cfg.model.framework = model_obj.framework()
 
-        if self._precisions == ['bf16'] and not CpuInfo().bf16:
-            if os.getenv('FORCE_BF16') == '1':
-                logger.warning("Graph optimization will generate bf16 graph although " \
-                               "the hardware doesn't support bf16 instruction.")
+        if self._precisions == ["bf16"] and not CpuInfo().bf16:
+            if os.getenv("FORCE_BF16") == "1":
+                logger.warning(
+                    "Graph optimization will generate bf16 graph although "
+                    "the hardware doesn't support bf16 instruction."
+                )
             else:
-                logger.warning("Graph optimization exits due to the hardware " \
-                               "doesn't support bf16 instruction.")
+                logger.warning("Graph optimization exits due to the hardware " "doesn't support bf16 instruction.")
                 sys.exit(0)
 
-        self.conf.usr_cfg.graph_optimization.precisions = self._precisions if \
-            isinstance(self._precisions, list) else [self._precisions]
+        self.conf.usr_cfg.graph_optimization.precisions = (
+            self._precisions if isinstance(self._precisions, list) else [self._precisions]
+        )
         self.conf.usr_cfg.model.inputs = self._input
-        if isinstance(self._output, str) and ',' in self._output:
-            self.conf.usr_cfg.model.outputs = [s.strip() for s in self._output.split(',')]
+        if isinstance(self._output, str) and "," in self._output:
+            self.conf.usr_cfg.model.outputs = [s.strip() for s in self._output.split(",")]
         else:
             self.conf.usr_cfg.model.outputs = self._output
 
@@ -225,8 +233,7 @@ class Graph_Optimization():
         if isinstance(customized_precisions, list):
             self._precisions = sorted([i.strip() for i in customized_precisions])
         elif isinstance(customized_precisions, str):
-            self._precisions = sorted([i.strip() for i in customized_precisions.split(',')])
-
+            self._precisions = sorted([i.strip() for i in customized_precisions.split(",")])
 
     @property
     def input(self):
@@ -255,11 +262,11 @@ class Graph_Optimization():
     def eval_dataloader(self, dataloader):
         """Set Data loader for evaluation.
 
-        It is iterable and the batched data should consists of a tuple like (input, label), 
-        when eval_dataloader is set, user should configure postprocess(optional) and metric 
-        in yaml file or set postprocess and metric cls. Notice evaluation dataloader will be 
+        It is iterable and the batched data should consists of a tuple like (input, label),
+        when eval_dataloader is set, user should configure postprocess(optional) and metric
+        in yaml file or set postprocess and metric cls. Notice evaluation dataloader will be
         used to generate data for model inference, make sure the input data can be feed to model.
-        
+
         Args:
             dataloader(generator): user are supported to set a user defined dataloader
                                     which meet the requirements that can yield tuple of
@@ -272,12 +279,12 @@ class Graph_Optimization():
                                     a 'real' eval_dataloader will be created,
                                     the reason is we have to know the framework info
                                     and only after the Quantization object created then
-                                    framework infomation can be known. Future we will support
+                                    framework information can be known. Future we will support
                                     creating iterable dataloader from neural_compressor.common.DataLoader
         """
         from .common import _generate_common_dataloader
-        self._eval_dataloader = _generate_common_dataloader(
-            dataloader, self.framework)
+
+        self._eval_dataloader = _generate_common_dataloader(dataloader, self.framework)
 
     @property
     def model(self):
@@ -287,7 +294,7 @@ class Graph_Optimization():
     @model.setter
     def model(self, user_model):
         """Set the user model and dispatch to framework specific internal model object.
-        
+
         Args:
            user_model: user are supported to set model from original framework model format
                        (eg, tensorflow frozen_pb or path to a saved model), but not recommended.
@@ -300,7 +307,7 @@ class Graph_Optimization():
         """
         if not isinstance(user_model, BaseModel):
             logger.warning("Force convert framework model to neural_compressor model.")
-            if self.conf.usr_cfg.model.framework == 'NA':
+            if self.conf.usr_cfg.model.framework == "NA":
                 self.framework = get_model_fwk_name(user_model)
                 if self.framework == "pytorch":
                     if self.conf.usr_cfg.model.backend == "default":
@@ -313,20 +320,21 @@ class Graph_Optimization():
             else:
                 self._model = NCModel(user_model, framework=self.framework)
         else:
-            assert self.conf.usr_cfg.model.framework != 'NA', \
-                "Please pass an original framework model but not neural compressor model!"
+            assert (
+                self.conf.usr_cfg.model.framework != "NA"
+            ), "Please pass an original framework model but not neural compressor model!"
             self._model = user_model
 
     @property
     def metric(self):
         """Get metric."""
-        assert False, 'Should not try to get the value of `metric` attribute.'
+        assert False, "Should not try to get the value of `metric` attribute."
         return None
 
     @metric.setter
     def metric(self, user_metric):
         """Set metric class.
-        
+
         neural_compressor will initialize this class when evaluation
         neural_compressor have many built-in metrics, but user can set specific metric through
         this api. The metric class should take the outputs of the model or
@@ -334,7 +342,7 @@ class Graph_Optimization():
         (predictions, labels) as inputs for update,
         and user_metric.metric_cls should be sub_class of neural_compressor.metric.BaseMetric
         or user defined metric object
-        
+
         Args:
             user_metric(neural_compressor.common.Metric): user_metric should be object initialized from
                                              neural_compressor.common.Metric, in this method the
@@ -342,21 +350,23 @@ class Graph_Optimization():
                                              specific frameworks and initialized.
         """
         if deep_get(self.conf.usr_cfg, "evaluation.accuracy.metric"):
-            logger.warning("Override the value of `metric` field defined in yaml file" \
-                           " as user defines the value of `metric` attribute by code.")
- 
-        from .common import Metric as NCMetric
+            logger.warning(
+                "Override the value of `metric` field defined in yaml file"
+                " as user defines the value of `metric` attribute by code."
+            )
+
         from ..metric import METRICS
+        from .common import Metric as NCMetric
+
         if isinstance(user_metric, NCMetric):
             name = user_metric.name
             metric_cls = user_metric.metric_cls
             metric_cfg = {name: {**user_metric.kwargs}}
         else:
-            for i in ['reset', 'update', 'result']:
-                assert hasattr(user_metric, i), 'Please realise {} function' \
-                                                'in user defined metric'.format(i)
+            for i in ["reset", "update", "result"]:
+                assert hasattr(user_metric, i), "Please realise {} function" "in user defined metric".format(i)
             metric_cls = type(user_metric).__name__
-            name = 'user_' + metric_cls
+            name = "user_" + metric_cls
             metric_cfg = {name: id(user_metric)}
 
         deep_set(self.conf.usr_cfg, "evaluation.accuracy.metric", metric_cfg)
@@ -368,7 +378,7 @@ class Graph_Optimization():
     @property
     def postprocess(self, user_postprocess):
         """Get postprocess."""
-        assert False, 'Should not try to get the value of `postprocess` attribute.'
+        assert False, "Should not try to get the value of `postprocess` attribute."
         return None
 
     @postprocess.setter
@@ -379,34 +389,39 @@ class Graph_Optimization():
         The postprocess class should take the outputs of the model as inputs, and
         output (predictions, labels) as inputs for metric update.
         user_postprocess.postprocess_cls should be sub_class of neural_compressor.data.BaseTransform.
-        
+
         Args:
-            user_postprocess(neural_compressor.common.Postprocess): user_postprocess should be object 
-                initialized from neural_compressor.common.Postprocess, in this method the 
+            user_postprocess(neural_compressor.common.Postprocess): user_postprocess should be object
+                initialized from neural_compressor.common.Postprocess, in this method the
                 user_postprocess.postprocess_cls will be registered to specific frameworks and initialized.
         """
         from neural_compressor.data import Postprocess as NCPostprocess
-        assert isinstance(user_postprocess, NCPostprocess), \
-            'please initialize a neural_compressor.common.Postprocess and set....'
-        postprocess_cfg = {user_postprocess.name : {**user_postprocess.kwargs}}
+
+        assert isinstance(
+            user_postprocess, NCPostprocess
+        ), "please initialize a neural_compressor.common.Postprocess and set...."
+        postprocess_cfg = {user_postprocess.name: {**user_postprocess.kwargs}}
         if deep_get(self.conf.usr_cfg, "evaluation.accuracy.postprocess"):
-            logger.warning("Override the value of `postprocess` field defined in yaml file" \
-                           " as user defines the value of `postprocess` attribute by code.")
+            logger.warning(
+                "Override the value of `postprocess` field defined in yaml file"
+                " as user defines the value of `postprocess` attribute by code."
+            )
         deep_set(self.conf.usr_cfg, "evaluation.accuracy.postprocess.transform", postprocess_cfg)
         from neural_compressor.data import TRANSFORMS
-        postprocesses = TRANSFORMS(self.framework, 'postprocess')
+
+        postprocesses = TRANSFORMS(self.framework, "postprocess")
         postprocesses.register(user_postprocess.name, user_postprocess.postprocess_cls)
 
     @property
     def eval_func(self):
         """Get evaluation function."""
-        assert False, 'Should not try to get the value of `eval_func` attribute.'
+        assert False, "Should not try to get the value of `eval_func` attribute."
         return None
 
     @eval_func.setter
     def eval_func(self, user_eval_func):
         """Set evaluation function provided by user.
-        
+
         Args:
             user_eval_func: This function takes model as parameter,
                             and evaluation dataset and metrics should be
@@ -424,6 +439,7 @@ class Graph_Optimization():
 
     def __repr__(self):
         """Return name."""
-        return 'GraphOptimization'
+        return "GraphOptimization"
+
 
 GraphOptimization = Graph_Optimization
