@@ -1,4 +1,4 @@
-"""pruning module."""
+"""Pruning module."""
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
@@ -16,17 +16,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .component import Component
-from .pruner_legacy import PRUNERS
-from ..utils import logger
-from ..utils.utility import GLOBAL_STATE, MODE
-from ..utils.create_obj_from_config import create_dataloader, create_train_func, create_eval_func
-from ..model import BaseModel
+from deprecated import deprecated
+
 from ..adaptor import FRAMEWORKS
 from ..conf.config import PruningConf
 from ..conf.pythonic_config import Config
-
-from deprecated import deprecated
+from ..model import BaseModel
+from ..utils import logger
+from ..utils.create_obj_from_config import create_dataloader, create_eval_func, create_train_func
+from ..utils.utility import GLOBAL_STATE, MODE
+from .component import Component
+from .pruner_legacy import PRUNERS
 
 
 class Pruning(Component):
@@ -45,11 +45,10 @@ class Pruning(Component):
     Attributes:
         conf: A config dict object. Contains pruning setting parameters.
         pruners: A list of Pruner object.
-
     """
 
     def __init__(self, conf_fname_or_obj=None):
-        """Initiailize."""
+        """Initialize."""
         super(Pruning, self).__init__()
         if isinstance(conf_fname_or_obj, PruningConf):
             self.conf = conf_fname_or_obj
@@ -66,7 +65,7 @@ class Pruning(Component):
     def update_items_for_all_pruners(self, **kwargs):
         """Functions which add User-defined arguments to the original configurations.
 
-        The original config of pruning is read from a file. 
+        The original config of pruning is read from a file.
         However, users can still modify configurations by passing key-value arguments in this function.
         Please note that the key-value arguments' keys are analysable in current configuration.
         """
@@ -142,19 +141,20 @@ class Pruning(Component):
 
     def pre_process(self):
         """Functions called before pruning begins, usually set up pruners."""
-        assert isinstance(self._model, BaseModel), 'need set neural_compressor Model for pruning....'
+        assert isinstance(self._model, BaseModel), "need set neural_compressor Model for pruning...."
 
         GLOBAL_STATE.STATE = MODE.PRUNING
-        framework_specific_info = {'device': self.cfg.device,
-                                   'random_seed': self.cfg.tuning.random_seed,
-                                   'workspace_path': self.cfg.tuning.workspace.path,
-                                   'q_dataloader': None,
-                                   'format': 'default',
-                                   'backend': 'default'}
+        framework_specific_info = {
+            "device": self.cfg.device,
+            "random_seed": self.cfg.tuning.random_seed,
+            "workspace_path": self.cfg.tuning.workspace.path,
+            "q_dataloader": None,
+            "format": "default",
+            "backend": "default",
+        }
 
-        if self.framework == 'tensorflow':
-            framework_specific_info.update(
-                {"inputs": self.cfg.model.inputs, "outputs": self.cfg.model.outputs})
+        if self.framework == "tensorflow":
+            framework_specific_info.update({"inputs": self.cfg.model.inputs, "outputs": self.cfg.model.outputs})
 
         self.adaptor = FRAMEWORKS[self.framework](framework_specific_info)
 
@@ -162,44 +162,53 @@ class Pruning(Component):
 
         if self._train_dataloader is None and self._train_func is None:
             train_dataloader_cfg = self.cfg.pruning.train.dataloader
-            assert train_dataloader_cfg is not None, \
-                   'dataloader field of train field of pruning section ' \
-                   'in yaml file should be configured as train_dataloader property is NOT set!'
+            assert train_dataloader_cfg is not None, (
+                "dataloader field of train field of pruning section "
+                "in yaml file should be configured as train_dataloader property is NOT set!"
+            )
             train_dataloader_cfg.distributed = self.train_distributed
             self._train_dataloader = create_dataloader(self.framework, train_dataloader_cfg)
 
         if self._eval_dataloader is None and self._eval_func is None:
             eval_dataloader_cfg = self.cfg.evaluation.accuracy.dataloader
-            assert eval_dataloader_cfg is not None, \
-                   'dataloader field of evaluation ' \
-                   'in yaml file should be configured as eval_dataloader property is NOT set!'
+            assert eval_dataloader_cfg is not None, (
+                "dataloader field of evaluation "
+                "in yaml file should be configured as eval_dataloader property is NOT set!"
+            )
             eval_dataloader_cfg.distributed = self.evaluation_distributed
             self._eval_dataloader = create_dataloader(self.framework, eval_dataloader_cfg)
 
         if self._train_func is None:
             # train section of pruning section in yaml file should be configured.
             train_cfg = self.cfg.pruning.train
-            assert train_cfg, "train field of pruning section in yaml file must " \
-                              "be configured for pruning if pruning_func is NOT set."
-            self._train_func = create_train_func(self.framework, \
-                                                   self.train_dataloader, \
-                                                   self.adaptor, \
-                                                   train_cfg, \
-                                                   hooks=self.hooks, \
-                                                   callbacks=self.callbacks)
+            assert train_cfg, (
+                "train field of pruning section in yaml file must "
+                "be configured for pruning if pruning_func is NOT set."
+            )
+            self._train_func = create_train_func(
+                self.framework,
+                self.train_dataloader,
+                self.adaptor,
+                train_cfg,
+                hooks=self.hooks,
+                callbacks=self.callbacks,
+            )
         if self._eval_func is None:
             # eval section in yaml file should be configured.
             eval_cfg = self.cfg.evaluation
-            assert eval_cfg, "eval field of pruning section in yaml file must " \
-                              "be configured for pruning if eval_func is NOT set."
-            self._eval_func = create_eval_func(self.framework, \
-                                               self.eval_dataloader, \
-                                               self.adaptor, \
-                                               eval_cfg.accuracy.metric, \
-                                               eval_cfg.accuracy.postprocess, \
-                                               fp32_baseline = False)
-        if getattr(self.train_dataloader, 'distributed', False):
-            self.register_hook('on_train_begin', self.adaptor._pre_hook_for_hvd)
+            assert eval_cfg, (
+                "eval field of pruning section in yaml file must " "be configured for pruning if eval_func is NOT set."
+            )
+            self._eval_func = create_eval_func(
+                self.framework,
+                self.eval_dataloader,
+                self.adaptor,
+                eval_cfg.accuracy.metric,
+                eval_cfg.accuracy.postprocess,
+                fp32_baseline=False,
+            )
+        if getattr(self.train_dataloader, "distributed", False):
+            self.register_hook("on_train_begin", self.adaptor._pre_hook_for_hvd)
 
     def execute(self):
         """Functions that execute the pruning process.
@@ -207,70 +216,71 @@ class Pruning(Component):
         Follow the working flow: evaluate the dense model -> train/prune the model, evaluate the sparse model.
         """
         logger.info("Start to get the baseline model's score before pruning.")
-        self.baseline_score = self._eval_func(self._model if getattr(self._eval_func, 'builtin', None) \
-                        else self._model.model)
+        self.baseline_score = self._eval_func(
+            self._model if getattr(self._eval_func, "builtin", None) else self._model.model
+        )
         logger.info("Baseline model's score is {}.".format(str(self.baseline_score)))
         logger.info("Model pruning begins.")
-        self._train_func(self._model if getattr(self._train_func, 'builtin', None) \
-                        else self._model.model)
+        self._train_func(self._model if getattr(self._train_func, "builtin", None) else self._model.model)
         logger.info("Model pruning is done. Start to evaluate the pruned model.")
-        self.last_score = self._eval_func(self._model if getattr(self._eval_func, 'builtin', None) \
-                        else self._model.model)
+        self.last_score = self._eval_func(
+            self._model if getattr(self._eval_func, "builtin", None) else self._model.model
+        )
         logger.info("Pruned model score is {}.".format(str(self.last_score)))
         return self._model
 
     def generate_hooks(self):
         """Register hooks for pruning."""
-        self.register_hook('on_train_begin', self._on_train_begin)
-        self.register_hook('on_train_end', self._on_train_end)
-        self.register_hook('on_epoch_begin', self._on_epoch_begin)
-        self.register_hook('on_epoch_end', self._on_epoch_end)
-        self.register_hook('on_step_begin', self._on_step_begin)
-        self.register_hook('on_step_end', self._on_step_end)
-        self.register_hook('on_before_optimizer_step', self._on_before_optimizer_step)
-        self.register_hook('on_after_optimizer_step', self._on_after_optimizer_step)
-        self.register_hook('on_before_eval', self._on_before_eval)
-        self.register_hook('on_after_eval', self._on_after_eval)
+        self.register_hook("on_train_begin", self._on_train_begin)
+        self.register_hook("on_train_end", self._on_train_end)
+        self.register_hook("on_epoch_begin", self._on_epoch_begin)
+        self.register_hook("on_epoch_end", self._on_epoch_end)
+        self.register_hook("on_step_begin", self._on_step_begin)
+        self.register_hook("on_step_end", self._on_step_end)
+        self.register_hook("on_before_optimizer_step", self._on_before_optimizer_step)
+        self.register_hook("on_after_optimizer_step", self._on_after_optimizer_step)
+        self.register_hook("on_before_eval", self._on_before_eval)
+        self.register_hook("on_after_eval", self._on_after_eval)
 
     def generate_pruners(self):
         """Functions that generate pruners and set up self.pruners."""
         for name in self.cfg.pruning.approach:
-            assert name == 'weight_compression' or name == "weight_compression_pytorch", \
-                'now we only support weight_compression and weight_compression_pytorch'
+            assert (
+                name == "weight_compression" or name == "weight_compression_pytorch"
+            ), "now we only support weight_compression and weight_compression_pytorch"
 
-            if self.cfg.pruning.approach.weight_compression_pytorch != None:
+            if self.cfg.pruning.approach.weight_compression_pytorch is not None:
                 from .pytorch_pruner.pruning import Pruning as PytorchPruning
+
                 self.pytorch_pruner = PytorchPruning(self.cfg)
-                self.pytorch_pruner.model = self.model._model # extract their pytorch model
+                self.pytorch_pruner.model = self.model._model  # extract their pytorch model
                 self.pytorch_pruner.prepare()
                 self.pytorch_pruner.on_train_begin()
                 self.pruners += self.pytorch_pruner.pruners
 
-            if self.cfg.pruning.approach.weight_compression != None:
+            if self.cfg.pruning.approach.weight_compression is not None:
                 for pruner in self.cfg.pruning.approach.weight_compression.pruners:
-                    if pruner.prune_type == 'basic_magnitude':
-                        self.pruners.append(PRUNERS['BasicMagnitude'](\
-                                                self._model, \
-                                                pruner,
-                                                self.cfg.pruning.approach.weight_compression))
-                    elif pruner.prune_type == 'pattern_lock':
-                        self.pruners.append(PRUNERS['PatternLock'](\
-                                                self._model, \
-                                                pruner,
-                                                self.cfg.pruning.approach.weight_compression))
-                    elif pruner.prune_type == 'gradient_sensitivity':
-                        self.pruners.append(PRUNERS['GradientSensitivity'](\
-                                                self._model, \
-                                                pruner,
-                                                self.cfg.pruning.approach.weight_compression))
-                    elif pruner.prune_type == 'group_lasso':
-                        self.pruners.append(PRUNERS['GroupLasso'](\
-                                                self._model, \
-                                                pruner,
-                                                self.cfg.pruning.approach.weight_compression))
+                    if pruner.prune_type == "basic_magnitude":
+                        self.pruners.append(
+                            PRUNERS["BasicMagnitude"](self._model, pruner, self.cfg.pruning.approach.weight_compression)
+                        )
+                    elif pruner.prune_type == "pattern_lock":
+                        self.pruners.append(
+                            PRUNERS["PatternLock"](self._model, pruner, self.cfg.pruning.approach.weight_compression)
+                        )
+                    elif pruner.prune_type == "gradient_sensitivity":
+                        self.pruners.append(
+                            PRUNERS["GradientSensitivity"](
+                                self._model, pruner, self.cfg.pruning.approach.weight_compression
+                            )
+                        )
+                    elif pruner.prune_type == "group_lasso":
+                        self.pruners.append(
+                            PRUNERS["GroupLasso"](self._model, pruner, self.cfg.pruning.approach.weight_compression)
+                        )
                     else:
                         ##print(pruner.prune_type)
-                        assert False, 'now only support {}'.format(PRUNERS.keys())
+                        assert False, "now only support {}".format(PRUNERS.keys())
 
     def __call__(self):
         """Entry point of pruning.
@@ -307,7 +317,6 @@ class Pruning(Component):
 
         Returns:
             pruned model: best pruned model found, otherwise return None
-
         """
         return super(Pruning, self).__call__()
 
@@ -317,11 +326,11 @@ class Pruning(Component):
     @property
     def pruning_func(self):
         """Not support get pruning_func."""
-        assert False, 'Should not try to get the value of `pruning_func` attribute.'
+        assert False, "Should not try to get the value of `pruning_func` attribute."
         return None
 
     @pruning_func.setter
-    @deprecated(version='2.0', reason="please use `train_func` instead")
+    @deprecated(version="2.0", reason="please use `train_func` instead")
     def pruning_func(self, user_pruning_func):
         """Training function for pruning.
 
@@ -339,7 +348,7 @@ class Pruning(Component):
     def evaluation_distributed(self):
         """Getter to know whether need distributed evaluation dataloader."""
         eval_dataloader_cfg = self.cfg.evaluation.accuracy.dataloader
-        yaml_distributed = eval_dataloader_cfg.get('distributed', False)
+        yaml_distributed = eval_dataloader_cfg.get("distributed", False)
         return self._evaluation_distributed or yaml_distributed
 
     @evaluation_distributed.setter
@@ -351,7 +360,7 @@ class Pruning(Component):
     def train_distributed(self):
         """Getter to know whether need distributed training dataloader."""
         train_dataloader_cfg = self.cfg.pruning.train.dataloader
-        yaml_distributed = train_dataloader_cfg.get('distributed', False)
+        yaml_distributed = train_dataloader_cfg.get("distributed", False)
         return self._train_distributed or yaml_distributed
 
     @train_distributed.setter
@@ -361,7 +370,7 @@ class Pruning(Component):
 
     def __repr__(self):
         """Return the class's string representation."""
-        return 'Pruning'
+        return "Pruning"
 
     def get_sparsity_ratio(self):
         """Functions that calculate a modules/layers sparsity.
@@ -373,6 +382,7 @@ class Pruning(Component):
             blockwise_over_matmul_gemm_conv refers to all-zero blocks' ratio in pruning layers.
         """
         import torch
+
         pattern_sparsity_cnt = 0
         element_sparsity_cnt = 0
         for pruner in self.pruners:
@@ -395,8 +405,7 @@ class Pruning(Component):
             param_cnt += param.numel()
         blockwise_over_matmul_gemm_conv = float(pattern_sparsity_cnt) / linear_conv_cnt
         elementwise_over_matmul_gemm_conv = float(element_sparsity_cnt) / linear_conv_cnt
-        elementwise_over_all = float(
-            element_sparsity_cnt) / param_cnt
+        elementwise_over_all = float(element_sparsity_cnt) / param_cnt
 
         return elementwise_over_matmul_gemm_conv, elementwise_over_all, blockwise_over_matmul_gemm_conv
 
@@ -429,18 +438,18 @@ class TfPruningCallback(object):
 
     def on_train_begin(self, logs=None, dataloader=None):
         """Call the same-name function from hooks."""
-        self.hooks['on_train_begin'](dataloader)
+        self.hooks["on_train_begin"](dataloader)
 
     def on_train_end(self, logs=None):
         """Call the same-name function from hooks."""
-        self.hooks['on_train_end']()
+        self.hooks["on_train_end"]()
 
-    @deprecated(version='2.0', reason="please use `on_train_begin` instead")
+    @deprecated(version="2.0", reason="please use `on_train_begin` instead")
     def pre_epoch_begin(self, logs=None, dataloader=None):  # pragma: no cover
         """Call the same-name function from hooks."""
         self.on_train_begin(logs, dataloader)
 
-    @deprecated(version='2.0', reason="please use `on_train_end` instead")
+    @deprecated(version="2.0", reason="please use `on_train_end` instead")
     def post_epoch_end(self, logs=None):  # pragma: no cover
         """Call the same-name function from hooks."""
         self.on_train_end(logs)
@@ -448,12 +457,12 @@ class TfPruningCallback(object):
     def on_epoch_begin(self, epoch, logs=None):
         """Call the same-name function from hooks."""
         self._set_weights()
-        self.hooks['on_epoch_begin'](epoch)
+        self.hooks["on_epoch_begin"](epoch)
 
     def on_epoch_end(self, logs=None):
         """Call the same-name function from hooks."""
         self._set_weights()
-        res = self.hooks['on_epoch_end']()
+        res = self.hooks["on_epoch_end"]()
         for layer_index, weights in res[0][0].items():
             get_weights = self.model.layers[layer_index].get_weights()
             get_weights[0] = weights
@@ -462,32 +471,31 @@ class TfPruningCallback(object):
     def on_step_begin(self, batch, logs=None):
         """Call the same-name function from hooks."""
         self._set_weights()
-        res = self.hooks['on_step_begin'](batch)
+        res = self.hooks["on_step_begin"](batch)
         for layer_index, weights in res[0][0].items():
             get_weights = self.model.layers[layer_index].get_weights()
             get_weights[0] = weights
             self.model.layers[layer_index].set_weights(get_weights)
 
-    @deprecated(version='2.0', reason="please use `on_step_begin` instead")
+    @deprecated(version="2.0", reason="please use `on_step_begin` instead")
     def on_batch_begin(self, batch, logs=None):  # pragma: no cover
         """Call the same-name function from hooks."""
         self.on_step_begin(batch, logs)
 
     def on_after_compute_loss(self, input, s_outputs, s_loss, t_outputs=None):
         """Call the same-name function from hooks."""
-        return self.hooks['on_after_compute_loss'](input, s_outputs, s_loss, t_outputs)
+        return self.hooks["on_after_compute_loss"](input, s_outputs, s_loss, t_outputs)
 
     def on_step_end(self, logs=None):
         """Call the same-name function from hooks."""
         self._set_weights()
-        res = self.hooks['on_step_end']()
+        res = self.hooks["on_step_end"]()
         for layer_index, weights in res[0][0].items():
             get_weights = self.model.layers[layer_index].get_weights()
             get_weights[0] = weights
             self.model.layers[layer_index].set_weights(get_weights)
 
-    @deprecated(version='2.0', reason="please use `on_step_end` instead")
+    @deprecated(version="2.0", reason="please use `on_step_end` instead")
     def on_batch_end(self, logs=None):  # pragma: no cover
         """Call the same-name function from hooks."""
         self.on_step_end(logs)
-
