@@ -1,4 +1,4 @@
-"""logger module."""
+"""Logger module."""
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
