@@ -1,4 +1,4 @@
-"""pruner module."""
+"""Pruner module."""
 # !/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
@@ -17,10 +17,10 @@
 # limitations under the License.
 
 import torch
-from .patterns import get_pattern
-from .scheduler import get_scheduler
 
 from .logger import logger
+from .patterns import get_pattern
+from .scheduler import get_scheduler
 
 PRUNERS = {}
 
@@ -50,15 +50,15 @@ def get_pruner(modules, config):
     """Get registered pruner class.
 
     Get a Pruner object from PRUNERS.
-    
+
     Args:
         modules: A dict {"module_name": Tensor}. Store the pruning modules' weights.
         config: A config dict object. Contains the pruner information.
 
     Returns:
         A Pruner object.
-    
-    Raises: AssertionError: Cuurently only support pruners which have been registered in PRUNERS.
+
+    Raises: AssertionError: Currently only support pruners which have been registered in PRUNERS.
     """
     name = config["prune_type"]
     if name not in PRUNERS.keys():
@@ -89,7 +89,7 @@ class Pruner:
         global_step: A integer. The total steps the model has run.
         start_step: A integer. When to trigger pruning process.
         end_step: A integer. When to end pruning process.
-        update_frequency_on_step: A integer. The pruning frequency, which's valid when iterative 
+        update_frequency_on_step: A integer. The pruning frequency, which's valid when iterative
             pruning is enabled.
         target_sparsity_ratio: A float. The final sparsity after pruning.
         max_sparsity_ratio_per_layer: A float. Sparsity ratio maximum for every module.
@@ -110,21 +110,20 @@ class Pruner:
     def _init(self):
         """Auxiliary function for initializing."""
         self.global_step = -1
-        self.start_step = self.config['start_step']
-        self.end_step = self.config['end_step']
-        self.update_frequency_on_step = self.config['update_frequency_on_step']
+        self.start_step = self.config["start_step"]
+        self.end_step = self.config["end_step"]
+        self.update_frequency_on_step = self.config["update_frequency_on_step"]
         ##this is different with original code
-        self.total_prune_cnt = (self.end_step - self.start_step + 1) \
-                               // self.update_frequency_on_step
+        self.total_prune_cnt = (self.end_step - self.start_step + 1) // self.update_frequency_on_step
         self.completed_pruned_cnt = 0
         self.masks = {}
         for key in self.modules.keys():
             module = self.modules[key]
             self.masks[key] = torch.ones(module.weight.shape).to(module.weight.device)  ##TODO support bias or others
 
-        self.target_sparsity_ratio = self.config['target_sparsity']
+        self.target_sparsity_ratio = self.config["target_sparsity"]
 
-        self.max_sparsity_ratio_per_layer = self.config['max_sparsity_ratio_per_layer']
+        self.max_sparsity_ratio_per_layer = self.config["max_sparsity_ratio_per_layer"]
 
     def on_epoch_begin(self, epoch):
         """Functions called in the beginning of each epoch."""
@@ -133,7 +132,7 @@ class Pruner:
     def mask_weights(self):
         """Functions called when masks are applied on corresponding modules' weights.
 
-        Weights are multipled with masks. This is the formal pruning process.
+        Weights are multiplied with masks. This is the formal pruning process.
         """
         with torch.no_grad():
             for key in self.modules.keys():
@@ -154,16 +153,17 @@ class Pruner:
         if self.current_sparsity_ratio > self.target_sparsity_ratio:
             return
 
-        current_target_sparsity_ratio = self.scheduler.update_sparsity_ratio(self.target_sparsity_ratio,
-                                                                             self.completed_pruned_cnt,
-                                                                             self.total_prune_cnt, self.masks)
+        current_target_sparsity_ratio = self.scheduler.update_sparsity_ratio(
+            self.target_sparsity_ratio, self.completed_pruned_cnt, self.total_prune_cnt, self.masks
+        )
         logger.info(f"current target ratio is {current_target_sparsity_ratio}")
         self.update_scores()
         self.completed_pruned_cnt += 1
         if self.scores == {}:
             return
-        self.masks = self.pattern.get_masks(self.scores, current_target_sparsity_ratio, self.masks,
-                                            self.max_sparsity_ratio_per_layer)
+        self.masks = self.pattern.get_masks(
+            self.scores, current_target_sparsity_ratio, self.masks, self.max_sparsity_ratio_per_layer
+        )
         self.mask_weights()
 
         self.current_sparsity_ratio = self.pattern.get_sparsity_ratio(self.masks)
@@ -183,12 +183,12 @@ class Pruner:
 
     def on_after_optimizer_step(self):
         """Functions called after the optimizer.step().
-        
+
         Prune the model after optimization.
         """
         self.mask_weights()
 
-    def on_train_begin(self, dataloader = None):
+    def on_train_begin(self, dataloader=None):
         """Functions called in the beginning of training."""
         pass
 
@@ -217,7 +217,7 @@ class Pruner:
         pass
 
 
-@register_pruners('magnitude')
+@register_pruners("magnitude")
 class MagnitudePruner(Pruner):
     """Pruning Pruner.
 
@@ -244,12 +244,12 @@ class MagnitudePruner(Pruner):
                 self.scores[key] = p
 
 
-@register_pruners('snip')
+@register_pruners("snip")
 class SnipPruner(Pruner):
     """Pruning Pruner.
 
     A Pruner class derived from Pruner. In this pruner, the scores are calculated based on SNIP.
-    Please refer to SNIP: Single-shot Network Pruning based on Connection Sensitivity 
+    Please refer to SNIP: Single-shot Network Pruning based on Connection Sensitivity
     (https://arxiv.org/abs/1810.02340)
 
     Args:
@@ -268,7 +268,7 @@ class SnipPruner(Pruner):
 
     def on_after_optimizer_step(self):
         """Functions called after the optimizer.step().
-        
+
         Prune the model after optimization and update the scores based on weights and gradients.
         """
         self.mask_weights()
@@ -278,7 +278,7 @@ class SnipPruner(Pruner):
                 self.scores[key] = torch.abs(p * p.grad)
 
 
-@register_pruners('snip_momentum')
+@register_pruners("snip_momentum")
 class SnipMomentumPruner(Pruner):
     """Pruning Pruner.
 
@@ -304,7 +304,7 @@ class SnipMomentumPruner(Pruner):
 
     def on_after_optimizer_step(self):
         """Functions called after the optimizer.step().
-        
+
         Prune the model after optimization and update the scores based on weights and gradients.
         """
         self.mask_weights()
@@ -315,7 +315,7 @@ class SnipMomentumPruner(Pruner):
                 self.scores[key] += 1.0 * torch.abs(p * p.grad)
 
 
-@register_pruners('pattern_lock')
+@register_pruners("pattern_lock")
 class PatternLockPruner(Pruner):
     """Pruning Pruner.
 
