@@ -20,20 +20,23 @@
 import os
 import pickle
 import random
+
 import numpy as np
-from .component import Component
-from ..conf.dotdict import deep_get, deep_set, DotDict
-from ..strategy import STRATEGIES
-from ..utils import logger
-from ..utils.utility import time_limit
-from ..utils.create_obj_from_config import create_dataloader
-from ..model import BaseModel
-from ..model.tensorflow_model import TensorflowQATModel
-from ..model.model import get_model_fwk_name
-from ..conf.config import QuantConf
-from ..conf.pythonic_config import Config
 from deprecated import deprecated
 
+from ..conf.config import QuantConf
+from ..conf.dotdict import DotDict, deep_get, deep_set
+from ..conf.pythonic_config import Config
+from ..model import BaseModel
+from ..model.model import get_model_fwk_name
+from ..model.tensorflow_model import TensorflowQATModel
+from ..utils import logger
+from ..utils.create_obj_from_config import create_dataloader
+from ..utils.utility import time_limit
+from .component import Component
+from .strategy import EXP_STRATEGIES
+
+
 class Quantization(Component):
     """This class provides easy use API for quantization.
 
@@ -51,7 +54,6 @@ class Quantization(Component):
         conf_fname_or_obj (string or obj): The path to the YAML configuration file or
             QuantConf class containing accuracy goal, tuning objective and preferred
             calibration & quantization tuning space etc.
-
     """
 
     def __init__(self, conf_fname_or_obj=None):
@@ -77,50 +79,60 @@ class Quantization(Component):
         # when eval_func is set, will be directly used and eval_dataloader can be None
         if self._eval_func is None:
             if self._eval_dataloader is None:
-                eval_dataloader_cfg = deep_get(cfg, 'evaluation.accuracy.dataloader')
+                eval_dataloader_cfg = deep_get(cfg, "evaluation.accuracy.dataloader")
                 if eval_dataloader_cfg is None:
-                    logger.info("Because both eval_dataloader_cfg and user-defined eval_func are None," \
-                        " automatically setting 'tuning.exit_policy.performance_only = True'.")
-                    deep_set(cfg, 'tuning.exit_policy.performance_only', True)
-                    logger.info("The cfg.tuning.exit_policy.performance_only is: {}".format(\
-                        cfg.tuning.exit_policy.performance_only))
+                    logger.info(
+                        "Because both eval_dataloader_cfg and user-defined eval_func are None,"
+                        " automatically setting 'tuning.exit_policy.performance_only = True'."
+                    )
+                    deep_set(cfg, "tuning.exit_policy.performance_only", True)
+                    logger.info(
+                        "The cfg.tuning.exit_policy.performance_only is: {}".format(
+                            cfg.tuning.exit_policy.performance_only
+                        )
+                    )
                 else:
-                    if deep_get(cfg, 'evaluation.accuracy.iteration') == -1 and 'dummy_v2' \
-                        in deep_get(cfg, 'evaluation.accuracy.dataloader.dataset', {}):
-                        deep_set(cfg, 'evaluation.accuracy.iteration', 10)
+                    if deep_get(cfg, "evaluation.accuracy.iteration") == -1 and "dummy_v2" in deep_get(
+                        cfg, "evaluation.accuracy.dataloader.dataset", {}
+                    ):
+                        deep_set(cfg, "evaluation.accuracy.iteration", 10)
 
-                    self._eval_dataloader = create_dataloader(self.framework, \
-                                                              eval_dataloader_cfg)
-        if os.environ.get("PERFORMANCE_ONLY") in ['0', '1']:
+                    self._eval_dataloader = create_dataloader(self.framework, eval_dataloader_cfg)
+        if os.environ.get("PERFORMANCE_ONLY") in ["0", "1"]:
             performance_only = bool(int(os.environ.get("PERFORMANCE_ONLY")))
-            deep_set(cfg, 'tuning.exit_policy.performance_only', performance_only)
-            logger.info("Get environ 'PERFORMANCE_ONLY={}'," \
-                " force setting 'tuning.exit_policy.performance_only = True'.".format(performance_only))
+            deep_set(cfg, "tuning.exit_policy.performance_only", performance_only)
+            logger.info(
+                "Get environ 'PERFORMANCE_ONLY={}',"
+                " force setting 'tuning.exit_policy.performance_only = True'.".format(performance_only)
+            )
 
     def _create_calib_dataloader(self, cfg):
         """Create default calibration dataloader if train_func is not set."""
-        approach_cfg = deep_get(cfg, 'quantization.approach')
+        approach_cfg = deep_get(cfg, "quantization.approach")
 
         if self._calib_dataloader is None and self._calib_func is None:
-            if approach_cfg in ['post_training_static_quant', 'post_training_auto_quant']:
-                calib_dataloader_cfg = deep_get(cfg, 'quantization.calibration.dataloader')
+            if approach_cfg in ["post_training_static_quant", "post_training_auto_quant"]:
+                calib_dataloader_cfg = deep_get(cfg, "quantization.calibration.dataloader")
 
-                if approach_cfg == "post_training_auto_quant" and calib_dataloader_cfg == None:
-                    logger.error("dataloader is required for 'post_training_auto_quant'. "
-                                 "use 'post_training_dynamic_quant' instead if no dataloader provided.")
-                assert calib_dataloader_cfg is not None, \
-                       'dataloader field of calibration field of quantization section ' \
-                       'in yaml file should be configured as calib_dataloader property is NOT set!'
+                if approach_cfg == "post_training_auto_quant" and calib_dataloader_cfg is None:
+                    logger.error(
+                        "dataloader is required for 'post_training_auto_quant'. "
+                        "use 'post_training_dynamic_quant' instead if no dataloader provided."
+                    )
+                assert calib_dataloader_cfg is not None, (
+                    "dataloader field of calibration field of quantization section "
+                    "in yaml file should be configured as calib_dataloader property is NOT set!"
+                )
 
-                if deep_get(calib_dataloader_cfg, 'shuffle'):
-                    logger.warning("Reset `shuffle` field to False when post_training_static_quant"
-                                   " is selected.")
-                    deep_set(calib_dataloader_cfg, 'shuffle', False)
-            elif approach_cfg == 'quant_aware_training':
-                calib_dataloader_cfg = deep_get(cfg, 'quantization.train.dataloader')
-                assert calib_dataloader_cfg is not None, \
-                       'dataloader field of train field of quantization section ' \
-                       'in yaml file should be configured as calib_dataloader property is NOT set!'
+                if deep_get(calib_dataloader_cfg, "shuffle"):
+                    logger.warning("Reset `shuffle` field to False when post_training_static_quant" " is selected.")
+                    deep_set(calib_dataloader_cfg, "shuffle", False)
+            elif approach_cfg == "quant_aware_training":
+                calib_dataloader_cfg = deep_get(cfg, "quantization.train.dataloader")
+                assert calib_dataloader_cfg is not None, (
+                    "dataloader field of train field of quantization section "
+                    "in yaml file should be configured as calib_dataloader property is NOT set!"
+                )
             else:
                 calib_dataloader_cfg = None
 
@@ -130,34 +142,38 @@ class Quantization(Component):
     def pre_process(self):
         """Prepare dataloaders, qfuncs for Component."""
         cfg = self.conf.usr_cfg
-        assert isinstance(self._model, BaseModel), 'need set your Model for quantization....'
+        assert isinstance(self._model, BaseModel), "need set your Model for quantization...."
 
         self._create_eval_dataloader(cfg)
         self._create_calib_dataloader(cfg)
         strategy = cfg.tuning.strategy.name.lower()
         if cfg.quantization.quant_level == 0:
             strategy = "conservative"
-            logger.info(f"On the premise that the accuracy meets the conditions, improve the performance.")
+            logger.info("On the premise that the accuracy meets the conditions, improve the performance.")
 
         if strategy == "mse_v2":
-            if not (self.framework.startswith("tensorflow") or self.framework == 'pytorch_fx'):
+            if not (self.framework.startswith("tensorflow") or self.framework == "pytorch_fx"):
                 strategy = "basic"
                 logger.warning(f"MSE_v2 does not support {self.framework} now, use basic instead.")
                 logger.warning("Only tensorflow, pytorch_fx is supported by MSE_v2 currently.")
-        assert strategy in STRATEGIES, "Tuning strategy {} is NOT supported".format(strategy)
+        assert strategy in EXP_STRATEGIES, "Tuning strategy {} is NOT supported".format(strategy)
 
         _resume = None
         # check if interrupted tuning procedure exists. if yes, it will resume the
         # whole auto tune process.
-        self.resume_file = os.path.abspath(os.path.expanduser(cfg.tuning.workspace.resume)) \
-                           if cfg.tuning.workspace and cfg.tuning.workspace.resume else None
+        self.resume_file = (
+            os.path.abspath(os.path.expanduser(cfg.tuning.workspace.resume))
+            if cfg.tuning.workspace and cfg.tuning.workspace.resume
+            else None
+        )
         if self.resume_file:
-            assert os.path.exists(self.resume_file), \
-                "The specified resume file {} doesn't exist!".format(self.resume_file)
-            with open(self.resume_file, 'rb') as f:
+            assert os.path.exists(self.resume_file), "The specified resume file {} doesn't exist!".format(
+                self.resume_file
+            )
+            with open(self.resume_file, "rb") as f:
                 _resume = pickle.load(f).__dict__
 
-        self.strategy = STRATEGIES[strategy](
+        self.strategy = EXP_STRATEGIES[strategy](
             self._model,
             self.conf,
             self._calib_dataloader,
@@ -165,17 +181,14 @@ class Quantization(Component):
             self._eval_dataloader,
             self._eval_func,
             _resume,
-            self.hooks)
+            self.hooks,
+        )
 
-        if getattr(self._calib_dataloader, 'distributed', False):
-            self.register_hook('on_train_begin', self.strategy.adaptor._pre_hook_for_hvd)
+        if getattr(self._calib_dataloader, "distributed", False):
+            self.register_hook("on_train_begin", self.strategy.adaptor._pre_hook_for_hvd)
 
     def execute(self):
-        """Quantization execute routinue based on strategy design."""
-        # check here the distributed flag
-        logger.info("..............use_distributed_tuning: {}".format(self.conf.usr_cfg.tuning.use_distributed_tuning))
-        if self.conf.usr_cfg.tuning.use_distributed_tuning:
-            return self.distributed_execute()
+        """Quantization execute routine based on strategy design."""
         try:
             with time_limit(self.conf.usr_cfg.tuning.exit_policy.timeout):
                 logger.debug("Dump user yaml configuration:")
@@ -186,46 +199,20 @@ class Quantization(Component):
         except Exception as e:
             logger.error("Unexpected exception {} happened during tuning.".format(repr(e)))
             import traceback
+
             traceback.print_exc()
         finally:
             if self.strategy.best_qmodel:
                 logger.info(
                     "Specified timeout or max trials is reached! "
-                    "Found a quantized model which meet accuracy goal. Exit.")
+                    "Found a quantized model which meet accuracy goal. Exit."
+                )
                 self.strategy.deploy_config()
             else:
                 logger.error(
                     "Specified timeout or max trials is reached! "
-                    "Not found any quantized model which meet accuracy goal. Exit.")
-
-            return self.strategy.best_qmodel
-
-    def distributed_execute(self):
-        """Quantization distributed execute routinue based on strategy design."""
-        from ..utils.utility import LazyImport
-        MPI = LazyImport("mpi4py.MPI")
-        comm = MPI.COMM_WORLD
-        try:
-            with time_limit(self.conf.usr_cfg.tuning.exit_policy.timeout):
-                self.strategy.traverse()
-        except KeyboardInterrupt:
-            pass
-        except Exception as e:
-            logger.error("Unexpected exception {} happened during tuning.".format(repr(e)))
-            import traceback
-            traceback.print_exc()
-        finally:
-            if self.strategy.best_qmodel:
-                logger.info(
-                    "Specified timeout or max trials is reached! "
-                    "Found a quantized model which meet accuracy goal. Exit.")
-                self.strategy.deploy_config()
-            else:
-                if comm.Get_rank() != 0:    # slaves have no q model
-                    return None
-                logger.error(
-                    "Specified timeout or max trials is reached! "
-                    "Not found any quantized model which meet accuracy goal. Exit.")
+                    "Not found any quantized model which meet accuracy goal. Exit."
+                )
 
             return self.strategy.best_qmodel
 
@@ -268,7 +255,6 @@ class Quantization(Component):
 
         Returns:
             quantized model: best qanitized model found, otherwise return None
-
         """
         return super(Quantization, self).__call__()
 
@@ -277,6 +263,7 @@ class Quantization(Component):
     def dataset(self, dataset_type, *args, **kwargs):
         """Get dataset according to dataset_type."""
         from ..data import Datasets
+
         return Datasets(self.framework)[dataset_type](*args, **kwargs)
 
     @property
@@ -308,18 +295,18 @@ class Quantization(Component):
                                     a 'real' calib_dataloader will be created,
                                     the reason is we have to know the framework info
                                     and only after the Quantization object created then
-                                    framework infomation can be known.
+                                    framework information can be known.
                                     Future we will support creating iterable dataloader
                                     from neural_compressor.experimental.common.DataLoader
         """
         from .common import _generate_common_dataloader
-        self._calib_dataloader = _generate_common_dataloader(
-            dataloader, self.framework)
+
+        self._calib_dataloader = _generate_common_dataloader(dataloader, self.framework)
 
     @property
     def metric(self):
         """Get `metric` attribute."""
-        assert False, 'Should not try to get the value of `metric` attribute.'
+        assert False, "Should not try to get the value of `metric` attribute."
         return None
 
     @metric.setter
@@ -340,21 +327,23 @@ class Quantization(Component):
                 specific frameworks and initialized.
         """
         if deep_get(self.conf.usr_cfg, "evaluation.accuracy.metric"):
-            logger.warning("Override the value of `metric` field defined in yaml file" \
-                           " as user defines the value of `metric` attribute by code.")
+            logger.warning(
+                "Override the value of `metric` field defined in yaml file"
+                " as user defines the value of `metric` attribute by code."
+            )
 
-        from .common import Metric as NCMetric
         from ..metric import METRICS
+        from .common import Metric as NCMetric
+
         if isinstance(user_metric, NCMetric):
             name = user_metric.name
             metric_cls = user_metric.metric_cls
             metric_cfg = {name: {**user_metric.kwargs}}
         else:
-            for i in ['reset', 'update', 'result']:
-                assert hasattr(user_metric, i), 'Please realise {} function' \
-                                                'in user defined metric'.format(i)
+            for i in ["reset", "update", "result"]:
+                assert hasattr(user_metric, i), "Please realise {} function" "in user defined metric".format(i)
             metric_cls = type(user_metric).__name__
-            name = 'user_' + metric_cls
+            name = "user_" + metric_cls
             metric_cfg = {name: id(user_metric)}
         deep_set(self.conf.usr_cfg, "evaluation.accuracy.metric", metric_cfg)
         self.conf.usr_cfg = DotDict(self.conf.usr_cfg)
@@ -365,7 +354,7 @@ class Quantization(Component):
     @property
     def objective(self):
         """Get `objective` attribute."""
-        assert False, 'Should not try to get the value of `objective` attribute.'
+        assert False, "Should not try to get the value of `objective` attribute."
         return None
 
     @objective.setter
@@ -374,14 +363,21 @@ class Quantization(Component):
 
         The built-in objectives include Accuracy, Performance, Footprint and ModelSize.
         """
-        if deep_get(self.conf.usr_cfg, "tuning.multi_objectives.objective") or \
-            deep_get(self.conf.usr_cfg, "tuning.objective"):
-            logger.warning("Override the value of `objective` field defined in yaml file" \
-                           " as user defines the value of `objective` attribute by code.")
+        if deep_get(self.conf.usr_cfg, "tuning.multi_objectives.objective") or deep_get(
+            self.conf.usr_cfg, "tuning.objective"
+        ):
+            logger.warning(
+                "Override the value of `objective` field defined in yaml file"
+                " as user defines the value of `objective` attribute by code."
+            )
 
-        user_obj_cfg = "tuning.objective" if deep_get(self.conf.usr_cfg, "tuning.objective") \
+        user_obj_cfg = (
+            "tuning.objective"
+            if deep_get(self.conf.usr_cfg, "tuning.objective")
             else "tuning.multi_objectives.objective"
+        )
         from ..objective import objective_custom_registry
+
         objective_cls = type(user_objective)
         name = user_objective.__class__.__name__
         objective_cfg = name if deep_get(self.conf.usr_cfg, "tuning.objective") else [name]
@@ -392,7 +388,7 @@ class Quantization(Component):
     @property
     def postprocess(self, user_postprocess):
         """Get `postprocess` attribute."""
-        assert False, 'Should not try to get the value of `postprocess` attribute.'
+        assert False, "Should not try to get the value of `postprocess` attribute."
         return None
 
     @postprocess.setter
@@ -411,23 +407,27 @@ class Quantization(Component):
                 registered to specific frameworks and initialized.
         """
         from .common import Postprocess as NCPostprocess
-        assert isinstance(user_postprocess, NCPostprocess), \
-            'please initialize a neural_compressor.experimental.common.Postprocess and set....'
-        postprocess_cfg = {user_postprocess.name : {**user_postprocess.kwargs}}
+
+        assert isinstance(
+            user_postprocess, NCPostprocess
+        ), "please initialize a neural_compressor.experimental.common.Postprocess and set...."
+        postprocess_cfg = {user_postprocess.name: {**user_postprocess.kwargs}}
         if deep_get(self.conf.usr_cfg, "evaluation.accuracy.postprocess"):
-            logger.warning("Override the value of `postprocess` field defined in yaml file" \
-                           " as user defines the value of `postprocess` attribute by code.")
-        deep_set(
-            self.conf.usr_cfg, "evaluation.accuracy.postprocess.transform", postprocess_cfg)
+            logger.warning(
+                "Override the value of `postprocess` field defined in yaml file"
+                " as user defines the value of `postprocess` attribute by code."
+            )
+        deep_set(self.conf.usr_cfg, "evaluation.accuracy.postprocess.transform", postprocess_cfg)
         from neural_compressor.data import TRANSFORMS
-        postprocesses = TRANSFORMS(self.framework, 'postprocess')
+
+        postprocesses = TRANSFORMS(self.framework, "postprocess")
         postprocesses.register(user_postprocess.name, user_postprocess.postprocess_cls)
 
     # BELOW API TO BE DEPRECATED!
     @property
     def q_func(self):
         """Get `q_func` attribute."""
-        assert False, 'Should not try to get the value of `q_func` attribute.'
+        assert False, "Should not try to get the value of `q_func` attribute."
         return None
 
     @q_func.setter
@@ -468,10 +468,10 @@ class Quantization(Component):
                        be careful of the name of model configured in yaml file,
                        make sure the name is in supported slim model list.
         """
-        approach_cfg = deep_get(self.cfg, 'quantization.approach')
+        approach_cfg = deep_get(self.cfg, "quantization.approach")
         if not self.framework:
             self.framework = get_model_fwk_name(user_model)
-        if self.framework == 'tensorflow' and approach_cfg == 'quant_aware_training':
+        if self.framework == "tensorflow" and approach_cfg == "quant_aware_training":
             if type(user_model) == str:
                 self._model = TensorflowQATModel(user_model)
             else:
@@ -481,4 +481,4 @@ class Quantization(Component):
 
     def __repr__(self):
         """Return the class string."""
-        return 'Quantization'
+        return "Quantization"
