@@ -14,34 +14,65 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """The Bayesian tuning strategy."""
 
-import copy
 import warnings
-import numpy as np
-from scipy.optimize import minimize
-from sklearn.gaussian_process.kernels import Matern
-from sklearn.gaussian_process import GaussianProcessRegressor
-
-from collections import OrderedDict
 from copy import deepcopy
 
+import numpy as np
+from scipy.optimize import minimize
+from sklearn.gaussian_process import GaussianProcessRegressor
+from sklearn.gaussian_process.kernels import Matern
+
+from ..config import options
 from ..utils import logger
-from .strategy import strategy_registry, TuneStrategy
+from .strategy import TuneStrategy, strategy_registry
 from .utils.tuning_sampler import OpWiseTuningSampler
-from .utils.tuning_structs import OpTuningConfig
 
 
 @strategy_registry
 class BayesianTuneStrategy(TuneStrategy):
     """The Bayesian tuning strategy."""
-    
-    def __init__(self, model, conf, q_dataloader, q_func=None, eval_dataloader=None, 
-                 eval_func=None, dicts=None, q_hooks=None):
-        """Init the BaySian tuning strategy."""
-        super().__init__(model, conf, q_dataloader, q_func, eval_dataloader, 
-                         eval_func, dicts, q_hooks)
+
+    def __init__(
+        self,
+        model,
+        conf,
+        q_dataloader=None,
+        q_func=None,
+        eval_func=None,
+        eval_dataloader=None,
+        eval_metric=None,
+        resume=None,
+        q_hooks=None,
+    ):
+        """Init the BaySian tuning strategy.
+
+        Args:
+            model: The FP32 model specified for low precision tuning.
+            conf: The Conf class instance includes all user configurations.
+            q_dataloader: Data loader for calibration, mandatory for post-training quantization.  Defaults to None.
+            q_func: Training function for quantization aware training. Defaults to None. Defaults to None.
+            eval_func: The evaluation function provided by user. This function takes model as parameter, and
+                evaluation dataset and metrics should be encapsulated in this function implementation and
+                outputs a higher-is-better accuracy scalar value.
+            eval_dataloader: Data loader for evaluation. Defaults to None.
+            eval_metric: Metric for evaluation. Defaults to None.
+            resume: The dict containing resume information. Defaults to None.
+            q_hooks: The dict of training hooks, supported keys are: on_epoch_begin, on_epoch_end, on_step_begin,
+                on_step_end. Their values are functions to be executed in adaptor layer.. Defaults to None.
+        """
+        super().__init__(
+            model=model,
+            conf=conf,
+            q_dataloader=q_dataloader,
+            q_func=q_func,
+            eval_func=eval_func,
+            eval_dataloader=eval_dataloader,
+            eval_metric=eval_metric,
+            resume=resume,
+            q_hooks=q_hooks,
+        )
         self.bayes_opt = None
 
     def __getstate__(self):
@@ -51,57 +82,55 @@ class BayesianTuneStrategy(TuneStrategy):
             dict: Saved dict for resuming
         """
         for history in self.tuning_history:
-            if self._same_yaml(history['cfg'], self.cfg):
-                history['bayes_opt'] = self.bayes_opt
+            if self._same_conf(history["cfg"], self.conf):
+                history["bayes_opt"] = self.bayes_opt
         save_dict = super().__getstate__()
         return save_dict
 
     def _params_to_tune_configs(self, params):
         op_tuning_cfg = {}
-        calib_sampling_size_lst = self.tuning_space.root_item.get_option_by_name('calib_sampling_size').options
+        calib_sampling_size_lst = self.tuning_space.root_item.get_option_by_name("calib_sampling_size").options
         for op_name_type, configs in self.op_configs.items():
             if len(configs) == 1:
                 op_tuning_cfg[op_name_type] = configs[0]
             else:
                 op_tuning_cfg[op_name_type] = configs[min(len(configs) - 1, int(params[op_name_type[0]]))]
         if len(calib_sampling_size_lst) > 1:
-            calib_sampling_size = calib_sampling_size_lst[min(len(configs) - 1, int(params['calib_sampling_size']))]
+            calib_sampling_size = calib_sampling_size_lst[min(len(configs) - 1, int(params["calib_sampling_size"]))]
         else:
             calib_sampling_size = calib_sampling_size_lst[0]
-        op_tuning_cfg['calib_sampling_size'] = calib_sampling_size
+        op_tuning_cfg["calib_sampling_size"] = calib_sampling_size
         return op_tuning_cfg
 
     def next_tune_cfg(self):
         """Generate the next tuning config according to bayesian search algorithm.
-        
+
         This strategy comes from the Bayesian optimization package and changed it to a discrete version.
-        It uses Gaussian processes to define the prior/posterior distribution over the black-box 
-        function with the tuning history and then finds the tuning configuration that maximizes 
+        It uses Gaussian processes to define the prior/posterior distribution over the black-box
+        function with the tuning history and then finds the tuning configuration that maximizes
         the expected improvement.
 
         Returns:
             tune_config (dict): A dict containing the tuning configuration for quantization.
         """
         params = None
-        pbounds = {} 
+        pbounds = {}
         tuning_space = self.tuning_space
-        calib_sampling_size_lst = tuning_space.root_item.get_option_by_name('calib_sampling_size').options
+        calib_sampling_size_lst = tuning_space.root_item.get_option_by_name("calib_sampling_size").options
         op_item_dtype_dict, quant_mode_wise_items, initial_op_tuning_cfg = self.initial_tuning_cfg()
-        op_wise_pool = OpWiseTuningSampler(tuning_space, [], [], 
-                                           op_item_dtype_dict, initial_op_tuning_cfg)
+        op_wise_pool = OpWiseTuningSampler(tuning_space, [], [], op_item_dtype_dict, initial_op_tuning_cfg)
         self.op_configs = op_wise_pool.get_opwise_candidate()
 
         for op_name_type, configs in self.op_configs.items():
             if len(configs) > 1:
                 pbounds[op_name_type[0]] = (0, len(configs))
         if len(calib_sampling_size_lst) > 1:
-            pbounds['calib_sampling_size'] = (0, len(calib_sampling_size_lst))
+            pbounds["calib_sampling_size"] = (0, len(calib_sampling_size_lst))
         if len(pbounds) == 0:
             yield self._params_to_tune_configs(params)
             return
         if self.bayes_opt is None:
-            self.bayes_opt = BayesianOptimization(
-                pbounds=pbounds, random_seed=self.cfg.tuning.random_seed)
+            self.bayes_opt = BayesianOptimization(pbounds=pbounds, random_seed=options.random_seed)
         while True:
             params = self.bayes_opt.gen_next_params()
             logger.debug("Dump current bayesian params:")
@@ -111,7 +140,7 @@ class BayesianTuneStrategy(TuneStrategy):
                 self.bayes_opt._space.register(params, self.last_tune_result[0])
             except KeyError:
                 logger.debug("Find registered params, skip it.")
-                pass
+
 
 # Util part
 # Bayesian opt acq function
@@ -119,7 +148,7 @@ class BayesianTuneStrategy(TuneStrategy):
 
 def acq_max(ac, gp, y_max, bounds, random_seed, n_warmup=10000, n_iter=10):
     """Find the maximum of the acquisition function parameters.
-    
+
     Args:
         ac: The acquisition function object that return its point-wise value.
         gp: A gaussian process fitted to the relevant data.
@@ -128,31 +157,28 @@ def acq_max(ac, gp, y_max, bounds, random_seed, n_warmup=10000, n_iter=10):
         random_seed: instance of np.RandomState random number generator
         n_warmup: number of times to randomly sample the acquisition function
         n_iter: number of times to run scipy.minimize
-    
+
     Returns:
         x_max: The arg max of the acquisition function.
     """
     # Warm up with random points
-    x_tries = np.random.uniform(bounds[:, 0], bounds[:, 1],
-                                size=(n_warmup, bounds.shape[0]))
+    x_tries = np.random.uniform(bounds[:, 0], bounds[:, 1], size=(n_warmup, bounds.shape[0]))
     ys = ac(x_tries, gp=gp, y_max=y_max)
     x_max = x_tries[ys.argmax()]
     max_acq = ys.max()
 
     # Explore the parameter space more thoroughly
-    x_seeds = np.random.uniform(bounds[:, 0], bounds[:, 1],
-                                size=(n_iter, bounds.shape[0]))
+    x_seeds = np.random.uniform(bounds[:, 0], bounds[:, 1], size=(n_iter, bounds.shape[0]))
     for x_try in x_seeds:
         # Find the minimum of minus the acquisition function
-        res = minimize(lambda x: -ac(x.reshape(1, -1), gp=gp, y_max=y_max),
-                       x_try.reshape(1, -1),
-                       bounds=bounds,
-                       method="L-BFGS-B")
+        res = minimize(
+            lambda x: -ac(x.reshape(1, -1), gp=gp, y_max=y_max), x_try.flatten(), bounds=bounds, method="L-BFGS-B"
+        )
 
         # See if success
         if not res.success:
             continue
-        
+
         if isinstance(res.fun, float):
             res.fun = np.array([res.fun])
         # Store it if better than previous minimum(maximum).
@@ -169,16 +195,17 @@ def _hashable(x):
     """Ensure that an point is hashable by a python dict."""
     return tuple(map(float, x))
 
+
 # Target space part
 class TargetSpace(object):
     """Holds the param-space coordinates (X) and target values (Y).
-    
+
     Allows for constant-time appends while ensuring no duplicates are added.
     """
 
     def __init__(self, pbounds, random_seed=9527):
         """Construct a TargetSpace.
-        
+
         Args:
             target_func (function): Function to be maximized.
             pbounds (dict): Dictionary with parameters names as keys and a tuple with minimum and maximum values.
@@ -189,10 +216,7 @@ class TargetSpace(object):
         names = list(pbounds.keys())
         self._keys = deepcopy(names)
         # Create an array with parameters bounds
-        self._bounds = np.array(
-            [pbounds[name] for name in names],
-            dtype=np.float32
-        )
+        self._bounds = np.array([pbounds[name] for name in names], dtype=np.float32)
 
         # preallocated memory for X and Y points
         self._params = np.empty(shape=(0, self.dim))
@@ -244,18 +268,18 @@ class TargetSpace(object):
         """Generate an array from params.
 
         Args:
-            params (Dict): The dict contains keys in `self.keys`, and 
+            params (Dict): The dict contains keys in `self.keys`, and
               corresponding param.
 
         Returns:
-            np.array: An array contains all params. 
+            np.array: An array contains all params.
         """
         try:
             assert set(params) == set(self.keys)
         except AssertionError:
             raise ValueError(
-                "Parameters' keys ({}) do ".format(list(params.keys())) +
-                "not match the expected set of keys ({}).".format(self.keys)
+                "Parameters' keys ({}) do ".format(list(params.keys()))
+                + "not match the expected set of keys ({}).".format(self.keys)
             )
         return np.asarray([params[key] for key in self.keys])
 
@@ -272,8 +296,8 @@ class TargetSpace(object):
             assert len(x) == len(self.keys)
         except AssertionError:
             raise ValueError(
-                "Size of array ({}) is different than the ".format(len(x)) +
-                "expected number of parameters ({}).".format(len(self.keys))
+                "Size of array ({}) is different than the ".format(len(x))
+                + "expected number of parameters ({}).".format(len(self.keys))
             )
         return dict(zip(self.keys, x))
 
@@ -288,26 +312,26 @@ class TargetSpace(object):
             assert x.size == self.dim
         except AssertionError:
             raise ValueError(
-                "Size of array ({}) is different than the ".format(len(x)) +
-                "expected number of parameters ({}).".format(len(self.keys))
+                "Size of array ({}) is different than the ".format(len(x))
+                + "expected number of parameters ({}).".format(len(self.keys))
             )
         return x
 
     def register(self, params, target):
         """Append a point and its target value to the known data.
-        
+
         Runs in amortized constant time.
-        
+
         Args:
             params (ndarray): a single point, with len(params) == self.dim
             target (float): target function value
-        
+
         Raises:
             KeyError: if the point is not unique
         """
         x = self._as_array(params)
         if x in self:
-            raise KeyError('Params point {} is not unique'.format(x))
+            raise KeyError("Params point {} is not unique".format(x))
 
         # Insert data into unique dictionary
         self._cache[_hashable(x.ravel())] = target
@@ -317,10 +341,10 @@ class TargetSpace(object):
 
     def get_target(self, params):
         """Get the target value of params.
-        
+
         Args:
             params (ndarray): a single point, with len(params) == self.dim
-        
+
         Returns:
             target (float): target function value.
         """
@@ -330,54 +354,46 @@ class TargetSpace(object):
 
     def random_sample(self):
         """Create random points within the bounds of the space.
-        
+
         Returns:
             data (ndarray): [num x dim] array points with dimensions corresponding to `self._keys`
         """
         # TODO: support integer, category, and basic scipy.optimize constraints
         data = np.empty((1, self.dim))
         for col, (lower, upper) in enumerate(self._bounds):
-            data.T[col] = np.random.uniform(  # pylint: disable=unsupported-assignment-operation
-                lower, upper, size=1)
+            data.T[col] = np.random.uniform(lower, upper, size=1)  # pylint: disable=unsupported-assignment-operation
         return data.ravel()
 
     def max(self):
-        """Get maximum target value found and corresponding parametes."""
+        """Get maximum target value found and corresponding parameters."""
         try:
-            res = {
-                'target': self.target.max(),
-                'params': dict(
-                    zip(self.keys, self.params[self.target.argmax()])
-                )
-            }
+            res = {"target": self.target.max(), "params": dict(zip(self.keys, self.params[self.target.argmax()]))}
         except ValueError:
             res = {}
         return res
 
     def res(self):
-        """Get all target values found and corresponding parametes."""
+        """Get all target values found and corresponding parameters."""
         params = [dict(zip(self.keys, p)) for p in self.params]
 
-        return [
-            {"target": target, "params": param}
-            for target, param in zip(self.target, params)
-        ]
+        return [{"target": target, "params": param} for target, param in zip(self.target, params)]
+
 
 # Tuning part
-class BayesianOptimization():
+class BayesianOptimization:
     """The class for bayesian optimization.
-    
-    This class takes the parameters bounds in order to find which values for 
+
+    This class takes the parameters bounds in order to find which values for
     the parameters yield the maximum value using bayesian optimization.
     """
-    
+
     def __init__(self, pbounds, random_seed=9527, verbose=2):
         """Init bayesian optimization.
 
         Args:
             pbounds (dict): Dictionary with parameters names as keys and a tuple with
               minimum and maximum values.
-            random_seed (int, optional): The seed for random searching. Default to 9527. 
+            random_seed (int, optional): The seed for random searching. Default to 9527.
             verbose (int, optional): The level of verbosity. Default to 2.
         """
         self._random_seed = random_seed
@@ -434,7 +450,7 @@ class BayesianOptimization():
             gp=self._gp,
             y_max=self._space.target.max(),
             bounds=self._space.bounds,
-            random_seed=self._random_seed
+            random_seed=self._random_seed,
         )
         return self._space.array_to_params(suggestion)
 
