@@ -14,13 +14,22 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """Utils: provide useful methods and auxiliary functionalities."""
 
 from .collect_layer_histogram import LayerHistogramCollector
 from .logger import log, info, debug, warn, warning, error, fatal
 from .options import OPTIONS
-from .utility import set_random_seed
+from .utility import alias_param
 
-__all__ = ["LayerHistogramCollector", "log", "info", "debug", "warn", "warning", "error", "fatal",
-           "OPTIONS", "set_random_seed"]
+__all__ = [
+    "LayerHistogramCollector",
+    "log",
+    "info",
+    "debug",
+    "warn",
+    "warning",
+    "error",
+    "fatal",
+    "OPTIONS",
+    "alias_param",
+]
